@@ -118,18 +118,45 @@ public class AuthzAuditEvent extends AuditEventBase {
 	@SerializedName("cluster_name")
 	protected String clusterName;
 
+	@SerializedName("zone_name")
+	protected String zoneName;
+
+	@SerializedName("policy_version")
+	protected Long policyVersion;
+
 	public AuthzAuditEvent() {
 		super();
 
 		this.repositoryType = 0;
 	}
 
+	public AuthzAuditEvent(int repositoryType, String repositoryName,
+						   String user, Date eventTime, String accessType,
+						   String resourcePath, String resourceType, String action,
+						   short accessResult, String agentId, long policyId,
+						   String resultReason, String aclEnforcer, String sessionId,
+						   String clientType, String clientIP, String requestData, String clusterName) {
+		this(repositoryType, repositoryName, user, eventTime, accessType, resourcePath, resourceType, action, accessResult, agentId,
+				policyId, resultReason, aclEnforcer, sessionId, clientType, clientIP, requestData, clusterName, null);
+	}
+
 	public AuthzAuditEvent(int repositoryType, String repositoryName,
 			String user, Date eventTime, String accessType,
 			String resourcePath, String resourceType, String action,
 			short accessResult, String agentId, long policyId,
 			String resultReason, String aclEnforcer, String sessionId,
-			String clientType, String clientIP, String requestData, String clusterName) {
+			String clientType, String clientIP, String requestData, String clusterName, String zoneName) {
+		this(repositoryType, repositoryName, user, eventTime, accessType, resourcePath, resourceType, action, accessResult, agentId,
+				policyId, resultReason, aclEnforcer, sessionId, clientType, clientIP, requestData, clusterName, zoneName, null);
+
+	}
+
+	public AuthzAuditEvent(int repositoryType, String repositoryName,
+						   String user, Date eventTime, String accessType,
+						   String resourcePath, String resourceType, String action,
+						   short accessResult, String agentId, long policyId,
+						   String resultReason, String aclEnforcer, String sessionId,
+						   String clientType, String clientIP, String requestData, String clusterName, String zoneName, Long policyVersion) {
 		this.repositoryType = repositoryType;
 		this.repositoryName = repositoryName;
 		this.user = user;
@@ -148,6 +175,8 @@ public class AuthzAuditEvent extends AuditEventBase {
 		this.clientIP = clientIP;
 		this.requestData = requestData;
 		this.clusterName = clusterName;
+		this.zoneName = zoneName;
+		this.policyVersion = policyVersion;
 	}
 
 	/**
@@ -461,6 +490,22 @@ public class AuthzAuditEvent extends AuditEventBase {
 		return clusterName;
 	}
 
+	public void setZoneName(String zoneName) {
+		this.zoneName = zoneName;
+	}
+
+	public String getZoneName() {
+		return zoneName;
+	}
+
+	public void setPolicyVersion(Long policyVersion) {
+		this.policyVersion = policyVersion;
+	}
+
+	public Long getPolicyVersion() {
+		return policyVersion;
+	}
+
 	public void setClusterName(String clusterName) {
 		this.clusterName = clusterName;
 	}
@@ -522,6 +567,9 @@ public class AuthzAuditEvent extends AuditEventBase {
 				.append("tags=").append("[")
 				.append(StringUtils.join(tags, ", "))
 				.append("]")
+				.append(FIELD_SEPARATOR).append("clusterName=").append(clusterName)
+				.append(FIELD_SEPARATOR).append("zoneName=").append(zoneName)
+				.append(FIELD_SEPARATOR).append("policyVersion=").append(policyVersion)
 				.append(FIELD_SEPARATOR).append("additionalInfo=").append(additionalInfo);
 
 		return sb;
