@@ -20,7 +20,9 @@
  package org.apache.ranger.admin.client;
 
 
+import org.apache.ranger.plugin.model.RangerRole;
 import org.apache.ranger.plugin.util.GrantRevokeRequest;
+import org.apache.ranger.plugin.util.GrantRevokeRoleRequest;
 import org.apache.ranger.plugin.util.ServicePolicies;
 import org.apache.ranger.plugin.util.ServiceTags;
 
@@ -33,6 +35,20 @@ public interface RangerAdminClient {
 
 	ServicePolicies getServicePoliciesIfUpdated(long lastKnownVersion, long lastActivationTimeInMillis) throws Exception;
 
+	RangerRole createRole(RangerRole request) throws Exception;
+
+	void dropRole(String execUser, String roleName) throws Exception;
+
+	List<String> getAllRoles(String execUser) throws Exception;
+
+	List<String> getUserRoles(String execUser) throws Exception;
+
+	RangerRole getRole(String execUser, String roleName) throws Exception;
+
+	void grantRole(GrantRevokeRoleRequest request) throws Exception;
+
+	void revokeRole(GrantRevokeRoleRequest request) throws Exception;
+
 	void grantAccess(GrantRevokeRequest request) throws Exception;
 
 	void revokeAccess(GrantRevokeRequest request) throws Exception;
