@@ -35,8 +35,9 @@ import org.apache.ranger.authorization.hadoop.constants.RangerHadoopConstants;
 import org.apache.ranger.plugin.contextenricher.RangerTagForEval;
 import org.apache.ranger.plugin.policyengine.*;
 import org.apache.ranger.plugin.service.RangerBasePlugin;
+import org.apache.ranger.plugin.util.JsonUtilsV2;
 import org.apache.ranger.plugin.util.RangerAccessRequestUtil;
-import org.codehaus.jackson.map.ObjectMapper;
+import org.apache.ranger.plugin.util.RangerRESTUtils;
 
 
 public class RangerDefaultAuditHandler implements RangerAccessResultProcessor {
@@ -49,6 +50,8 @@ public class RangerDefaultAuditHandler implements RangerAccessResultProcessor {
 	private static String UUID 	= MiscUtil.generateUniqueId();
 	private static AtomicInteger  counter =  new AtomicInteger(0);
 
+	RangerRESTUtils restUtils = new RangerRESTUtils();
+
 	public RangerDefaultAuditHandler() {
 	}
 
@@ -123,6 +126,9 @@ public class RangerDefaultAuditHandler implements RangerAccessResultProcessor {
 			}
 			ret.setAdditionalInfo(getAdditionalInfo(request));
 			ret.setClusterName(request.getClusterName());
+			ret.setZoneName(result.getZoneName());
+			ret.setAgentHostname(restUtils.getAgentHostname());
+			ret.setPolicyVersion(result.getPolicyVersion());
 			populateDefaults(ret);
 		}
 
@@ -200,6 +206,10 @@ public class RangerDefaultAuditHandler implements RangerAccessResultProcessor {
 			auditEvent.setEventId(generateNextAuditEventId());
 		}
 
+		if (auditEvent.getAgentId() == null) {
+			auditEvent.setAgentId(MiscUtil.getApplicationType());
+		}
+
 		auditEvent.setSeqNum(sequenceNumber++);
 	}
 
@@ -262,11 +272,9 @@ public class RangerDefaultAuditHandler implements RangerAccessResultProcessor {
 	 }
 
 	private String writeObjectAsString(Serializable obj) {
-		ObjectMapper mapper = new ObjectMapper();
-
 		String jsonStr = StringUtils.EMPTY;
 		try {
-			jsonStr = mapper.writeValueAsString(obj);
+			jsonStr = JsonUtilsV2.objToJson(obj);
 		} catch (Exception e) {
 			LOG.error("Cannot create JSON string for object:[" + obj + "]", e);
 		}
