@@ -20,6 +20,7 @@
 package org.apache.ranger.plugin.model;
 
 import java.util.ArrayList;
+import java.util.Comparator;
 import java.util.List;
 import java.util.HashMap;
 import java.util.Map;
@@ -61,6 +62,8 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	public static final String POLICY_PRIORITY_NAME_NORMAL   = "NORMAL";
 	public static final String POLICY_PRIORITY_NAME_OVERRIDE = "OVERRIDE";
 
+	public static final Comparator<RangerPolicy> POLICY_ID_COMPARATOR = new PolicyIdComparator();
+
 	// For future use
 	private static final long serialVersionUID = 1L;
 
@@ -72,6 +75,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	private String							  resourceSignature;
 	private Boolean                           isAuditEnabled;
 	private Map<String, RangerPolicyResource> resources;
+	private List<RangerPolicyItemCondition>   conditions;
 	private List<RangerPolicyItem>            policyItems;
 	private List<RangerPolicyItem>            denyPolicyItems;
 	private List<RangerPolicyItem>            allowExceptions;
@@ -82,11 +86,25 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	private Map<String, Object>               options;
 	private List<RangerValiditySchedule>      validitySchedules;
 	private List<String>                      policyLabels;
+	private String                            zoneName;
+	private Boolean                           isDenyAllElse;
 
 	public RangerPolicy() {
 		this(null, null, null, null, null, null, null, null, null, null, null);
 	}
 
+	public RangerPolicy(String service, String name, Integer policyType, Integer policyPriority, String description, Map<String, RangerPolicyResource> resources, List<RangerPolicyItem> policyItems, String resourceSignature, Map<String, Object> options, List<RangerValiditySchedule> validitySchedules, List<String> policyLables) {
+		this(service, name, policyType, policyPriority, description, resources, policyItems, resourceSignature, options, validitySchedules, policyLables, null);
+	}
+
+	public RangerPolicy(String service, String name, Integer policyType, Integer policyPriority, String description, Map<String, RangerPolicyResource> resources, List<RangerPolicyItem> policyItems, String resourceSignature, Map<String, Object> options, List<RangerValiditySchedule> validitySchedules, List<String> policyLables, String zoneName) {
+		this(service, name, policyType, policyPriority, description, resources, policyItems, resourceSignature, options, validitySchedules, policyLables, zoneName, null);
+	}
+
+	public RangerPolicy(String service, String name, Integer policyType, Integer policyPriority, String description, Map<String, RangerPolicyResource> resources, List<RangerPolicyItem> policyItems, String resourceSignature, Map<String, Object> options, List<RangerValiditySchedule> validitySchedules, List<String> policyLables, String zoneName, List<RangerPolicyItemCondition> conditions) {
+		this(service, name, policyType, policyPriority, description, resources, policyItems, resourceSignature, options, validitySchedules, policyLables, zoneName, conditions, null);
+	}
+
 	/**
 	 * @param service
 	 * @param name
@@ -96,7 +114,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	 * @param policyItems
 	 * @param resourceSignature TODO
 	 */
-	public RangerPolicy(String service, String name, Integer policyType, Integer policyPriority, String description, Map<String, RangerPolicyResource> resources, List<RangerPolicyItem> policyItems, String resourceSignature, Map<String, Object> options, List<RangerValiditySchedule> validitySchedules, List<String> policyLables) {
+	public RangerPolicy(String service, String name, Integer policyType, Integer policyPriority, String description, Map<String, RangerPolicyResource> resources, List<RangerPolicyItem> policyItems, String resourceSignature, Map<String, Object> options, List<RangerValiditySchedule> validitySchedules, List<String> policyLables, String zoneName, List<RangerPolicyItemCondition> conditions, Boolean isDenyAllElse) {
 		super();
 
 		setService(service);
@@ -116,6 +134,9 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		setOptions(options);
 		setValiditySchedules(validitySchedules);
 		setPolicyLabels(policyLables);
+		setZoneName(zoneName);
+		setConditions(conditions);
+		setIsDenyAllElse(isDenyAllElse);
 
 	}
 
@@ -142,6 +163,9 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		setOptions(other.getOptions());
 		setValiditySchedules(other.getValiditySchedules());
 		setPolicyLabels(other.getPolicyLabels());
+		setZoneName(other.getZoneName());
+		setConditions(other.getConditions());
+		setIsDenyAllElse(other.getIsDenyAllElse());
 	}
 
 	/**
@@ -475,6 +499,30 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
             this.validitySchedules.addAll(validitySchedules);
         }
     }
+    public String getZoneName() { return zoneName; }
+
+    public void setZoneName(String zoneName) {
+	    this.zoneName = zoneName;
+    }
+
+	/**
+	 * @return the conditions
+	 */
+	public List<RangerPolicyItemCondition> getConditions() { return conditions; }
+	/**
+	 * @param conditions the conditions to set
+	 */
+	public void setConditions(List<RangerPolicyItemCondition> conditions) {
+		this.conditions = conditions;
+	}
+
+	public Boolean getIsDenyAllElse() {
+		return isDenyAllElse;
+	}
+
+	public void setIsDenyAllElse(Boolean isDenyAllElse) {
+		this.isDenyAllElse = isDenyAllElse == null ? Boolean.FALSE : isDenyAllElse;
+	}
 
 	@Override
 	public String toString( ) {
@@ -517,6 +565,17 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
                         }
                 }
                 sb.append("} ");
+
+		sb.append("policyConditions={");
+		if(conditions != null) {
+			for(RangerPolicyItemCondition condition : conditions) {
+				if(condition != null) {
+					condition.toString(sb);
+				}
+			}
+		}
+		sb.append("} ");
+
 		sb.append("policyItems={");
 		if(policyItems != null) {
 			for(RangerPolicyItem policyItem : policyItems) {
@@ -596,13 +655,23 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
                 }
             }
         }
-        sb.append("}");
+        sb.append(", zoneName=").append(zoneName);
+
+		sb.append(", isDenyAllElse={").append(isDenyAllElse).append("} ");
+
+		sb.append("}");
 
 		sb.append("}");
 
 		return sb;
 	}
 
+	static class PolicyIdComparator implements Comparator<RangerPolicy>, java.io.Serializable {
+		@Override
+		public int compare(RangerPolicy me, RangerPolicy other) {
+			return Long.compare(me.getId(), other.getId());
+		}
+	}
 
 	@JsonAutoDetect(fieldVisibility=Visibility.ANY)
 	@JsonSerialize(include=JsonSerialize.Inclusion.NON_NULL)
@@ -783,17 +852,19 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		private List<RangerPolicyItemAccess>    accesses;
 		private List<String>                    users;
 		private List<String>                    groups;
+		private List<String>                    roles;
 		private List<RangerPolicyItemCondition> conditions;
 		private Boolean                         delegateAdmin;
 
 		public RangerPolicyItem() {
-			this(null, null, null, null, null);
+			this(null, null, null, null, null, null);
 		}
 
-		public RangerPolicyItem(List<RangerPolicyItemAccess> accessTypes, List<String> users, List<String> groups, List<RangerPolicyItemCondition> conditions, Boolean delegateAdmin) {
+		public RangerPolicyItem(List<RangerPolicyItemAccess> accessTypes, List<String> users, List<String> groups, List<String> roles, List<RangerPolicyItemCondition> conditions, Boolean delegateAdmin) {
 			setAccesses(accessTypes);
 			setUsers(users);
 			setGroups(groups);
+			setRoles(roles);
 			setConditions(conditions);
 			setDelegateAdmin(delegateAdmin);
 		}
@@ -870,6 +941,30 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 				this.groups.addAll(groups);
 			}
 		}
+		/**
+		 * @return the roles
+		 */
+		public List<String> getRoles() {
+			return roles;
+		}
+		/**
+		 * @param roles the roles to set
+		 */
+		public void setRoles(List<String> roles) {
+			if(this.roles == null) {
+				this.roles = new ArrayList<>();
+			}
+
+			if(this.roles == roles) {
+				return;
+			}
+
+			this.roles.clear();
+
+			if(roles != null) {
+				this.roles.addAll(roles);
+			}
+		}
 		/**
 		 * @return the conditions
 		 */
@@ -951,6 +1046,16 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 			}
 			sb.append("} ");
 
+			sb.append("roles={");
+			if(roles != null) {
+				for(String role : roles) {
+					if(role != null) {
+						sb.append(role).append(" ");
+					}
+				}
+			}
+			sb.append("} ");
+
 			sb.append("conditions={");
 			if(conditions != null) {
 				for(RangerPolicyItemCondition condition : conditions) {
@@ -977,6 +1082,8 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 					+ ((conditions == null) ? 0 : conditions.hashCode());
 			result = prime * result
 					+ ((delegateAdmin == null) ? 0 : delegateAdmin.hashCode());
+			result = prime * result
+					+ ((roles == null) ? 0 : roles.hashCode());
 			result = prime * result
 					+ ((groups == null) ? 0 : groups.hashCode());
 			result = prime * result + ((users == null) ? 0 : users.hashCode());
@@ -1007,6 +1114,11 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 					return false;
 			} else if (!delegateAdmin.equals(other.delegateAdmin))
 				return false;
+			if (roles == null) {
+				if (other.roles != null)
+					return false;
+			} else if (!roles.equals(other.roles))
+				return false;
 			if (groups == null) {
 				if (other.groups != null)
 					return false;
@@ -1033,11 +1145,11 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		private RangerPolicyItemDataMaskInfo dataMaskInfo;
 
 		public RangerDataMaskPolicyItem() {
-			this(null, null, null, null, null, null);
+			this(null, null, null, null, null, null, null);
 		}
 
-		public RangerDataMaskPolicyItem(List<RangerPolicyItemAccess> accesses, RangerPolicyItemDataMaskInfo dataMaskDetail, List<String> users, List<String> groups, List<RangerPolicyItemCondition> conditions, Boolean delegateAdmin) {
-			super(accesses, users, groups, conditions, delegateAdmin);
+		public RangerDataMaskPolicyItem(List<RangerPolicyItemAccess> accesses, RangerPolicyItemDataMaskInfo dataMaskDetail, List<String> users, List<String> groups, List<String> roles, List<RangerPolicyItemCondition> conditions, Boolean delegateAdmin) {
+			super(accesses, users, groups, roles, conditions, delegateAdmin);
 
 			setDataMaskInfo(dataMaskDetail);
 		}
@@ -1120,11 +1232,11 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		private RangerPolicyItemRowFilterInfo rowFilterInfo;
 
 		public RangerRowFilterPolicyItem() {
-			this(null, null, null, null, null, null);
+			this(null, null, null, null, null, null, null);
 		}
 
-		public RangerRowFilterPolicyItem(RangerPolicyItemRowFilterInfo rowFilterInfo, List<RangerPolicyItemAccess> accesses, List<String> users, List<String> groups, List<RangerPolicyItemCondition> conditions, Boolean delegateAdmin) {
-			super(accesses, users, groups, conditions, delegateAdmin);
+		public RangerRowFilterPolicyItem(RangerPolicyItemRowFilterInfo rowFilterInfo, List<RangerPolicyItemAccess> accesses, List<String> users, List<String> groups, List<String> roles, List<RangerPolicyItemCondition> conditions, Boolean delegateAdmin) {
+			super(accesses, users, groups, roles, conditions, delegateAdmin);
 
 			setRowFilterInfo(rowFilterInfo);
 		}
@@ -1370,7 +1482,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		}
 
 		public StringBuilder toString(StringBuilder sb) {
-			sb.append("RangerPolicyItemCondition={");
+			sb.append("RangerPolicyCondition={");
 			sb.append("type={").append(type).append("} ");
 			sb.append("values={");
 			if(values != null) {
