@@ -1225,27 +1225,27 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	public static class RangerResourceDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
-		private Long                itemId;
-		private String              name;
-		private String              type;
-		private Integer             level;
-		private String              parent;
-		private Boolean             mandatory;
-		private Boolean             lookupSupported;
-		private Boolean             recursiveSupported;
-		private Boolean             excludesSupported;
-		private String              matcher;
-		private Map<String, String> matcherOptions;
-		private String              validationRegEx;
-		private String              validationMessage;
-		private String              uiHint;
-		private String              label;
-		private String              description;
-		private String              rbKeyLabel;
-		private String              rbKeyDescription;
-		private String              rbKeyValidationMessage;
-		private Set<String>         accessTypeRestrictions;
-		private Boolean             isValidLeaf;
+		private Long                itemId                 = null;
+		private String              name                   = null;
+		private String              type                   = null;
+		private Integer             level                  = null;
+		private String              parent                 = null;
+		private Boolean             mandatory              = null;
+		private Boolean             lookupSupported        = null;
+		private Boolean             recursiveSupported     = null;
+		private Boolean             excludesSupported      = null;
+		private String              matcher                = null;
+		private Map<String, String> matcherOptions         = null;
+		private String              validationRegEx        = null;
+		private String              validationMessage      = null;
+		private String              uiHint                 = null;
+		private String              label                  = null;
+		private String              description            = null;
+		private String              rbKeyLabel             = null;
+		private String              rbKeyDescription       = null;
+		private String              rbKeyValidationMessage = null;
+		private Set<String>         accessTypeRestrictions = null;
+		private Boolean             isValidLeaf            = null;
 
 		public RangerResourceDef() {
 			this(null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null);
