@@ -33,6 +33,7 @@ import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItemAccess;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyResource;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerRowFilterPolicyItem;
 import org.apache.ranger.plugin.model.RangerPolicyResourceSignature;
+import org.apache.ranger.plugin.model.RangerSecurityZone;
 import org.apache.ranger.plugin.model.RangerService;
 import org.apache.ranger.plugin.model.RangerServiceDef;
 import org.apache.ranger.plugin.model.RangerServiceDef.RangerAccessTypeDef;
@@ -165,10 +166,12 @@ public class RangerPolicyValidator extends RangerValidator {
 					valid = false;
 				}
 			}
-			String policyName = policy.getName();
+			String policyName  = policy.getName();
 			String serviceName = policy.getService();
+			String zoneName    = policy.getZoneName();
 
 			RangerService service = null;
+			RangerSecurityZone zone = null;
 			boolean serviceNameValid = false;
 			if (StringUtils.isBlank(serviceName)) {
 				ValidationErrorCode error = ValidationErrorCode.POLICY_VALIDATION_ERR_MISSING_FIELD;
@@ -195,6 +198,32 @@ public class RangerPolicyValidator extends RangerValidator {
 				}
 			}
 
+			if (StringUtils.isNotEmpty(zoneName)) {
+				zone = getSecurityZone(zoneName);
+				if (zone == null) {
+					ValidationErrorCode error = ValidationErrorCode.POLICY_VALIDATION_ERR_NONEXISTANT_ZONE_NAME;
+					failures.add(new ValidationFailureDetailsBuilder()
+							.field("zoneName")
+							.isSemanticallyIncorrect()
+							.becauseOf(error.getMessage(id, zoneName))
+							.errorCode(error.getErrorCode())
+							.build());
+					valid = false;
+				}
+				List<String> tagSvcList = zone.getTagServices();
+				Set<String> svcNameSet = zone.getServices().keySet();
+				if(!svcNameSet.contains(serviceName) && !tagSvcList.contains(serviceName)){
+					ValidationErrorCode error = ValidationErrorCode.POLICY_VALIDATION_ERR_SERVICE_NOT_ASSOCIATED_TO_ZONE;
+					failures.add(new ValidationFailureDetailsBuilder()
+							.field("zoneName")
+							.isSemanticallyIncorrect()
+							.becauseOf(error.getMessage(serviceName, zoneName))
+							.errorCode(error.getErrorCode())
+							.build());
+					valid = false;
+				}
+			}
+
 			if (StringUtils.isBlank(policyName)) {
 				ValidationErrorCode error = ValidationErrorCode.POLICY_VALIDATION_ERR_MISSING_FIELD;
 				failures.add(new ValidationFailureDetailsBuilder()
@@ -205,8 +234,10 @@ public class RangerPolicyValidator extends RangerValidator {
 					.build());
 				valid = false;
 			} else {
-				if (service != null) {
-					Long policyId = getPolicyId(service.getId(), policyName);
+				if (service != null && (StringUtils.isEmpty(zoneName) || zone != null)) {
+					Long zoneId = zone != null ? zone.getId() : RangerSecurityZone.RANGER_UNZONED_SECURITY_ZONE_ID;
+					Long policyId = getPolicyId(service.getId(), policyName, zoneId);
+
 					if (policyId != null) {
 						if (action == Action.CREATE) {
 							ValidationErrorCode error = ValidationErrorCode.POLICY_VALIDATION_ERR_POLICY_NAME_CONFLICT;
@@ -232,7 +263,7 @@ public class RangerPolicyValidator extends RangerValidator {
 			}
 
 			if(existingPolicy != null) {
-				if(! StringUtils.equalsIgnoreCase(existingPolicy.getService(), policy.getService())) {
+				if (!StringUtils.equalsIgnoreCase(existingPolicy.getService(), policy.getService())) {
 					ValidationErrorCode error = ValidationErrorCode.POLICY_VALIDATION_ERR_POLICY_UPDATE_MOVE_SERVICE_NOT_ALLOWED;
 					failures.add(new ValidationFailureDetailsBuilder()
 							.field("service name")
@@ -246,7 +277,7 @@ public class RangerPolicyValidator extends RangerValidator {
 				int existingPolicyType = existingPolicy.getPolicyType() == null ? RangerPolicy.POLICY_TYPE_ACCESS : existingPolicy.getPolicyType();
 				int policyType         = policy.getPolicyType() == null ? RangerPolicy.POLICY_TYPE_ACCESS : policy.getPolicyType();
 
-				if(existingPolicyType != policyType) {
+				if (existingPolicyType != policyType) {
 					ValidationErrorCode error = ValidationErrorCode.POLICY_VALIDATION_ERR_POLICY_TYPE_CHANGE_NOT_ALLOWED;
 					failures.add(new ValidationFailureDetailsBuilder()
 							.field("policy type")
@@ -256,6 +287,21 @@ public class RangerPolicyValidator extends RangerValidator {
 							.build());
 					valid = false;
 				}
+
+				String existingZoneName = existingPolicy.getZoneName();
+
+				if (StringUtils.isNotEmpty(zoneName) || StringUtils.isNotEmpty(existingZoneName)) {
+					if (!StringUtils.equals(existingZoneName, zoneName)) {
+						ValidationErrorCode error = ValidationErrorCode.POLICY_VALIDATION_ERR_UPDATE_ZONE_NAME_NOT_ALLOWED;
+						failures.add(new ValidationFailureDetailsBuilder()
+								.field("zoneName")
+								.isSemanticallyIncorrect()
+								.becauseOf(error.getMessage(existingZoneName, zoneName))
+								.errorCode(error.getErrorCode())
+								.build());
+						valid = false;
+					}
+				}
 			}
 
 			boolean          isAuditEnabled   = getIsAuditEnabled(policy);
@@ -307,6 +353,17 @@ public class RangerPolicyValidator extends RangerValidator {
 						.build());
 					valid = false;
 				} else {
+					if (Boolean.TRUE.equals(policy.getIsDenyAllElse())) {
+						if (CollectionUtils.isNotEmpty(policy.getDenyPolicyItems()) || CollectionUtils.isNotEmpty(policy.getDenyExceptions())) {
+							ValidationErrorCode error = ValidationErrorCode.POLICY_VALIDATION_ERR_UNSUPPORTED_POLICY_ITEM_TYPE;
+							failures.add(new ValidationFailureDetailsBuilder()
+									.field("policy items")
+									.becauseOf(error.getMessage())
+									.errorCode(error.getErrorCode())
+									.build());
+							valid = false;
+						}
+					}
 					valid = isValidPolicyItems(policy.getPolicyItems(), failures, serviceDef) && valid;
 					valid = isValidPolicyItems(policy.getDenyPolicyItems(), failures, serviceDef) && valid;
 					valid = isValidPolicyItems(policy.getAllowExceptions(), failures, serviceDef) && valid;
@@ -500,7 +557,8 @@ public class RangerPolicyValidator extends RangerValidator {
 		}
 
 		boolean valid = true;
-		Set<String> policyResources = getPolicyResources(policy);
+		convertPolicyResourceNamesToLower(policy);
+		Set<String> policyResources = policy.getResources().keySet();
 
 		RangerServiceDefHelper defHelper = new RangerServiceDefHelper(serviceDef);
 		Set<List<RangerResourceDef>> hierarchies = defHelper.getResourceHierarchies(policy.getPolicyType()); // this can be empty but not null!
@@ -863,10 +921,10 @@ public class RangerPolicyValidator extends RangerValidator {
 				valid = isValidItemAccesses(policyItem.getAccesses(), failures, serviceDef) && valid;
 			}
 			// both users and user-groups collections can't be empty
-			if (CollectionUtils.isEmpty(policyItem.getUsers()) && CollectionUtils.isEmpty(policyItem.getGroups())) {
+			if (CollectionUtils.isEmpty(policyItem.getUsers()) && CollectionUtils.isEmpty(policyItem.getGroups()) && CollectionUtils.isEmpty(policyItem.getRoles())) {
 				ValidationErrorCode error = ValidationErrorCode.POLICY_VALIDATION_ERR_MISSING_USER_AND_GROUPS;
 				failures.add(new ValidationFailureDetailsBuilder()
-					.field("policy item users/user-groups")
+					.field("policy item users/user-groups/roles")
 					.isMissing()
 					.becauseOf(error.getMessage())
 					.errorCode(error.getErrorCode())
@@ -935,15 +993,20 @@ public class RangerPolicyValidator extends RangerValidator {
 					.errorCode(error.getErrorCode())
 					.build());
 				valid = false;
-			} else if (!accessTypes.contains(accessType.toLowerCase())) {
-				ValidationErrorCode error = ValidationErrorCode.POLICY_VALIDATION_ERR_POLICY_ITEM_ACCESS_TYPE_INVALID;
-				failures.add(new ValidationFailureDetailsBuilder()
-					.field("policy item access type")
-					.isSemanticallyIncorrect()
-					.becauseOf(error.getMessage(accessType, accessTypes))
-					.errorCode(error.getErrorCode())
-					.build());
-				valid = false;
+			} else {
+				String matchedAccessType = getMatchedAccessType(accessType, accessTypes);
+				if (StringUtils.isEmpty(matchedAccessType)) {
+					ValidationErrorCode error = ValidationErrorCode.POLICY_VALIDATION_ERR_POLICY_ITEM_ACCESS_TYPE_INVALID;
+					failures.add(new ValidationFailureDetailsBuilder()
+							.field("policy item access type")
+							.isSemanticallyIncorrect()
+							.becauseOf(error.getMessage(accessType, accessTypes))
+							.errorCode(error.getErrorCode())
+							.build());
+					valid = false;
+				} else {
+					access.setType(matchedAccessType);
+				}
 			}
 			Boolean isAllowed = access.getIsAllowed();
 			// it can be null (which is treated as allowed) but not false
@@ -964,4 +1027,15 @@ public class RangerPolicyValidator extends RangerValidator {
 		}
 		return valid;
 	}
+
+	String getMatchedAccessType(String accessType, Set<String> validAccessTypes) {
+		String ret = null;
+		for (String validType : validAccessTypes) {
+			if (StringUtils.equalsIgnoreCase(accessType, validType)) {
+				ret = validType;
+				break;
+			}
+		}
+		return ret;
+	}
 }
