@@ -183,7 +183,22 @@ public class RangerServiceDefHelper {
 		return _delegate.getResourceHierarchies(policyType);
 	}
 
+	public Set<List<RangerResourceDef>> filterHierarchies_containsOnlyMandatoryResources(Integer policyType) {
+		Set<List<RangerResourceDef>> hierarchies = getResourceHierarchies(policyType);
+		Set<List<RangerResourceDef>> result = new HashSet<List<RangerResourceDef>>(hierarchies.size());
+		for (List<RangerResourceDef> aHierarchy : hierarchies) {
+			Set<String> mandatoryResources = getMandatoryResourceNames(aHierarchy);
+			if (aHierarchy.size() == mandatoryResources.size()) {
+				result.add(aHierarchy);
+			}
+		}
+		return result;
+	}
+
 	public Set<List<RangerResourceDef>> getResourceHierarchies(Integer policyType, Collection<String> keys) {
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("==> getResourceHierarchies(policyType=" + policyType + ", keys=" + StringUtils.join(keys, ",") + ")");
+		}
 
 		Set<List<RangerResourceDef>> ret = new HashSet<List<RangerResourceDef>>();
 
@@ -193,10 +208,16 @@ public class RangerServiceDefHelper {
 			}
 		}
 
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("<== getResourceHierarchies(policyType=" + policyType + ", keys=" + StringUtils.join(keys, ",") + ") : " + StringUtils.join(ret, ","));
+		}
 		return ret;
 	}
 
 	public boolean hierarchyHasAllResources(List<RangerResourceDef> hierarchy, Collection<String> resourceNames) {
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("==> hierarchyHasAllResources(hierarchy=" + StringUtils.join(hierarchy, ",") + ", resourceNames=" + StringUtils.join(resourceNames, ",") + ")");
+		}
 		boolean foundAllResourceKeys = true;
 
 		for (String resourceKey : resourceNames) {
@@ -214,7 +235,9 @@ public class RangerServiceDefHelper {
 				break;
 			}
 		}
-
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("<== hierarchyHasAllResources(hierarchy=" + StringUtils.join(hierarchy, ",") + ", resourceNames=" + StringUtils.join(resourceNames, ",") + "): " + foundAllResourceKeys);
+		}
 		return foundAllResourceKeys;
 	}
 
