@@ -36,6 +36,7 @@ import org.apache.commons.logging.LogFactory;
 import org.apache.ranger.plugin.errors.ValidationErrorCode;
 import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyResource;
+import org.apache.ranger.plugin.model.RangerSecurityZone;
 import org.apache.ranger.plugin.model.RangerService;
 import org.apache.ranger.plugin.model.RangerServiceDef;
 import org.apache.ranger.plugin.model.RangerServiceDef.RangerAccessTypeDef;
@@ -80,6 +81,22 @@ public abstract class RangerValidator {
 			throw new Exception(message);
 		}
 	}
+    public void validate(String name, Action action) throws Exception {
+        if(LOG.isDebugEnabled()) {
+            LOG.debug("==> RangerValidator.validate(" + name + ")");
+        }
+
+        List<ValidationFailureDetails> failures = new ArrayList<>();
+        if (isValid(name, action, failures)) {
+            if(LOG.isDebugEnabled()) {
+                LOG.debug("<== RangerValidator.validate(" + name + "): valid");
+            }
+        } else {
+            String message = serializeFailures(failures);
+            LOG.debug("<== RangerValidator.validate(" + name + "): invalid, reason[" + message + "]");
+            throw new Exception(message);
+        }
+    }
 	
 	/**
 	 * This method is expected to be overridden by sub-classes.  Default implementation provided to not burden implementers from having to implement methods that they know would never be called.
@@ -96,6 +113,14 @@ public abstract class RangerValidator {
 		return false;
 	}
 
+    boolean isValid(String name, Action action, List<ValidationFailureDetails> failures) {
+        failures.add(new ValidationFailureDetailsBuilder()
+                .isAnInternalError()
+                .becauseOf("unimplemented method called")
+                .build());
+        return false;
+    }
+
 	public static String serializeFailures(List<ValidationFailureDetails> failures) {
 		if(LOG.isDebugEnabled()) {
 			LOG.debug("==> RangerValidator.getFailureMessage()");
@@ -246,21 +271,15 @@ public abstract class RangerValidator {
 		return result;
 	}
 
-	Long getPolicyId(final Long serviceId, final String policyName) {
+	Long getPolicyId(final Long serviceId, final String policyName, final Long zoneId) {
 		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerValidator.getPolicyId(" + serviceId + ", " + policyName + ")");
+			LOG.debug("==> RangerValidator.getPolicyId(" + serviceId + ", " + policyName + ", " + zoneId + ")");
 		}
 
-		Long policyId = null;
-		try {
-			policyId = _store.getPolicyId(serviceId, policyName);
-
-		} catch (Exception e) {
-			LOG.debug("Encountred exception while retrieving service from service store!", e);
-		}
+		Long policyId = _store.getPolicyId(serviceId, policyName, zoneId);
 
 		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerValidator.getPolicyId(" + serviceId + ", " + policyName + "): policy-id[" + policyId + "]");
+			LOG.debug("<== RangerValidator.getPolicyId(" + serviceId + ", " + policyName + ", " + zoneId + "): policy-id[" + policyId + "]");
 		}
 		return policyId;
 	}
@@ -284,6 +303,45 @@ public abstract class RangerValidator {
 		return policies;
 	}
 
+    RangerSecurityZone getSecurityZone(Long id) {
+        if(LOG.isDebugEnabled()) {
+            LOG.debug("==> RangerValidator.getSecurityZone(" + id + ")");
+        }
+        RangerSecurityZone result = null;
+
+        if (id != null) {
+            try {
+                result = _store.getSecurityZone(id);
+            } catch (Exception e) {
+                LOG.debug("Encountred exception while retrieving security zone from service store!", e);
+            }
+        }
+
+        if(LOG.isDebugEnabled()) {
+            LOG.debug("<== RangerValidator.getSecurityZone(" + id + "): " + result);
+        }
+        return result;
+    }
+
+	RangerSecurityZone getSecurityZone(String name) {
+        if(LOG.isDebugEnabled()) {
+            LOG.debug("==> RangerValidator.getSecurityZone(" + name + ")");
+        }
+        RangerSecurityZone result = null;
+
+        if (StringUtils.isNotEmpty(name)) {
+            try {
+                result = _store.getSecurityZone(name);
+            } catch (Exception e) {
+                LOG.debug("Encountred exception while retrieving security zone from service store!", e);
+            }
+        }
+
+        if(LOG.isDebugEnabled()) {
+            LOG.debug("<== RangerValidator.getSecurityZone(" + name + "): " + result);
+        }
+        return result;
+    }
 	Set<String> getAccessTypes(RangerServiceDef serviceDef) {
 		if(LOG.isDebugEnabled()) {
 			LOG.debug("==> RangerValidator.getAccessTypes(" + serviceDef + ")");
@@ -303,7 +361,7 @@ public abstract class RangerValidator {
 					if (StringUtils.isBlank(accessType)) {
 						LOG.warn("Access type def name was null/empty/blank!");
 					} else {
-						accessTypes.add(accessType.toLowerCase());
+						accessTypes.add(accessType);
 					}
 				}
 			}
@@ -409,22 +467,22 @@ public abstract class RangerValidator {
 		}
 		return resourceNames;
 	}
-	
+
 	/**
-	 * Returns the resource-types defined on the policy converted to lowe-case
+	 * Converts, in place, the resources defined in the policy to have lower-case resource-def-names
 	 * @param policy
 	 * @return
 	 */
-	Set<String> getPolicyResources(RangerPolicy policy) {
-		if (policy == null || policy.getResources() == null || policy.getResources().isEmpty()) {
-			return new HashSet<>();
-		} else {
-			Set<String> result = new HashSet<>();
-			for (String name : policy.getResources().keySet()) {
-				result.add(name.toLowerCase());
+
+	void convertPolicyResourceNamesToLower(RangerPolicy policy) {
+		Map<String, RangerPolicyResource> lowerCasePolicyResources = new HashMap<>();
+		if (policy.getResources() != null) {
+			for (Map.Entry<String, RangerPolicyResource> entry : policy.getResources().entrySet()) {
+				String lowerCasekey = entry.getKey().toLowerCase();
+				lowerCasePolicyResources.put(lowerCasekey, entry.getValue());
 			}
-			return result;
 		}
+		policy.setResources(lowerCasePolicyResources);
 	}
 
 	Map<String, String> getValidationRegExes(RangerServiceDef serviceDef) {
@@ -582,6 +640,10 @@ public abstract class RangerValidator {
 		return valid;
 	}
 
+	/*
+	 * Important: Resource-names are required to be lowercase. This is used in validating policy create/update operations.
+	 * Ref: RANGER-2272
+	 */
 	boolean isValidResourceName(final String value, final String valueContext, final List<ValidationFailureDetails> failures) {
 		boolean ret = true;
 
