@@ -27,7 +27,9 @@ import java.util.Set;
 import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerServiceDef;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyResource;
+import org.apache.ranger.plugin.util.GrantRevokeRequest;
 import org.apache.ranger.plugin.util.RangerAccessRequestUtil;
+import org.apache.ranger.plugin.util.ServicePolicies;
 
 public interface RangerPolicyEngine {
 	String GROUP_PUBLIC   = "public";
@@ -63,6 +65,8 @@ public interface RangerPolicyEngine {
 
 	RangerResourceACLs getResourceACLs(RangerAccessRequest request);
 
+	String getMatchedZoneName(GrantRevokeRequest grantRevokeRequest);
+
 	boolean preCleanup();
 
 	void cleanup();
@@ -75,9 +79,11 @@ public interface RangerPolicyEngine {
 
 	boolean isAccessAllowed(RangerPolicy policy, String user, Set<String> userGroups, String accessType);
 
+	boolean isAccessAllowed(RangerPolicy policy, String user, Set<String> userGroups, Set<String> roles, String accessType);
+
 	List<RangerPolicy> getExactMatchPolicies(RangerAccessResource resource, Map<String, Object> evalContext);
 
-	List<RangerPolicy> getExactMatchPolicies(Map<String, RangerPolicyResource> resources, Map<String, Object> evalContext);
+	List<RangerPolicy> getExactMatchPolicies(RangerPolicy policy, Map<String, Object> evalContext);
 
 	List<RangerPolicy> getMatchingPolicies(RangerAccessResource resource);
 
@@ -87,4 +93,8 @@ public interface RangerPolicyEngine {
 
 	List<RangerPolicy> getAllowedPolicies(String user, Set<String> userGroups, String accessType);
 
+	RangerPolicyEngine cloneWithDelta(ServicePolicies servicePolicies);
+
+	Set<String> getRolesFromUserAndGroups(String user, Set<String> groups);
+
 }
