@@ -581,7 +581,9 @@ public class RangerDefaultPolicyResourceMatcher implements RangerPolicyResourceM
                         }
                     }
 
-                    int lastMatchedMatcherIndex = -1;
+                    if (resourceKeysSize == 0) {
+                        ret = MatchType.SELF;
+                    }
 
                     for (RangerResourceDef resourceDef : hierarchy) {
 
@@ -589,26 +591,13 @@ public class RangerDefaultPolicyResourceMatcher implements RangerPolicyResourceM
                         Object resourceValue = resource.getValue(resourceDef.getName());
 
                         if (matcher != null) {
-                            if (resourceValue != null) {
+                            if (resourceValue != null || matcher.isMatchAny()) {
                                 if (matcher.isMatch(resourceValue, evalContext)) {
                                     ret = MatchType.SELF;
-                                    lastMatchedMatcherIndex++;
                                 } else {
                                     ret = MatchType.NONE;
                                     break;
                                 }
-                            } else {
-                                // More matchers than resource-values
-                                ret = MatchType.DESCENDANT;
-
-                                if (lastMatchedMatcherIndex >= lastNonAnyMatcherIndex) {
-                                    ret = MatchType.ANCESTOR;
-                                    if (lastMatchedMatcherIndex == lastNonAnyMatcherIndex && lastMatchedMatcherIndex == -1) {
-                                        // For degenerate case : resourceKeysSize == 0 and all matchers are of type Any
-                                        ret = MatchType.SELF;
-                                    }
-                                }
-                                break;
                             }
                         } else {
                             if (resourceValue != null) {
@@ -618,6 +607,16 @@ public class RangerDefaultPolicyResourceMatcher implements RangerPolicyResourceM
                             break;
                         }
                     }
+
+                    if (ret == MatchType.SELF && resourceKeysSize < policyResources.size()) {
+                        // More matchers than resource-values
+                        if (resourceKeysSize > lastNonAnyMatcherIndex) {
+                            // all remaining matchers which matched resource value of null are of type Any
+                            ret = MatchType.ANCESTOR_WITH_WILDCARDS;
+                        } else {
+                            ret = MatchType.DESCENDANT;
+                        }
+                    }
                 }
             }
         }
@@ -631,7 +630,10 @@ public class RangerDefaultPolicyResourceMatcher implements RangerPolicyResourceM
         return ret;
     }
 
-    private static boolean isHierarchyValidForResources(List<RangerResourceDef> hierarchy, Map<String, ?> resources) {
+    public static boolean isHierarchyValidForResources(List<RangerResourceDef> hierarchy, Map<String, ?> resources) {
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("==> isHierarchyValidForResources(" + StringUtils.join(hierarchy, ",") + ")");
+        }
         boolean ret = true;
 
         if (hierarchy != null) {
@@ -655,7 +657,9 @@ public class RangerDefaultPolicyResourceMatcher implements RangerPolicyResourceM
         } else {
             ret = false;
          }
-
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("<== isHierarchyValidForResources(" + StringUtils.join(hierarchy, ",") + ") : " + ret);
+        }
         return ret;
     }
 
