@@ -19,14 +19,12 @@
 
 package org.apache.ranger.plugin.service;
 
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.Hashtable;
-import java.util.Map;
-import java.util.Timer;
-import java.util.TimerTask;
+import java.util.*;
+import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.ConcurrentHashMap;
-
+import java.util.concurrent.LinkedBlockingQueue;
+import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.collections.MapUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -37,21 +35,23 @@ import org.apache.ranger.audit.provider.AuditProviderFactory;
 import org.apache.ranger.audit.provider.StandAloneAuditProviderFactory;
 import org.apache.ranger.authorization.hadoop.config.RangerConfiguration;
 import org.apache.ranger.authorization.utils.StringUtil;
+import org.apache.ranger.plugin.contextenricher.RangerContextEnricher;
+import org.apache.ranger.plugin.contextenricher.RangerTagEnricher;
 import org.apache.ranger.plugin.model.RangerPolicy;
+import org.apache.ranger.plugin.model.RangerRole;
 import org.apache.ranger.plugin.model.RangerServiceDef;
 import org.apache.ranger.plugin.policyengine.RangerAccessRequest;
 import org.apache.ranger.plugin.policyengine.RangerAccessRequestImpl;
 import org.apache.ranger.plugin.policyengine.RangerAccessResourceImpl;
 import org.apache.ranger.plugin.policyengine.RangerAccessResult;
 import org.apache.ranger.plugin.policyengine.RangerAccessResultProcessor;
+import org.apache.ranger.plugin.policyengine.RangerPluginContext;
 import org.apache.ranger.plugin.policyengine.RangerPolicyEngine;
 import org.apache.ranger.plugin.policyengine.RangerPolicyEngineImpl;
 import org.apache.ranger.plugin.policyengine.RangerPolicyEngineOptions;
 import org.apache.ranger.plugin.policyengine.RangerResourceAccessInfo;
 import org.apache.ranger.plugin.store.EmbeddedServiceDefsUtil;
-import org.apache.ranger.plugin.util.GrantRevokeRequest;
-import org.apache.ranger.plugin.util.PolicyRefresher;
-import org.apache.ranger.plugin.util.ServicePolicies;
+import org.apache.ranger.plugin.util.*;
 
 
 public class RangerBasePlugin {
@@ -68,18 +68,23 @@ public class RangerBasePlugin {
 	private PolicyRefresher           refresher;
 	private RangerPolicyEngine        policyEngine;
 	private RangerPolicyEngineOptions policyEngineOptions = new RangerPolicyEngineOptions();
+	private RangerPluginContext       rangerPluginContext;
 	private RangerAuthContext         currentAuthContext;
 	private RangerAuthContext         readOnlyAuthContext;
 	private RangerAccessResultProcessor resultProcessor;
 	private boolean                   useForwardedIPAddress;
 	private String[]                  trustedProxyAddresses;
+	private Timer                     policyDownloadTimer;
 	private Timer                     policyEngineRefreshTimer;
 	private RangerAuthContextListener authContextListener;
 	private AuditProviderFactory      auditProviderFactory;
 
+	private final BlockingQueue<DownloadTrigger> policyDownloadQueue = new LinkedBlockingQueue<>();
+	private final DownloadTrigger                accessTrigger       = new DownloadTrigger();
+
 
 	Map<String, LogHistory> logHistoryList = new Hashtable<String, RangerBasePlugin.LogHistory>();
-	int logInterval = 30000; // 30 seconds
+	int                     logInterval    = 30000; // 30 seconds
 
 	public static Map<String, RangerBasePlugin> getServicePluginMap() {
 		return servicePluginMap;
@@ -179,8 +184,10 @@ public class RangerBasePlugin {
 		long   pollingIntervalMs = configuration.getLong(propertyPrefix + ".policy.pollIntervalMs", 30 * 1000);
 		String cacheDir          = configuration.get(propertyPrefix + ".policy.cache.dir");
 		serviceName = configuration.get(propertyPrefix + ".service.name");
-		clusterName = RangerConfiguration.getInstance().get(propertyPrefix + ".ambari.cluster.name", "");
-
+		clusterName = RangerConfiguration.getInstance().get(propertyPrefix + ".access.cluster.name", "");
+		if(StringUtil.isEmpty(clusterName)){
+			clusterName = RangerConfiguration.getInstance().get(propertyPrefix + ".ambari.cluster.name", "");
+		}
 		useForwardedIPAddress = configuration.getBoolean(propertyPrefix + ".use.x-forwarded-for.ipaddress", false);
 		String trustedProxyAddressString = configuration.get(propertyPrefix + ".trusted.proxy.ipaddresses");
 		trustedProxyAddresses = StringUtils.split(trustedProxyAddressString, RANGER_TRUSTED_PROXY_IPADDRESSES_SEPARATOR_CHAR);
@@ -217,10 +224,23 @@ public class RangerBasePlugin {
 
 		RangerAdminClient admin = createAdminClient(serviceName, appId, propertyPrefix);
 
-		refresher = new PolicyRefresher(this, serviceType, appId, serviceName, admin, pollingIntervalMs, cacheDir);
+		refresher = new PolicyRefresher(this, serviceType, appId, serviceName, admin, policyDownloadQueue, cacheDir);
 		refresher.setDaemon(true);
 		refresher.startRefresher();
 
+		policyDownloadTimer = new Timer("policyDownloadTimer", true);
+
+		try {
+			policyDownloadTimer.schedule(new DownloaderTask(policyDownloadQueue), pollingIntervalMs, pollingIntervalMs);
+			if (LOG.isDebugEnabled()) {
+				LOG.debug("Scheduled policyDownloadRefresher to download policies every " + pollingIntervalMs + " milliseconds");
+			}
+		} catch (IllegalStateException exception) {
+			LOG.error("Error scheduling policyDownloadTimer:", exception);
+			LOG.error("*** Policies will NOT be downloaded every " + pollingIntervalMs + " milliseconds ***");
+			policyDownloadTimer = null;
+		}
+
 		long policyReorderIntervalMs = configuration.getLong(propertyPrefix + ".policy.policyReorderInterval", 60 * 1000);
 		if (policyReorderIntervalMs >= 0 && policyReorderIntervalMs < 15 * 1000) {
 			policyReorderIntervalMs = 15 * 1000;
@@ -248,34 +268,111 @@ public class RangerBasePlugin {
 	}
 
 	public void setPolicies(ServicePolicies policies) {
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("==> setPolicies(" + policies + ")");
+		}
 
 		// guard against catastrophic failure during policy engine Initialization or
 		try {
 			RangerPolicyEngine oldPolicyEngine = this.policyEngine;
+			ServicePolicies    servicePolicies = null;
+			boolean            isValid         = true;
+			boolean            usePolicyDeltas = false;
 
 			if (policies == null) {
 				policies = getDefaultSvcPolicies();
-			}
-			if (policies == null) {
-				this.policyEngine = null;
-				readOnlyAuthContext = null;
+				if (policies == null) {
+					LOG.error("Could not get default Service Policies");
+					isValid = false;
+				}
 			} else {
-				currentAuthContext = new RangerAuthContext();
-				RangerPolicyEngine policyEngine = new RangerPolicyEngineImpl(appId, policies, policyEngineOptions);
-				policyEngine.setUseForwardedIPAddress(useForwardedIPAddress);
-				policyEngine.setTrustedProxyAddresses(trustedProxyAddresses);
-				this.policyEngine = policyEngine;
-				currentAuthContext.setPolicyEngine(this.policyEngine);
-				readOnlyAuthContext = new RangerAuthContext(currentAuthContext);
+				if ((policies.getPolicies() == null && policies.getPolicyDeltas() == null) || (policies.getPolicies() != null && policies.getPolicyDeltas() != null)) {
+					LOG.error("Invalid servicePolicies: Both policies and policy-deltas cannot be null OR both of them cannot be non-null");
+					isValid = false;
+				} else if (policies.getPolicies() != null) {
+					usePolicyDeltas = false;
+				} else if (policies.getPolicyDeltas() != null) {
+					// Rebuild policies from deltas
+					RangerPolicyEngineImpl policyEngine = (RangerPolicyEngineImpl) oldPolicyEngine;
+					servicePolicies = ServicePolicies.applyDelta(policies, policyEngine);
+					if (servicePolicies != null) {
+						usePolicyDeltas = true;
+					} else {
+						isValid = false;
+						LOG.error("Could not apply deltas=" + Arrays.toString(policies.getPolicyDeltas().toArray()));
+					}
+				} else {
+					LOG.error("Should not get here!!");
+					isValid = false;
+				}
 			}
-			contextChanged();
 
-			if (oldPolicyEngine != null && !oldPolicyEngine.preCleanup()) {
-				LOG.error("preCleanup() failed on the previous policy engine instance !!");
+			if (isValid) {
+				RangerPolicyEngine newPolicyEngine = null;
+
+				if (!usePolicyDeltas) {
+					if (LOG.isDebugEnabled()) {
+						LOG.debug("policies are not null. Creating engine from policies");
+					}
+					rangerPluginContext = new RangerPluginContext(serviceType);
+					currentAuthContext = new RangerAuthContext(rangerPluginContext);
+					newPolicyEngine = new RangerPolicyEngineImpl(appId, policies, policyEngineOptions, rangerPluginContext);
+				} else {
+					if (LOG.isDebugEnabled()) {
+						LOG.debug("policy-deltas are not null");
+					}
+					if (CollectionUtils.isNotEmpty(policies.getPolicyDeltas())) {
+						if (LOG.isDebugEnabled()) {
+							LOG.debug("Non empty policy-deltas found. Cloning engine using policy-deltas");
+						}
+						newPolicyEngine = oldPolicyEngine.cloneWithDelta(policies);
+						if (newPolicyEngine != null) {
+							if (LOG.isDebugEnabled()) {
+								LOG.debug("Applied policyDeltas=" + Arrays.toString(policies.getPolicyDeltas().toArray()) + ")");
+							}
+						} else {
+							if (LOG.isDebugEnabled()) {
+								LOG.debug("Failed to apply policyDeltas=" + Arrays.toString(policies.getPolicyDeltas().toArray()) + "), Creating engine from policies");
+								LOG.debug("Creating new engine from servicePolicies:[" + servicePolicies + "]");
+							}
+							rangerPluginContext = new RangerPluginContext(serviceType);
+							currentAuthContext = new RangerAuthContext(rangerPluginContext);
+							newPolicyEngine = new RangerPolicyEngineImpl(appId, servicePolicies, policyEngineOptions, rangerPluginContext);
+						}
+					} else {
+						if (LOG.isDebugEnabled()) {
+							LOG.debug("Empty policy-deltas. No need to change policy engine");
+						}
+					}
+				}
+
+				if (newPolicyEngine != null) {
+
+					newPolicyEngine.setUseForwardedIPAddress(useForwardedIPAddress);
+					newPolicyEngine.setTrustedProxyAddresses(trustedProxyAddresses);
+					this.policyEngine = newPolicyEngine;
+					currentAuthContext.setPolicyEngine(this.policyEngine);
+					readOnlyAuthContext = new RangerAuthContext(currentAuthContext);
+
+					contextChanged();
+
+					if (oldPolicyEngine != null && !oldPolicyEngine.preCleanup()) {
+						LOG.error("preCleanup() failed on the previous policy engine instance !!");
+					}
+					if (this.refresher != null) {
+						this.refresher.saveToCache(usePolicyDeltas ? servicePolicies : policies);
+					}
+				}
+			} else {
+				LOG.error("Returning without saving policies to cache. Leaving current policy engine as-is");
 			}
+
 		} catch (Exception e) {
 			LOG.error("setPolicies: policy engine initialization failed!  Leaving current policy engine as-is. Exception : ", e);
 		}
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("<== setPolicies(" + policies + ")");
+		}
 	}
 
 	public void contextChanged() {
@@ -294,17 +391,24 @@ public class RangerBasePlugin {
 
 		Timer policyEngineRefreshTimer = this.policyEngineRefreshTimer;
 
+		Timer policyDownloadTimer = this.policyDownloadTimer;
+
 		String serviceName = this.serviceName;
 
 		this.serviceName  = null;
 		this.policyEngine = null;
 		this.refresher    = null;
 		this.policyEngineRefreshTimer = null;
+		this.policyDownloadTimer = null;
 
 		if (refresher != null) {
 			refresher.stopRefresher();
 		}
 
+		if (policyDownloadTimer != null) {
+			policyDownloadTimer.cancel();
+		}
+
 		if (policyEngineRefreshTimer != null) {
 			policyEngineRefreshTimer.cancel();
 		}
@@ -394,21 +498,100 @@ public class RangerBasePlugin {
 		return null;
 	}
 
+	public RangerRole createRole(RangerRole request, RangerAccessResultProcessor resultProcessor) throws Exception {
+		if(LOG.isDebugEnabled()) {
+			LOG.debug("==> RangerBasePlugin.createRole(" + request + ")");
+		}
+
+		RangerRole ret = getAdminClient().createRole(request);
+
+		if(LOG.isDebugEnabled()) {
+			LOG.debug("<== RangerBasePlugin.createRole(" + request + ")");
+		}
+		return ret;
+	}
+
+	public void dropRole(String execUser, String roleName, RangerAccessResultProcessor resultProcessor) throws Exception {
+		if(LOG.isDebugEnabled()) {
+			LOG.debug("==> RangerBasePlugin.dropRole(" + roleName + ")");
+		}
+		getAdminClient().dropRole(execUser, roleName);
+
+		if(LOG.isDebugEnabled()) {
+			LOG.debug("<== RangerBasePlugin.dropRole(" + roleName + ")");
+		}
+	}
+
+	public List<String> getUserRoles(String execUser, RangerAccessResultProcessor resultProcessor) throws Exception {
+		if(LOG.isDebugEnabled()) {
+			LOG.debug("==> RangerBasePlugin.getUserRoleNames(" + execUser + ")");
+		}
+		final List<String> ret = getAdminClient().getUserRoles(execUser);
+
+		if(LOG.isDebugEnabled()) {
+			LOG.debug("<== RangerBasePlugin.getUserRoleNames(" + execUser + ")");
+		}
+		return ret;
+	}
+
+	public List<String> getAllRoles(String execUser, RangerAccessResultProcessor resultProcessor) throws Exception {
+		if(LOG.isDebugEnabled()) {
+			LOG.debug("==> RangerBasePlugin.getAllRoles()");
+		}
+		final List<String> ret = getAdminClient().getAllRoles(execUser);
+
+		if(LOG.isDebugEnabled()) {
+			LOG.debug("<== RangerBasePlugin.getAllRoles()");
+		}
+		return ret;
+	}
+
+	public RangerRole getRole(String execUser, String roleName, RangerAccessResultProcessor resultProcessor) throws Exception {
+		if(LOG.isDebugEnabled()) {
+			LOG.debug("==> RangerBasePlugin.getPrincipalsForRole(" + roleName + ")");
+		}
+		final RangerRole ret = getAdminClient().getRole(execUser, roleName);
+
+		if(LOG.isDebugEnabled()) {
+			LOG.debug("<== RangerBasePlugin.getPrincipalsForRole(" + roleName + ")");
+		}
+		return ret;
+	}
+
+	public void grantRole(GrantRevokeRoleRequest request, RangerAccessResultProcessor resultProcessor) throws Exception {
+		if(LOG.isDebugEnabled()) {
+			LOG.debug("==> RangerBasePlugin.grantRole(" + request + ")");
+		}
+		getAdminClient().grantRole(request);
+
+		if(LOG.isDebugEnabled()) {
+			LOG.debug("<== RangerBasePlugin.grantRole(" + request + ")");
+		}
+	}
+
+	public void revokeRole(GrantRevokeRoleRequest request, RangerAccessResultProcessor resultProcessor) throws Exception {
+		if(LOG.isDebugEnabled()) {
+			LOG.debug("==> RangerBasePlugin.revokeRole(" + request + ")");
+		}
+		getAdminClient().revokeRole(request);
+
+		if(LOG.isDebugEnabled()) {
+			LOG.debug("<== RangerBasePlugin.revokeRole(" + request + ")");
+		}
+	}
+
 	public void grantAccess(GrantRevokeRequest request, RangerAccessResultProcessor resultProcessor) throws Exception {
 		if(LOG.isDebugEnabled()) {
 			LOG.debug("==> RangerBasePlugin.grantAccess(" + request + ")");
 		}
-
-		PolicyRefresher   refresher = this.refresher;
-		RangerAdminClient admin     = refresher == null ? null : refresher.getRangerAdminClient();
 		boolean           isSuccess = false;
 
 		try {
-			if(admin == null) {
-				throw new Exception("ranger-admin client is null");
+			if (policyEngine != null) {
+				request.setZoneName(policyEngine.getMatchedZoneName(request));
 			}
 
-			admin.grantAccess(request);
+			getAdminClient().grantAccess(request);
 
 			isSuccess = true;
 		} finally {
@@ -424,17 +607,14 @@ public class RangerBasePlugin {
 		if(LOG.isDebugEnabled()) {
 			LOG.debug("==> RangerBasePlugin.revokeAccess(" + request + ")");
 		}
-
-		PolicyRefresher   refresher = this.refresher;
-		RangerAdminClient admin     = refresher == null ? null : refresher.getRangerAdminClient();
 		boolean           isSuccess = false;
 
 		try {
-			if(admin == null) {
-				throw new Exception("ranger-admin client is null");
+			if (policyEngine != null) {
+				request.setZoneName(policyEngine.getMatchedZoneName(request));
 			}
 
-			admin.revokeAccess(request);
+			getAdminClient().revokeAccess(request);
 
 			isSuccess = true;
 		} finally {
@@ -449,6 +629,7 @@ public class RangerBasePlugin {
 	public void registerAuthContextEventListener(RangerAuthContextListener authContextListener) {
 		this.authContextListener = authContextListener;
 	}
+
 	public void unregisterAuthContextEventListener(RangerAuthContextListener authContextListener) {
 		this.authContextListener = null;
 	}
@@ -493,6 +674,31 @@ public class RangerBasePlugin {
 		return ret;
 	}
 
+	public void refreshPoliciesAndTags() {
+		if (LOG.isDebugEnabled()) {
+			LOG.debug("==> refreshPoliciesAndTags()");
+		}
+		try {
+			// Synch-up policies
+			long oldPolicyVersion = this.policyEngine.getPolicyVersion();
+			syncPoliciesWithAdmin(accessTrigger);
+			long newPolicyVersion = this.policyEngine.getPolicyVersion();
+
+			if (oldPolicyVersion == newPolicyVersion) {
+				// Synch-up tags
+				RangerTagEnricher tagEnricher = getTagEnricher();
+				if (tagEnricher != null) {
+					tagEnricher.syncTagsWithAdmin(accessTrigger);
+				}
+			}
+		} catch (InterruptedException exception) {
+			LOG.error("Failed to update policy-engine, continuing to use old policy-engine and/or tags", exception);
+		}
+		if (LOG.isDebugEnabled()) {
+			LOG.info("<== refreshPoliciesAndTags()");
+		}
+	}
+
 	private void auditGrantRevoke(GrantRevokeRequest request, String action, boolean isSuccess, RangerAccessResultProcessor resultProcessor) {
 		if(request != null && resultProcessor != null) {
 			RangerAccessRequestImpl accessRequest = new RangerAccessRequestImpl();
@@ -505,7 +711,6 @@ public class RangerBasePlugin {
 			accessRequest.setClientType(request.getClientType());
 			accessRequest.setRequestData(request.getRequestData());
 			accessRequest.setSessionId(request.getSessionId());
-			accessRequest.setClusterName(request.getClusterName());
 
 			// call isAccessAllowed() to determine if audit is enabled or not
 			RangerAccessResult accessResult = isAccessAllowed(accessRequest, null);
@@ -523,7 +728,7 @@ public class RangerBasePlugin {
 		}
 	}
 
-	public RangerServiceDef getDefaultServiceDef() {
+	private RangerServiceDef getDefaultServiceDef() {
 		RangerServiceDef ret = null;
 
 		if (StringUtils.isNotBlank(serviceType)) {
@@ -573,7 +778,7 @@ public class RangerBasePlugin {
 		return false;
 	}
 
-	static class LogHistory {
+	static private final class LogHistory {
 		long lastLogTime;
 		int counter;
 	}
@@ -593,4 +798,39 @@ public class RangerBasePlugin {
 			}
 		}
 	}
+
+	private void syncPoliciesWithAdmin(final DownloadTrigger token) throws InterruptedException{
+		policyDownloadQueue.put(token);
+		token.waitForCompletion();
+	}
+
+	private RangerTagEnricher getTagEnricher() {
+		RangerTagEnricher ret = null;
+		RangerAuthContext authContext = getCurrentRangerAuthContext();
+		if (authContext != null) {
+			Map<RangerContextEnricher, Object> contextEnricherMap = authContext.getRequestContextEnrichers();
+			if (MapUtils.isNotEmpty(contextEnricherMap)) {
+				Set<RangerContextEnricher> contextEnrichers = contextEnricherMap.keySet();
+
+				for (RangerContextEnricher enricher : contextEnrichers) {
+					if (enricher instanceof RangerTagEnricher) {
+						ret = (RangerTagEnricher) enricher;
+						break;
+					}
+				}
+			}
+		}
+		return ret;
+	}
+
+	private RangerAdminClient getAdminClient() throws Exception {
+		PolicyRefresher   refresher = this.refresher;
+		RangerAdminClient admin     = refresher == null ? null : refresher.getRangerAdminClient();
+
+		if(admin == null) {
+			throw new Exception("ranger-admin client is null");
+		}
+		return admin;
+	}
+
 }
