@@ -23,6 +23,7 @@ import java.util.List;
 import java.util.Map;
 
 import org.apache.ranger.plugin.model.RangerPolicy;
+import org.apache.ranger.plugin.model.RangerSecurityZone;
 import org.apache.ranger.plugin.model.RangerService;
 import org.apache.ranger.plugin.model.RangerServiceDef;
 import org.apache.ranger.plugin.util.SearchFilter;
@@ -74,7 +75,7 @@ public interface ServiceStore {
 
 	List<RangerPolicy> getPolicies(SearchFilter filter) throws Exception;
 
-	Long getPolicyId(final Long serviceId, final String policyName);
+	Long getPolicyId(final Long serviceId, final String policyName, final Long zoneId);
 
 	PList<RangerPolicy> getPaginatedPolicies(SearchFilter filter) throws Exception;
 
@@ -88,15 +89,21 @@ public interface ServiceStore {
 
 	PList<RangerPolicy> getPaginatedServicePolicies(String serviceName, SearchFilter filter) throws Exception;
 
-	ServicePolicies getServicePoliciesIfUpdated(String serviceName, Long lastKnownVersion) throws Exception;
+	ServicePolicies getServicePoliciesIfUpdated(String serviceName, Long lastKnownVersion, boolean needsBackwardCompatibility) throws Exception;
 
 	Long getServicePolicyVersion(String serviceName);
 
-	ServicePolicies getServicePolicies(String serviceName) throws Exception;
+	ServicePolicies getServicePolicyDeltasOrPolicies(String serviceName, Long lastKnownVersion) throws Exception;
+
+	ServicePolicies getOnlyServicePolicyDeltas(String serviceName, Long lastKnownVersion) throws Exception;
 
 	RangerPolicy getPolicyFromEventTime(String eventTimeStr, Long policyId);
 
 	void setPopulateExistingBaseFields(Boolean populateExistingBaseFields);
 
 	Boolean getPopulateExistingBaseFields();
+
+    RangerSecurityZone getSecurityZone(Long id) throws Exception;
+
+    RangerSecurityZone getSecurityZone(String name) throws Exception;
 }
