@@ -48,6 +48,7 @@ public class GrantRevokeRequest implements Serializable {
 	private Map<String, String> resource;
 	private Set<String>         users;
 	private Set<String>         groups;
+	private Set<String>         roles;
 	private Set<String>         accessTypes;
 	private Boolean             delegateAdmin              = Boolean.FALSE;
 	private Boolean             enableAudit                = Boolean.TRUE;
@@ -58,17 +59,29 @@ public class GrantRevokeRequest implements Serializable {
 	private String              requestData;
 	private String              sessionId;
 	private String              clusterName;
+	private String              zoneName;
 
 	public GrantRevokeRequest() {
-		this(null, null, null, null, null, null, null, null, null, null, null, null, null, null, null);
+		this(null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null);
 	}
 
-	public GrantRevokeRequest(String grantor, Set<String> grantorGroups, Map<String, String> resource, Set<String> users, Set<String> groups, Set<String> accessTypes, Boolean delegateAdmin, Boolean enableAudit, Boolean replaceExistingPermissions, Boolean isRecursive, String clientIPAddress, String clientType, String requestData, String sessionId, String clusterName) {
+	public GrantRevokeRequest(String grantor, Set<String> grantorGroups, Map<String, String> resource, Set<String> users,
+							  Set<String> groups, Set<String> accessTypes, Boolean delegateAdmin, Boolean enableAudit,
+							  Boolean replaceExistingPermissions, Boolean isRecursive, String clientIPAddress,
+							  String clientType, String requestData, String sessionId, String clusterName, String zoneName) {
+		this(grantor, grantorGroups, resource, users, groups, null, accessTypes, delegateAdmin, enableAudit, replaceExistingPermissions, isRecursive, clientIPAddress, clientType, requestData, sessionId, clusterName, zoneName);
+	}
+
+	public GrantRevokeRequest(String grantor, Set<String> grantorGroups, Map<String, String> resource, Set<String> users,
+							  Set<String> groups, Set<String> roles, Set<String> accessTypes, Boolean delegateAdmin, Boolean enableAudit,
+							  Boolean replaceExistingPermissions, Boolean isRecursive, String clientIPAddress,
+							  String clientType, String requestData, String sessionId, String clusterName, String zoneName) {
 		setGrantor(grantor);
 		setGrantorGroups(grantorGroups);
 		setResource(resource);
 		setUsers(users);
 		setGroups(groups);
+		setRoles(roles);
 		setAccessTypes(accessTypes);
 		setDelegateAdmin(delegateAdmin);
 		setEnableAudit(enableAudit);
@@ -79,6 +92,7 @@ public class GrantRevokeRequest implements Serializable {
 		setRequestData(requestData);
 		setSessionId(sessionId);
 		setClusterName(clusterName);
+		setZoneName(zoneName);
 	}
 
 	/**
@@ -150,6 +164,21 @@ public class GrantRevokeRequest implements Serializable {
 		this.groups = groups == null ? new HashSet<String>() : groups;
 	}
 
+	/**
+	 * @return the roles
+	 */
+	public Set<String> getRoles() {
+		return roles;
+	}
+
+	/**
+	 * @param roles the roles to set
+	 */
+	public void setRoles(Set<String> roles) {
+		this.roles = roles == null ? new HashSet<String>() : roles;
+	}
+
+
 	/**
 	 * @return the accessTypes
 	 */
@@ -290,6 +319,20 @@ public class GrantRevokeRequest implements Serializable {
 		this.clusterName = clusterName;
 	}
 
+	/**
+	 * @return the clusterName
+	 */
+	public String getZoneName() {
+		return zoneName;
+	}
+
+	/**
+	 * @param zoneName the clusterName to set
+	 */
+	public void setZoneName(String zoneName) {
+		this.zoneName = zoneName;
+	}
+
 	@Override
 	public String toString( ) {
 		StringBuilder sb = new StringBuilder();
@@ -353,6 +396,7 @@ public class GrantRevokeRequest implements Serializable {
 		sb.append("requestData={").append(requestData).append("} ");
 		sb.append("sessionId={").append(sessionId).append("} ");
 		sb.append("clusterName={").append(clusterName).append("} ");
+		sb.append("zoneName={").append(zoneName).append("} ");
 
 		sb.append("}");
 
