@@ -80,7 +80,7 @@ public class RangerRESTClient {
 
 	public static final String RANGER_SSL_KEYMANAGER_ALGO_TYPE					 = KeyManagerFactory.getDefaultAlgorithm();
 	public static final String RANGER_SSL_TRUSTMANAGER_ALGO_TYPE				 = TrustManagerFactory.getDefaultAlgorithm();
-	public static final String RANGER_SSL_CONTEXT_ALGO_TYPE					     = "SSL";
+	public static final String RANGER_SSL_CONTEXT_ALGO_TYPE					     = "TLS";
 
 	private String  mUrl;
 	private String  mSslConfigFileName;
@@ -228,7 +228,7 @@ public class RangerRESTClient {
 
 	private void init() {
 		try {
-			gsonBuilder = new GsonBuilder().setDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSSZ").setPrettyPrinting().create();
+			gsonBuilder = new GsonBuilder().setDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSSZ").create();
 		} catch(Throwable excp) {
 			LOG.fatal("RangerRESTClient.init(): failed to create GsonBuilder object", excp);
 		}
@@ -383,9 +383,7 @@ public class RangerRESTClient {
 	}
 
 	private String getCredential(String url, String alias) {
-		char[] credStr = RangerCredentialProvider.getInstance().getCredentialString(url, alias);
-
-		return credStr == null ? null : new String(credStr);
+		return RangerCredentialProvider.getInstance().getCredentialString(url, alias);
 	}
 
 	private InputStream getFileInputStream(String fileName)  throws IOException {
