@@ -46,8 +46,6 @@ import org.apache.hadoop.conf.Configuration;
 import org.apache.ranger.authorization.hadoop.utils.RangerCredentialProvider;
 import org.apache.ranger.authorization.utils.StringUtil;
 
-import com.google.common.base.Objects;
-
 public class RangerSslHelper {
 	private static final Log LOG = LogFactory.getLog(RangerSslHelper.class);
 
@@ -65,7 +63,7 @@ public class RangerSslHelper {
 
 	static final String RANGER_SSL_KEYMANAGER_ALGO_TYPE                   = KeyManagerFactory.getDefaultAlgorithm();
 	static final String RANGER_SSL_TRUSTMANAGER_ALGO_TYPE                 = TrustManagerFactory.getDefaultAlgorithm();
-	static final String RANGER_SSL_CONTEXT_ALGO_TYPE                      = "SSL";
+	static final String RANGER_SSL_CONTEXT_ALGO_TYPE                      = "TLS";
 
 	private String mKeyStoreURL;
 	private String mKeyStoreAlias;
@@ -130,16 +128,7 @@ public class RangerSslHelper {
 			mTrustStoreFile  = conf.get(RANGER_POLICYMGR_TRUSTSTORE_FILE);
 
 			if (LOG.isDebugEnabled()) {
-				LOG.debug(Objects.toStringHelper("RangerSslHelper")
-					.add("keyStoreAlias", mKeyStoreAlias)
-					.add("keyStoreFile", mKeyStoreFile)
-					.add("keyStoreType", mKeyStoreType)
-					.add("keyStoreURL", mKeyStoreURL)
-					.add("trustStoreAlias", mTrustStoreAlias)
-					.add("trustStoreFile", mTrustStoreFile)
-					.add("trustStoreType", mTrustStoreType)
-					.add("trustStoreURL", mTrustStoreURL)
-					.toString());
+				LOG.debug(toString());
 			}
 		}
 		catch(IOException ioe) {
@@ -255,9 +244,7 @@ public class RangerSslHelper {
 	}
 
 	private String getCredential(String url, String alias) {
-		char[] credStr = RangerCredentialProvider.getInstance().getCredentialString(url, alias);
-
-		return credStr == null ? null : new String(credStr);
+		return RangerCredentialProvider.getInstance().getCredentialString(url, alias);
 	}
 
 	private InputStream getFileInputStream(String fileName)  throws IOException {
@@ -286,4 +273,17 @@ public class RangerSslHelper {
 			}
 		}
 	}
+
+	@Override
+	public String toString() {
+		return "keyStoreAlias=" + mKeyStoreAlias + ", "
+				+ "keyStoreFile=" + mKeyStoreFile + ", "
+				+ "keyStoreType="+ mKeyStoreType + ", "
+				+ "keyStoreURL=" + mKeyStoreURL + ", "
+				+ "trustStoreAlias=" + mTrustStoreAlias + ", "
+				+ "trustStoreFile=" + mTrustStoreFile + ", "
+				+ "trustStoreType=" + mTrustStoreType + ", "
+				+ "trustStoreURL=" + mTrustStoreURL
+				;
+	}
 }
