@@ -40,6 +40,7 @@ public class SearchFilter {
 	public static final String TAG_SERVICE_ID  = "tagServiceId";  // search
 	public static final String USER            = "user";          // search
 	public static final String GROUP           = "group";         // search
+	public static final String ROLE            = "role";         // search
 	public static final String RESOURCE_PREFIX = "resource:";     // search
 	public static final String RESOURCE_MATCH_SCOPE = "resourceMatchScope"; // search - valid values: "self", "ancestor", "self_or_ancestor"
 	public static final String POL_RESOURCE    = "polResource";   // search
@@ -56,6 +57,15 @@ public class SearchFilter {
     public static final String POLICY_LABEL     = "policyLabel";    // search
     public static final String POLICY_LABELS_PARTIAL     = "policyLabelsPartial";    // search
     public static final String POLICY_LABEL_ID       = "policyLabelId";      // search, sort
+    public static final String ZONE_ID               = "zoneId";      // search, sort
+    public static final String ZONE_NAME             = "zoneName";      // search, sort
+	public static final String ROLE_ID               = "roleId";      // search, sort
+	public static final String ROLE_NAME             = "roleName";      // search, sort
+	public static final String GROUP_NAME            = "groupName";      // search, sort
+	public static final String USER_NAME             = "userName";      // search, sort
+	public static final String ROLE_NAME_PARTIAL     = "roleNamePartial";      // search
+	public static final String GROUP_NAME_PARTIAL    = "groupNamePartial";      // search
+	public static final String USER_NAME_PARTIAL     = "userNamePartial";      // search
 
 	public static final String TAG_DEF_ID                = "tagDefId";            // search
 	public static final String TAG_DEF_GUID              = "tagDefGuid";          // search
@@ -75,6 +85,7 @@ public class SearchFilter {
 	public static final String PLUGIN_APP_TYPE           = "pluginAppType";
 	public static final String PLUGIN_ENTITY_TYPE        = "pluginEntityType";
 	public static final String PLUGIN_IP_ADDRESS         = "pluginIpAddress";
+	public static final String CLUSTER_NAME              = "clusterName";
 
 	private Map<String, String> params;
 	private int                 startIndex;
