@@ -47,8 +47,7 @@ public class RangerServiceTag extends RangerBaseService {
 	public static final String RANGER_TAG_NAME_EXPIRES_ON = "EXPIRES_ON";
 	public static final String RANGER_TAG_EXPIRY_CONDITION_NAME = "accessed-after-expiry";
 
-	private TagStore tagStore = null;
-
+	private TagStore tagStore;
 
 	public RangerServiceTag() {
 		super();
@@ -69,7 +68,7 @@ public class RangerServiceTag extends RangerBaseService {
 			LOG.debug("==> RangerServiceTag.validateConfig(" + serviceName + " )");
 		}
 
-		HashMap<String, Object> ret = new HashMap<String, Object>();
+		Map<String, Object> ret = new HashMap<>();
 
 		ret.put("connectivityStatus", true);
 
@@ -86,7 +85,7 @@ public class RangerServiceTag extends RangerBaseService {
 			LOG.debug("==> RangerServiceTag.lookupResource(" + context + ")");
 		}
 
-		List<String> ret = new ArrayList<String>();
+		List<String> ret = new ArrayList<>();
 
 		if (context != null && StringUtils.equals(context.getResourceName(), TAG_RESOURCE_NAME)) {
 			try {
@@ -96,9 +95,7 @@ public class RangerServiceTag extends RangerBaseService {
 					List<String> valuesToExclude = MapUtils.isNotEmpty(context.getResources()) ? context.getResources().get(TAG_RESOURCE_NAME) : null;
 
 					if(CollectionUtils.isNotEmpty(valuesToExclude)) {
-						for (String valueToExclude : valuesToExclude) {
-							tags.remove(valueToExclude);
-						}
+						tags.removeAll(valuesToExclude);
 					}
 
 					String valueToMatch = context.getUserInput();
@@ -151,41 +148,43 @@ public class RangerServiceTag extends RangerBaseService {
 		if (isConditionDefFound) {
 
 			ret = super.getDefaultRangerPolicies();
+			String tagResourceName = null;
+			if (!serviceDef.getResources().isEmpty()) {
+				tagResourceName = serviceDef.getResources().get(0).getName();
 
-			String tagResourceName = serviceDef.getResources().get(0).getName();
+				for (RangerPolicy defaultPolicy : ret) {
 
-			for (RangerPolicy defaultPolicy : ret) {
+					RangerPolicy.RangerPolicyResource tagPolicyResource = defaultPolicy.getResources().get(tagResourceName);
 
-				RangerPolicy.RangerPolicyResource tagPolicyResource = defaultPolicy.getResources().get(tagResourceName);
+					if (tagPolicyResource != null) {
 
-				if (tagPolicyResource != null) {
+						String value = RANGER_TAG_NAME_EXPIRES_ON;
 
-					String value = RANGER_TAG_NAME_EXPIRES_ON;
+						tagPolicyResource.setValue(value);
+						defaultPolicy.setName(value);
+						defaultPolicy.setDescription("Policy for data with " + value + " tag");
 
-					tagPolicyResource.setValue(value);
-					defaultPolicy.setName(value);
-					defaultPolicy.setDescription("Policy for data with " + value + " tag");
+						List<RangerPolicy.RangerPolicyItem> defaultPolicyItems = defaultPolicy.getPolicyItems();
 
-					List<RangerPolicy.RangerPolicyItem> defaultPolicyItems = defaultPolicy.getPolicyItems();
+						for (RangerPolicy.RangerPolicyItem defaultPolicyItem : defaultPolicyItems) {
 
-					for (RangerPolicy.RangerPolicyItem defaultPolicyItem : defaultPolicyItems) {
+							List<String> groups = new ArrayList<String>();
+							groups.add(GROUP_PUBLIC);
+							defaultPolicyItem.setGroups(groups);
 
-						List<String> groups = new ArrayList<String>();
-						groups.add(GROUP_PUBLIC);
-						defaultPolicyItem.setGroups(groups);
+							List<RangerPolicy.RangerPolicyItemCondition> policyItemConditions = new ArrayList<RangerPolicy.RangerPolicyItemCondition>();
+							List<String> values = new ArrayList<String>();
+							values.add("yes");
+							RangerPolicy.RangerPolicyItemCondition policyItemCondition = new RangerPolicy.RangerPolicyItemCondition(RANGER_TAG_EXPIRY_CONDITION_NAME, values);
+							policyItemConditions.add(policyItemCondition);
 
-						List<RangerPolicy.RangerPolicyItemCondition> policyItemConditions = new ArrayList<RangerPolicy.RangerPolicyItemCondition>();
-						List<String> values = new ArrayList<String>();
-						values.add("yes");
-						RangerPolicy.RangerPolicyItemCondition policyItemCondition = new RangerPolicy.RangerPolicyItemCondition(RANGER_TAG_EXPIRY_CONDITION_NAME, values);
-						policyItemConditions.add(policyItemCondition);
+							defaultPolicyItem.setConditions(policyItemConditions);
+							defaultPolicyItem.setDelegateAdmin(Boolean.FALSE);
+						}
 
-						defaultPolicyItem.setConditions(policyItemConditions);
-						defaultPolicyItem.setDelegateAdmin(Boolean.FALSE);
+						defaultPolicy.setDenyPolicyItems(defaultPolicyItems);
+						defaultPolicy.setPolicyItems(null);
 					}
-
-					defaultPolicy.setDenyPolicyItems(defaultPolicyItems);
-					defaultPolicy.setPolicyItems(null);
 				}
 			}
 		} else {
