@@ -36,6 +36,7 @@ import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItem;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItemAccess;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyResource;
 import org.apache.ranger.plugin.model.RangerPolicyResourceSignature;
+import org.apache.ranger.plugin.model.RangerSecurityZone;
 import org.apache.ranger.plugin.model.RangerService;
 import org.apache.ranger.plugin.model.RangerServiceDef;
 import org.apache.ranger.plugin.model.RangerServiceDef.RangerResourceDef;
@@ -123,13 +124,13 @@ public class TestRangerPolicyValidator {
 	private final Object[][] policyResourceMap_good = new Object[][] {
 			// resource-name, values, excludes, recursive
 			{ "db", new String[] { "db1", "db2" }, null, null },
-			{ "TBL", new String[] { "tbl1", "tbl2" }, true, false } // case should not matter
+			{ "tbl", new String[] { "tbl1", "tbl2" }, true, false } // case matters - use only lowercase characters
 	};
 	
 	private final Object[][] policyResourceMap_goodMultipleHierarchies = new Object[][] {
 			// resource-name, values, excludes, recursive
 			{ "db", new String[] { "db1", "db2" }, null, null },
-			{ "UDF", new String[] { "udf1", "udf2" }, true, false } // case should not matter
+			{ "udf", new String[] { "udf1", "udf2" }, true, false } // case matters - use only lowercase characters
 	};
 	
 	private final Object[][] policyResourceMap_bad = new Object[][] {
@@ -252,7 +253,7 @@ public class TestRangerPolicyValidator {
 					if (action == Action.CREATE) {
 						when(_policy.getId()).thenReturn(7L);
 						when(_policy.getName()).thenReturn("policy-name-1");
-						when(_store.getPolicyId(service.getId(), _policy.getName())).thenReturn(null);
+						when(_store.getPolicyId(service.getId(), _policy.getName(), _zoneId)).thenReturn(null);
 						Assert.assertTrue("" + action + ", " + auditEnabled, _validator.isValid(_policy, action, isAdmin, _failures));
 						Assert.assertTrue(_failures.isEmpty());
 					} else {
@@ -263,7 +264,7 @@ public class TestRangerPolicyValidator {
 						Assert.assertTrue(_failures.isEmpty());
 	
 						when(_policy.getName()).thenReturn("policy-name-2");
-						when(_store.getPolicyId(service.getId(), _policy.getName())).thenReturn(null);
+						when(_store.getPolicyId(service.getId(), _policy.getName(), _zoneId)).thenReturn(null);
 						Assert.assertTrue("" + action + ", " + auditEnabled, _validator.isValid(_policy, action, isAdmin, _failures));
 						Assert.assertTrue(_failures.isEmpty());
 					}
@@ -377,7 +378,7 @@ public class TestRangerPolicyValidator {
 		when(existingPolicy.getService()).thenReturn("service-name");
 		List<RangerPolicy> existingPolicies = new ArrayList<>();
 
-		when(_store.getPolicyId(service.getId(), "policy-name")).thenReturn(7L);
+		when(_store.getPolicyId(service.getId(), "policy-name", _zoneId)).thenReturn(7L);
 		checkFailure_isValid(Action.CREATE, "semantic", "policy name");
 		
 		// update : does not exist for id
@@ -392,7 +393,7 @@ public class TestRangerPolicyValidator {
 		when(anotherExistingPolicy.getService()).thenReturn("service-name");
 
 		existingPolicies.add(anotherExistingPolicy);
-		when(_store.getPolicyId(service.getId(), "policy-name")).thenReturn(8L);
+		when(_store.getPolicyId(service.getId(), "policy-name", _zoneId)).thenReturn(8L);
 		checkFailure_isValid(Action.UPDATE, "semantic", "id/name");
 		
 		// policy must have service name on it and it should be valid
@@ -474,7 +475,7 @@ public class TestRangerPolicyValidator {
 		
 		// create the right service def with right resource defs - this is the same as in the happypath test above.
 		_serviceDef = _utils.createServiceDefWithAccessTypes(accessTypes, "service-type");
-		when(_store.getPolicyId(service.getId(), "policy-name")).thenReturn(null);
+		when(_store.getPolicyId(service.getId(), "policy-name", _zoneId)).thenReturn(null);
 		List<RangerResourceDef> resourceDefs = _utils.createResourceDefs(resourceDefData);
 		when(_serviceDef.getResources()).thenReturn(resourceDefs);
 		when(_store.getServiceDefByName("service-type")).thenReturn(_serviceDef);
@@ -563,7 +564,7 @@ public class TestRangerPolicyValidator {
 		when(policyItem.getUsers()).thenReturn(null);
 		when(policyItem.getGroups()).thenReturn(new ArrayList<String>());
 		_failures.clear(); Assert.assertFalse(_validator.isValidPolicyItem(policyItem, _failures, _serviceDef));
-		_utils.checkFailureForMissingValue(_failures, "policy item users/user-groups");
+		_utils.checkFailureForMissingValue(_failures, "policy item users/user-groups/roles");
 	}
 	
 	@Test
@@ -805,6 +806,70 @@ public class TestRangerPolicyValidator {
 		_utils.checkFailureForSemanticError(_failures, "policy resources", "missing mandatory");
 	}
 	
+	@Test
+	public final void test_isValidServiceWithZone_happyPath() throws Exception{
+		boolean isAdmin = true;
+		when(_policy.getId()).thenReturn(1L);
+		when(_policy.getName()).thenReturn("my-all");
+		when(_policy.getService()).thenReturn("hdfssvc");
+		when(_policy.getZoneName()).thenReturn("zone1");
+		when(_policy.getResources()).thenReturn(null);
+		when(_policy.getIsAuditEnabled()).thenReturn(Boolean.TRUE);
+		when(_policy.getIsEnabled()).thenReturn(Boolean.FALSE);
+		RangerService service = new RangerService();
+		service.setType("service-type");
+		service.setId(2L);
+		Action action = Action.CREATE;
+		List<String> tagSvcList = new ArrayList<String>();
+		tagSvcList.add("hdfssvc");
+		when(_store.getServiceByName("hdfssvc")).thenReturn(service);
+		RangerSecurityZone securityZone = new RangerSecurityZone();
+		securityZone.setName("zone1");
+		securityZone.setId(1L);
+		securityZone.setTagServices(tagSvcList);
+		when(_store.getSecurityZone("zone1")).thenReturn(securityZone);
+		when(_store.getPolicyId(2L, "my-all", 1L)).thenReturn(null);
+		RangerServiceDef svcDef = new RangerServiceDef();
+		svcDef.setName("my-svc-def");
+		when(_store.getServiceDefByName("service-type")).thenReturn(svcDef);
+		RangerPolicyResourceSignature policySignature = mock(RangerPolicyResourceSignature.class);
+		when(_factory.createPolicyResourceSignature(_policy)).thenReturn(policySignature);
+		Assert.assertTrue(_validator.isValid(_policy, action, isAdmin, _failures));
+	}
+
+	@Test
+	public final void test_isValidServiceWithZone_failurePath() throws Exception{
+		boolean isAdmin = true;
+		when(_policy.getId()).thenReturn(1L);
+		when(_policy.getName()).thenReturn("my-all");
+		when(_policy.getService()).thenReturn("hdfssvc1");
+		when(_policy.getZoneName()).thenReturn("zone1");
+		when(_policy.getResources()).thenReturn(null);
+		when(_policy.getIsAuditEnabled()).thenReturn(Boolean.TRUE);
+		when(_policy.getIsEnabled()).thenReturn(Boolean.FALSE);
+		RangerService service = new RangerService();
+		service.setType("service-type");
+		service.setId(2L);
+		Action action = Action.CREATE;
+		List<String> tagSvcList = new ArrayList<String>();
+		tagSvcList.add("hdfssvc");
+		when(_store.getServiceByName("hdfssvc1")).thenReturn(service);
+		RangerSecurityZone securityZone = new RangerSecurityZone();
+		securityZone.setName("zone1");
+		securityZone.setId(1L);
+		securityZone.setTagServices(tagSvcList);
+		when(_store.getSecurityZone("zone1")).thenReturn(securityZone);
+		when(_store.getPolicyId(2L, "my-all", 1L)).thenReturn(null);
+		RangerServiceDef svcDef = new RangerServiceDef();
+		svcDef.setName("my-svc-def");
+		when(_store.getServiceDefByName("service-type")).thenReturn(svcDef);
+		RangerPolicyResourceSignature policySignature = mock(RangerPolicyResourceSignature.class);
+		when(_factory.createPolicyResourceSignature(_policy)).thenReturn(policySignature);
+		boolean isValid = _validator.isValid(_policy, action, isAdmin, _failures);
+		Assert.assertFalse(isValid);
+		Assert.assertEquals(_failures.get(0)._errorCode, 3048);
+		Assert.assertEquals(_failures.get(0)._reason,"Service name = hdfssvc1 is not associated to Zone name = zone1");
+	}
 	
 	private ValidationTestUtils _utils = new ValidationTestUtils();
 	private List<ValidationFailureDetails> _failures = new ArrayList<ValidationFailureDetails>();
@@ -813,4 +878,5 @@ public class TestRangerPolicyValidator {
 	private RangerPolicyValidator _validator;
 	private RangerServiceDef _serviceDef;
 	private RangerObjectFactory _factory;
+	private Long _zoneId = RangerSecurityZone.RANGER_UNZONED_SECURITY_ZONE_ID;
 }
