@@ -35,6 +35,7 @@ import org.apache.ranger.authorization.hadoop.config.RangerConfiguration;
 import org.apache.ranger.plugin.audit.RangerDefaultAuditHandler;
 import org.apache.ranger.plugin.contextenricher.RangerTagForEval;
 import org.apache.ranger.plugin.model.RangerPolicy;
+import org.apache.ranger.plugin.model.RangerPolicyDelta;
 import org.apache.ranger.plugin.model.RangerServiceDef;
 import org.apache.ranger.plugin.model.RangerValiditySchedule;
 import org.apache.ranger.plugin.model.validation.RangerValidityScheduleValidator;
@@ -67,6 +68,7 @@ import static org.junit.Assert.*;
 
 public class TestPolicyEngine {
 	static Gson gsonBuilder;
+	long requestCount = 0L;
 
 	@BeforeClass
 	public static void setUpBeforeClass() throws Exception {
@@ -209,6 +211,19 @@ public class TestPolicyEngine {
 
 		runTestsFromResourceFiles(hdfsTestResourceFiles);
 	}
+	@Test
+	public void testPolicyEngine_hdfsForZones() {
+		String[] hdfsTestResourceFiles = { "/policyengine/test_policyengine_hdfs_zones.json" };
+
+		runTestsFromResourceFiles(hdfsTestResourceFiles);
+	}
+
+	@Test
+	public void testPolicyEngine_hive_with_partial_resource_policies() {
+		String[] hiveTestResourceFiles = { "/policyengine/test_policyengine_hive_with_partial_resource_policies.json" };
+
+		runTestsFromResourceFiles(hiveTestResourceFiles);
+	}
 
 	@Test
 	public void testPolicyEngine_hive() {
@@ -217,6 +232,27 @@ public class TestPolicyEngine {
 		runTestsFromResourceFiles(hiveTestResourceFiles);
 	}
 
+	@Test
+	public void testPolicyEngine_hive_incremental_add() {
+		String[] hiveTestResourceFiles = {"/policyengine/test_policyengine_hive_incremental_add.json"};
+
+		runTestsFromResourceFiles(hiveTestResourceFiles);
+	}
+
+	@Test
+	public void testPolicyEngine_hive_incremental_delete() {
+		String[] hiveTestResourceFiles = {"/policyengine/test_policyengine_hive_incremental_delete.json"};
+
+		runTestsFromResourceFiles(hiveTestResourceFiles);
+	}
+
+	@Test
+	public void testPolicyEngine_hive_incremental_update() {
+		String[] hiveTestResourceFiles = {"/policyengine/test_policyengine_hive_incremental_update.json"};
+
+		runTestsFromResourceFiles(hiveTestResourceFiles);
+	}
+
 	@Test
 	public void testPolicyEngine_hiveForTag() {
 		String[] hiveTestResourceFiles = { "/policyengine/test_policyengine_tag_hive.json" };
@@ -333,6 +369,20 @@ public class TestPolicyEngine {
 		runTestsFromResourceFiles(resourceFiles);
 	}
 
+	@Test
+	public void testPolicyEngine_policylevel_conditions() {
+		String[] conditionsTestResourceFiles = { "/policyengine/test_policyengine_policylevel_conditions.json" };
+
+		runTestsFromResourceFiles(conditionsTestResourceFiles);
+	}
+
+	@Test
+	public void testPolicyEngine_with_roles() {
+		String[] conditionsTestResourceFiles = { "/policyengine/test_policyengine_with_roles.json" };
+
+		runTestsFromResourceFiles(conditionsTestResourceFiles);
+	}
+
 	private void runTestsFromResourceFiles(String[] resourceNames) {
 		for(String resourceName : resourceNames) {
 			InputStream inStream = this.getClass().getResourceAsStream(resourceName);
@@ -351,6 +401,9 @@ public class TestPolicyEngine {
 		servicePolicies.setServiceName(testCase.serviceName);
 		servicePolicies.setServiceDef(testCase.serviceDef);
 		servicePolicies.setPolicies(testCase.policies);
+		servicePolicies.setSecurityZones(testCase.securityZones);
+		servicePolicies.setUserRoles(testCase.userRoles);
+		servicePolicies.setGroupRoles(testCase.groupRoles);
 
 		if (StringUtils.isNotBlank(testCase.auditMode)) {
 			servicePolicies.setAuditMode(testCase.auditMode);
@@ -382,7 +435,10 @@ public class TestPolicyEngine {
 				trustedProxyAddresses[i] = trustedProxyAddresses[i].trim();
 			}
 		}
-		RangerPolicyEngine policyEngine = new RangerPolicyEngineImpl(testName, servicePolicies, policyEngineOptions);
+		RangerPluginContext pluginContext = new RangerPluginContext("hive");
+		pluginContext.setClusterName("cl1");
+		pluginContext.setClusterType("on-prem");
+		RangerPolicyEngine policyEngine = new RangerPolicyEngineImpl(testName, servicePolicies, policyEngineOptions,  pluginContext);
 
 		policyEngine.setUseForwardedIPAddress(useForwardedIPAddress);
 		policyEngine.setTrustedProxyAddresses(trustedProxyAddresses);
@@ -390,16 +446,28 @@ public class TestPolicyEngine {
 		policyEngineOptions.disableAccessEvaluationWithPolicyACLSummary = true;
 		policyEngineOptions.optimizeTrieForRetrieval = false;
 
-		RangerPolicyEngine policyEngineForResourceAccessInfo = new RangerPolicyEngineImpl(testName, servicePolicies, policyEngineOptions);
+		RangerPolicyEngine policyEngineForResourceAccessInfo = new RangerPolicyEngineImpl(testName, servicePolicies, policyEngineOptions,  pluginContext);
 
 		policyEngineForResourceAccessInfo.setUseForwardedIPAddress(useForwardedIPAddress);
 		policyEngineForResourceAccessInfo.setTrustedProxyAddresses(trustedProxyAddresses);
 
-		long requestCount = 0L;
+		runTestCaseTests(policyEngine, policyEngineForResourceAccessInfo, testCase.serviceDef, testName, testCase.tests);
 
-		RangerAccessRequest request = null;
+		if (CollectionUtils.isNotEmpty(testCase.updatedPolicies)) {
+			servicePolicies.setPolicyDeltas(testCase.updatedPolicies);
+			servicePolicies.setPolicyVersion(-1L);
+			RangerPolicyEngine updatedPolicyEngine = policyEngine.cloneWithDelta(servicePolicies);
+			RangerPolicyEngine updatedPolicyEngineForResourceAccessInfo = policyEngineForResourceAccessInfo.cloneWithDelta(servicePolicies);
+			runTestCaseTests(updatedPolicyEngine, updatedPolicyEngineForResourceAccessInfo, testCase.serviceDef, testName, testCase.updatedTests);
 
-		for(TestData test : testCase.tests) {
+		}
+	}
+
+    private void runTestCaseTests(RangerPolicyEngine policyEngine, RangerPolicyEngine policyEngineForResourceAccessInfo, RangerServiceDef serviceDef, String testName, List<TestData> tests) {
+
+        RangerAccessRequest request = null;
+
+        for(TestData test : tests) {
 			request = test.request;
 			if ((requestCount++ % 10) == 1) {
 				policyEngine.reorderPolicyEvaluators();
@@ -464,7 +532,7 @@ public class TestPolicyEngine {
 
 				// Safe cast
 				RangerAccessResourceImpl accessResource = (RangerAccessResourceImpl) request.getResource();
-				accessResource.setServiceDef(testCase.serviceDef);
+				accessResource.setServiceDef(serviceDef);
 
 				request = newRequest;
 
@@ -482,7 +550,6 @@ public class TestPolicyEngine {
 				assertNotNull("result was null! - " + test.name, result);
 				assertEquals("isAllowed mismatched! - " + test.name, expected.getIsAllowed(), result.getIsAllowed());
 				assertEquals("isAudited mismatched! - " + test.name, expected.getIsAudited(), result.getIsAudited());
-				assertEquals("policyId mismatched! - " + test.name, expected.getPolicyId(), result.getPolicyId());
 			}
 
 			if(test.dataMaskResult != null) {
@@ -517,6 +584,7 @@ public class TestPolicyEngine {
 				assertEquals("deniedGroups mismatched! - " + test.name, expected.getDeniedGroups(), result.getDeniedGroups());
 			}
 		}
+
 	}
 
 	static class PolicyEngineTestCase {
@@ -524,8 +592,14 @@ public class TestPolicyEngine {
 		public RangerServiceDef   serviceDef;
 		public List<RangerPolicy> policies;
 		public TagPolicyInfo	  tagPolicyInfo;
+		public Map<String, ServicePolicies.SecurityZoneInfo> securityZones;
+		public Map<String, Set<String>> userRoles;
+		public Map<String, Set<String>> groupRoles;
 		public String             auditMode;
 		public List<TestData>     tests;
+
+		public List<RangerPolicyDelta> updatedPolicies;
+		public List<TestData>     updatedTests;
 		
 		class TestData {
 			public String              name;
