@@ -27,7 +27,6 @@ import java.util.Iterator;
 import java.util.Properties;
 import java.util.logging.Logger;
 import java.util.List;
-import javax.servlet.ServletException;
 
 import org.apache.catalina.Context;
 import org.apache.catalina.LifecycleException;
@@ -58,6 +57,7 @@ public class EmbeddedServer {
 	private static final String AUTH_TYPE_KERBEROS = "kerberos";
     private static final String AUTHENTICATION_TYPE = "hadoop.security.authentication";
     private static final String ADMIN_USER_PRINCIPAL = "ranger.admin.kerberos.principal";
+    private static final String SOLR_BOOTSTRAP_ENABLED = "ranger.audit.solr.bootstrap.enabled";
     private static final String ADMIN_USER_KEYTAB = "ranger.admin.kerberos.keytab";
 
 	private static final String ADMIN_NAME_RULES = "hadoop.security.auth_to_local";
@@ -222,9 +222,6 @@ public class EmbeddedServer {
 			webappCtx.init();
 			LOG.info("Finished init of webapp [" + webContextName
 					+ "] = path [" + webapp_dir + "].");
-		} catch (ServletException e1) {
-			LOG.severe("Tomcat Server failed to add webapp:" + e1.toString());
-			e1.printStackTrace();
 		} catch (LifecycleException lce) {
 			LOG.severe("Tomcat Server failed to start webapp:" + lce.toString());
 			lce.printStackTrace();
@@ -272,6 +269,22 @@ public class EmbeddedServer {
 
 	private void startServer(final Tomcat server) {
 		try {
+
+			try {
+				boolean solrBootstrapEnabled = Boolean.valueOf(getConfig(
+						SOLR_BOOTSTRAP_ENABLED, "true"));
+				if (solrBootstrapEnabled) {
+					String servername = getConfig("servername");
+					LOG.info("Server Name : " + servername);
+					if (servername.equalsIgnoreCase(ADMIN_SERVER_NAME)) {
+						SolrCollectionBootstrapper solrSetup = new SolrCollectionBootstrapper();
+						solrSetup.start();
+					}
+				}
+			} catch (Exception e) {
+				LOG.severe("Error while setting solr " + e);
+			}
+
 			server.start();
 			server.getServer().await();
 			shutdownServer();
@@ -376,6 +389,8 @@ public class EmbeddedServer {
 		server.getConnector().setMaxSavePostSize(getIntConfig("ranger.service.http.connector.attrib.maxSavePostSize", 4096));
 		server.getConnector().setParseBodyMethods(getConfig("ranger.service.http.connector.attrib.methods", "POST"));
 		server.getConnector().setURIEncoding(getConfig("ranger.service.http.connector.attrib.URIEncoding", "UTF-8"));
+		server.getConnector().setXpoweredBy(false);
+		server.getConnector().setAttribute("server", "Apache Ranger");
 		Iterator<Object> iterator = serverConfigProperties.keySet().iterator();
 		String key = null;
 		String property = null;
