@@ -20,7 +20,7 @@ package org.apache.ranger.authorization.hbase;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.hadoop.hbase.HRegionInfo;
+import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
 import org.apache.hadoop.hbase.security.access.Permission.Action;
 import org.apache.hadoop.hbase.util.Bytes;
@@ -56,7 +56,7 @@ public class HbaseAuthUtilsImpl implements HbaseAuthUtils {
 
 	@Override
 	public String getTable(RegionCoprocessorEnvironment regionServerEnv) {
-		HRegionInfo hri = regionServerEnv.getRegion().getRegionInfo();
+		RegionInfo hri = regionServerEnv.getRegion().getRegionInfo();
 		byte[] tableName = hri.getTable().getName();
 		String tableNameStr = Bytes.toString(tableName);
 		if (LOG.isDebugEnabled()) {
