@@ -43,6 +43,7 @@ import org.apache.hadoop.hdfs.server.namenode.INode;
 import org.apache.hadoop.hdfs.server.namenode.INodeAttributeProvider;
 import org.apache.hadoop.hdfs.server.namenode.INodeAttributes;
 import org.apache.hadoop.hdfs.server.namenode.INodeDirectory;
+import org.apache.hadoop.hdfs.server.namenode.snapshot.Snapshot;
 import org.apache.hadoop.hdfs.util.ReadOnlyList;
 import org.apache.hadoop.ipc.Server;
 import org.apache.hadoop.security.AccessControlException;
@@ -241,10 +242,14 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 				INode   parent              = null;
 				INode   inode               = null;
 
+				boolean useDefaultAuthorizerOnly = false;
+				boolean doNotGenerateAuditRecord = false;
+
 				if(plugin != null && !ArrayUtils.isEmpty(inodes)) {
 					int sz = inodeAttrs.length;
 					if (LOG.isDebugEnabled()) {
 						LOG.debug("Size of INodeAttrs array:[" + sz + "]");
+						LOG.debug("Size of INodes array:[" + inodes.length + "]");
 					}
 					byte[][] components = new byte[sz][];
 
@@ -259,11 +264,40 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 					if (i != sz) {
 						if (LOG.isDebugEnabled()) {
 							LOG.debug("Input INodeAttributes array contains null at position " + i);
-							LOG.debug("Will use only first [" + i + "] components to build resourcePath");
+							LOG.debug("Will use only first [" + i + "] components");
 						}
 					}
 
-					resourcePath = DFSUtil.byteArray2PathString(components, 0, i);
+					if (sz == 1 && inodes.length == 1 && inodes[0].getParent() != null) {
+
+						doNotGenerateAuditRecord = true;
+
+						if (LOG.isDebugEnabled()) {
+							LOG.debug("Using the only inode in the array to figure out path to resource. No audit record will be generated for this authorization request");
+						}
+
+						resourcePath = inodes[0].getFullPathName();
+
+						if (snapshotId != Snapshot.CURRENT_STATE_ID) {
+
+							useDefaultAuthorizerOnly = true;
+
+							if (LOG.isDebugEnabled()) {
+								LOG.debug("path:[" + resourcePath + "] is for a snapshot, id=[" + snapshotId +"], default Authorizer will be used to authorize this request");
+							}
+						} else {
+							if (LOG.isDebugEnabled()) {
+								LOG.debug("path:[" + resourcePath + "] is not for a snapshot, id=[" + snapshotId +"]. It will be used to authorize this request");
+							}
+						}
+					} else {
+
+						resourcePath = DFSUtil.byteArray2PathString(components, 0, i);
+
+						if (LOG.isDebugEnabled()) {
+							LOG.debug("INodeAttributes array is used to figure out path to resource, resourcePath:[" + resourcePath +"]");
+						}
+					}
 
 					if(ancestorIndex >= inodes.length) {
 						ancestorIndex = inodes.length - 1;
@@ -271,13 +305,13 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 
 					for(; ancestorIndex >= 0 && inodes[ancestorIndex] == null; ancestorIndex--);
 
-					authzStatus = AuthzStatus.ALLOW;
+					authzStatus = useDefaultAuthorizerOnly ? AuthzStatus.NOT_DETERMINED : AuthzStatus.ALLOW;
 
 					ancestor = inodes.length > ancestorIndex && ancestorIndex >= 0 ? inodes[ancestorIndex] : null;
 					parent   = inodes.length > 1 ? inodes[inodes.length - 2] : null;
 					inode    = inodes[inodes.length - 1]; // could be null while creating a new file
 
-					auditHandler = new RangerHdfsAuditHandler(resourcePath, isTraverseOnlyCheck);
+					auditHandler = doNotGenerateAuditRecord ? null : new RangerHdfsAuditHandler(resourcePath, isTraverseOnlyCheck);
 
 					/* Hadoop versions prior to 2.8.0 didn't ask for authorization of parent/ancestor traversal for
 					 * reading or writing a file. However, Hadoop version 2.8.0 and later ask traversal authorization for
@@ -294,7 +328,7 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 					 * This approach would ensure that Ranger authorization will continue to work with existing policies,
 					 * without requiring policy migration/update, for the changes in behaviour in Hadoop 2.8.0.
 					 */
-					if(isTraverseOnlyCheck) {
+					if(authzStatus == AuthzStatus.ALLOW && isTraverseOnlyCheck) {
 						authzStatus = traverseOnlyCheck(inode, inodeAttrs, resourcePath, components, parent, ancestor, ancestorIndex, user, groups, plugin, auditHandler);
 					}
 
@@ -486,7 +520,6 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 		private AuthzStatus isAccessAllowedForTraversal(INode inode, INodeAttributes inodeAttribs, String path, String user, Set<String> groups, RangerHdfsPlugin plugin, RangerHdfsAuditHandler auditHandler, boolean skipAuditOnAllow) {
 			final AuthzStatus ret;
 			String pathOwner = inodeAttribs != null ? inodeAttribs.getUserName() : null;
-			String clusterName = plugin.getClusterName();
 			FsAction access = FsAction.EXECUTE;
 
 
@@ -502,7 +535,7 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 				LOG.debug("==> RangerAccessControlEnforcer.isAccessAllowedForTraversal(" + path + ", " + access + ", " + user + ", " + skipAuditOnAllow + ")");
 			}
 
-			RangerHdfsAccessRequest request = new RangerHdfsAccessRequest(inode, path, pathOwner, access, EXECUTE_ACCCESS_TYPE, user, groups, clusterName);
+			RangerHdfsAccessRequest request = new RangerHdfsAccessRequest(inode, path, pathOwner, access, EXECUTE_ACCCESS_TYPE, user, groups);
 
 			RangerAccessResult result = plugin.isAccessAllowed(request, null);
 
@@ -605,7 +638,6 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 		private AuthzStatus isAccessAllowed(INode inode, INodeAttributes inodeAttribs, String path, FsAction access, String user, Set<String> groups, RangerHdfsPlugin plugin, RangerHdfsAuditHandler auditHandler) {
 			AuthzStatus ret       = null;
 			String      pathOwner = inodeAttribs != null ? inodeAttribs.getUserName() : null;
-			String 		clusterName = plugin.getClusterName();
 
 			if(pathOwner == null && inode != null) {
 				pathOwner = inode.getUserName();
@@ -628,7 +660,7 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 			}
 
 			for(String accessType : accessTypes) {
-				RangerHdfsAccessRequest request = new RangerHdfsAccessRequest(inode, path, pathOwner, access, accessType, user, groups, clusterName);
+				RangerHdfsAccessRequest request = new RangerHdfsAccessRequest(inode, path, pathOwner, access, accessType, user, groups);
 
 				RangerAccessResult result = plugin.isAccessAllowed(request, auditHandler);
 
@@ -659,7 +691,6 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 		private AuthzStatus isAccessAllowedForHierarchy(INode inode, INodeAttributes inodeAttribs, String path, FsAction access, String user, Set<String> groups, RangerHdfsPlugin plugin) {
 			AuthzStatus ret   = null;
 			String  pathOwner = inodeAttribs != null ? inodeAttribs.getUserName() : null;
-			String 		clusterName = plugin.getClusterName();
 
 			if (pathOwner == null && inode != null) {
 				pathOwner = inode.getUserName();
@@ -690,7 +721,7 @@ public class RangerHdfsAuthorizer extends INodeAttributeProvider {
 				subDirPath = subDirPath + RangerHdfsPlugin.getRandomizedWildcardPathName();
 
 				for (String accessType : accessTypes) {
-					RangerHdfsAccessRequest request = new RangerHdfsAccessRequest(null, subDirPath, pathOwner, access, accessType, user, groups, clusterName);
+					RangerHdfsAccessRequest request = new RangerHdfsAccessRequest(null, subDirPath, pathOwner, access, accessType, user, groups);
 
 					RangerAccessResult result = plugin.isAccessAllowed(request, null);
 
@@ -787,7 +818,7 @@ class RangerHdfsResource extends RangerAccessResourceImpl {
 
 class RangerHdfsAccessRequest extends RangerAccessRequestImpl {
 
-	public RangerHdfsAccessRequest(INode inode, String path, String pathOwner, FsAction access, String accessType, String user, Set<String> groups, String clusterName) {
+	public RangerHdfsAccessRequest(INode inode, String path, String pathOwner, FsAction access, String accessType, String user, Set<String> groups) {
 		super.setResource(new RangerHdfsResource(path, pathOwner));
 		super.setAccessType(accessType);
 		super.setUser(user);
@@ -795,7 +826,6 @@ class RangerHdfsAccessRequest extends RangerAccessRequestImpl {
 		super.setAccessTime(new Date());
 		super.setClientIPAddress(getRemoteIp());
 		super.setAction(access.toString());
-		super.setClusterName(clusterName);
 
 		if (inode != null) {
 			buildRequestContext(inode);
@@ -880,6 +910,7 @@ class RangerHdfsAuditHandler extends RangerDefaultAuditHandler {
 
 			auditEvent.setAccessResult((short) (result.getIsAllowed() ? 1 : 0));
 			auditEvent.setPolicyId(result.getPolicyId());
+			auditEvent.setPolicyVersion(result.getPolicyVersion());
 
 			Set<String> tags = getTags(request);
 			if (tags != null) {
