@@ -30,52 +30,70 @@ public class RangerHiveResource extends RangerAccessResourceImpl {
 	public static final String KEY_UDF      = "udf";
 	public static final String KEY_COLUMN   = "column";
 	public static final String KEY_URL		= "url";
+	public static final String KEY_HIVESERVICE = "hiveservice";
+	public static final String KEY_GLOBAL	 = "global";
+
 
 	private HiveObjectType objectType = null;
 
-	public RangerHiveResource(HiveObjectType objectType, String databaseorUrl) {
-		this(objectType, databaseorUrl, null, null);
+	//FirstLevelResource => Database or URL or Hive Service or Global
+	//SecondLevelResource => Table or UDF
+	//ThirdLevelResource => column
+	public RangerHiveResource(HiveObjectType objectType, String firstLevelResource) {
+		this(objectType, firstLevelResource, null, null);
 	}
 
-	public RangerHiveResource(HiveObjectType objectType, String databaseorUrl, String tableOrUdf) {
-		this(objectType, databaseorUrl, tableOrUdf, null);
+	public RangerHiveResource(HiveObjectType objectType, String firstLevelResource, String secondLevelResource) {
+		this(objectType, firstLevelResource, secondLevelResource, null);
 	}
 	
-	public RangerHiveResource(HiveObjectType objectType, String databaseorUrl, String tableOrUdf, String column) {
+	public RangerHiveResource(HiveObjectType objectType, String firstLevelResource, String secondLevelResource, String thirdLevelResource) {
 		this.objectType = objectType;
 
 		switch(objectType) {
 			case DATABASE:
-				if (databaseorUrl == null) {
-					databaseorUrl = "*";
-				}
-				setValue(KEY_DATABASE, databaseorUrl);
+				setValue(KEY_DATABASE, firstLevelResource);
 			break;
 
 			case FUNCTION:
-				if (databaseorUrl == null) {
-					databaseorUrl = "";
+				if (firstLevelResource == null) {
+					firstLevelResource = "";
 				}
-				setValue(KEY_DATABASE, databaseorUrl);
-				setValue(KEY_UDF, tableOrUdf);
+				setValue(KEY_DATABASE, firstLevelResource);
+				setValue(KEY_UDF, secondLevelResource);
 			break;
 
 			case COLUMN:
-				setValue(KEY_DATABASE, databaseorUrl);
-				setValue(KEY_TABLE, tableOrUdf);
-				setValue(KEY_COLUMN, column);
+				setValue(KEY_DATABASE, firstLevelResource);
+				setValue(KEY_TABLE, secondLevelResource);
+				setValue(KEY_COLUMN, thirdLevelResource);
 			break;
 
 			case TABLE:
 			case VIEW:
 			case INDEX:
 			case PARTITION:
-				setValue(KEY_DATABASE, databaseorUrl);
-				setValue(KEY_TABLE, tableOrUdf);
+				setValue(KEY_DATABASE, firstLevelResource);
+				setValue(KEY_TABLE, secondLevelResource);
 			break;
 
 			case URI:
-				setValue(KEY_URL,databaseorUrl);
+				setValue(KEY_URL,firstLevelResource);
+			break;
+
+			case SERVICE_NAME:
+				if (firstLevelResource == null) {
+					firstLevelResource = "";
+				}
+				setValue(KEY_HIVESERVICE,firstLevelResource);
+			break;
+
+			case GLOBAL:
+				if (firstLevelResource == null) {
+					firstLevelResource = KEY_GLOBAL;
+					//There is no resource name associated to global operations
+				}
+				setValue(KEY_GLOBAL,firstLevelResource);
 			break;
 
 			case NONE:
@@ -107,4 +125,8 @@ public class RangerHiveResource extends RangerAccessResourceImpl {
 	public String getUrl() {
 		return (String) getValue(KEY_URL);
 	}
+
+	public String getHiveService() {
+		return (String) getValue(KEY_HIVESERVICE);
+	}
 }
