@@ -40,6 +40,7 @@ import org.apache.hadoop.security.UserGroupInformation;
 import org.apache.ranger.plugin.util.*;
 import org.apache.ranger.audit.provider.MiscUtil;
 import org.apache.ranger.authorization.hadoop.config.RangerConfiguration;
+import org.apache.ranger.authorization.utils.StringUtil;
 import org.glassfish.jersey.client.ClientProperties;
 
 import com.google.gson.Gson;
@@ -49,7 +50,7 @@ import com.google.gson.JsonDeserializer;
 import com.google.gson.JsonElement;
 import com.google.gson.JsonParseException;
 
-public class RangerAdminJersey2RESTClient implements RangerAdminClient {
+public class RangerAdminJersey2RESTClient extends AbstractRangerAdminClient {
 
 	// none of the members are public -- this is only for testability.  None of these is meant to be accessible
 	private static final Log LOG = LogFactory.getLog(RangerAdminJersey2RESTClient.class);
@@ -59,10 +60,11 @@ public class RangerAdminJersey2RESTClient implements RangerAdminClient {
 	volatile Client _client = null;
 	SSLContext _sslContext = null;
 	HostnameVerifier _hv;
-	String _baseUrl = null;
+	String _baseUrl = "";
 	String _sslConfigFileName = null;
 	String _serviceName = null;
 	String _clusterName = null;
+	String _supportsPolicyDeltas = null;
 	String _pluginId = null;
 	int	   _restClientConnTimeOutMs;
 	int	   _restClientReadTimeOutMs;
@@ -75,14 +77,27 @@ public class RangerAdminJersey2RESTClient implements RangerAdminClient {
 
 		_serviceName = serviceName;
 		_pluginId = _utils.getPluginId(serviceName, appId);
-		_baseUrl = _utils.getPolicyRestUrl(configPropertyPrefix);
+		String tmpUrl = _utils.getPolicyRestUrl(configPropertyPrefix);
 		_sslConfigFileName = _utils.getSsslConfigFileName(configPropertyPrefix);
-		_isSSL = _utils.isSsl(_baseUrl);
 		_restClientConnTimeOutMs = RangerConfiguration.getInstance().getInt(configPropertyPrefix + ".policy.rest.client.connection.timeoutMs", 120 * 1000);
 		_restClientReadTimeOutMs = RangerConfiguration.getInstance().getInt(configPropertyPrefix + ".policy.rest.client.read.timeoutMs", 30 * 1000);
-		_clusterName = RangerConfiguration.getInstance().get(configPropertyPrefix + ".ambari.cluster.name", "");
+		_clusterName = RangerConfiguration.getInstance().get(configPropertyPrefix + ".access.cluster.name", "");
+		if(StringUtil.isEmpty(_clusterName)){
+			_clusterName = RangerConfiguration.getInstance().get(configPropertyPrefix + ".ambari.cluster.name", "");
+		}
+		_supportsPolicyDeltas = RangerConfiguration.getInstance().get(configPropertyPrefix + ".policy.rest.supports.policy.deltas", "false");
+		if (!"true".equalsIgnoreCase(_supportsPolicyDeltas)) {
+			_supportsPolicyDeltas = "false";
+		}
 
-		LOG.info("Init params: " + String.format("Base URL[%s], SSL Congig filename[%s], ServiceName=[%s]", _baseUrl, _sslConfigFileName, _serviceName));
+		if (!StringUtils.isEmpty(tmpUrl)) {
+			_baseUrl = tmpUrl.trim();
+			if (_baseUrl.endsWith("/")) {
+		        _baseUrl = _baseUrl.substring(0, _baseUrl.length() - 1);
+		    }
+		 }
+		_isSSL = _utils.isSsl(_baseUrl);
+		LOG.info("Init params: " + String.format("Base URL[%s], SSL Congig filename[%s], ServiceName=[%s], SupportsPolicyDeltas=[%s]", _baseUrl, _sslConfigFileName, _serviceName, _supportsPolicyDeltas));
 		
 		_client = getClient();
 		_client.property(ClientProperties.CONNECT_TIMEOUT, _restClientConnTimeOutMs);
@@ -119,6 +134,7 @@ public class RangerAdminJersey2RESTClient implements RangerAdminClient {
 							.queryParam(RangerRESTUtils.REST_PARAM_LAST_ACTIVATION_TIME, Long.toString(lastActivationTimeInMillis))
 							.queryParam(RangerRESTUtils.REST_PARAM_PLUGIN_ID, _pluginId)
 							.queryParam(RangerRESTUtils.REST_PARAM_CLUSTER_NAME, _clusterName)
+							.queryParam(RangerRESTUtils.REST_PARAM_SUPPORTS_POLICY_DELTAS, _supportsPolicyDeltas)
 							.request(MediaType.APPLICATION_JSON_TYPE)
 							.get();
 				}
@@ -134,6 +150,7 @@ public class RangerAdminJersey2RESTClient implements RangerAdminClient {
 					.queryParam(RangerRESTUtils.REST_PARAM_LAST_ACTIVATION_TIME, Long.toString(lastActivationTimeInMillis))
 					.queryParam(RangerRESTUtils.REST_PARAM_PLUGIN_ID, _pluginId)
 					.queryParam(RangerRESTUtils.REST_PARAM_CLUSTER_NAME, _clusterName)
+					.queryParam(RangerRESTUtils.REST_PARAM_SUPPORTS_POLICY_DELTAS, _supportsPolicyDeltas)
 					.request(MediaType.APPLICATION_JSON_TYPE)
 					.get();
 		}
