@@ -111,7 +111,6 @@ public class RangerAtlasAuthorizer implements AtlasAuthorizer {
             rangerRequest.setClientIPAddress(request.getClientIPAddress());
             rangerRequest.setAccessTime(request.getAccessTime());
             rangerRequest.setAction(action);
-            rangerRequest.setClusterName(getClusterName());
 
             ret = checkAccess(rangerRequest);
         } finally {
@@ -183,7 +182,6 @@ public class RangerAtlasAuthorizer implements AtlasAuthorizer {
             RangerAccessRequestImpl rangerRequest = new RangerAccessRequestImpl(rangerResource, action, request.getUser(), request.getUserGroups());
             rangerRequest.setClientIPAddress(request.getClientIPAddress());
             rangerRequest.setAccessTime(request.getAccessTime());
-            rangerRequest.setClusterName(getClusterName());
             rangerRequest.setAction(action);
 
 
@@ -229,7 +227,6 @@ public class RangerAtlasAuthorizer implements AtlasAuthorizer {
             RangerAccessRequestImpl rangerRequest = new RangerAccessRequestImpl(rangerResource, action, request.getUser(), request.getUserGroups());
             rangerRequest.setClientIPAddress(request.getClientIPAddress());
             rangerRequest.setAccessTime(request.getAccessTime());
-            rangerRequest.setClusterName(getClusterName());
             rangerRequest.setAction(action);
 
 
@@ -314,12 +311,6 @@ public class RangerAtlasAuthorizer implements AtlasAuthorizer {
         }
     }
 
-    private String getClusterName() {
-        RangerBasePlugin plugin = atlasPlugin;
-
-        return plugin != null ? plugin.getClusterName() : null;
-    }
-
     private RangerServiceDef getServiceDef() {
         RangerBasePlugin plugin = atlasPlugin;
 
@@ -340,17 +331,17 @@ public class RangerAtlasAuthorizer implements AtlasAuthorizer {
             final String                   classification = request.getClassification() != null ? request.getClassification().getTypeName() : null;
             final RangerAccessRequestImpl  rangerRequest  = new RangerAccessRequestImpl();
             final RangerAccessResourceImpl rangerResource = new RangerAccessResourceImpl();
+            final String                   ownerUser      = request.getEntity() != null ? (String) request.getEntity().getAttribute(RESOURCE_ENTITY_OWNER) : null;
 
             rangerResource.setValue(RESOURCE_ENTITY_TYPE, entityTypes);
             rangerResource.setValue(RESOURCE_ENTITY_ID, entityId);
-
+            rangerResource.setOwnerUser(ownerUser);
             rangerRequest.setAccessType(action);
             rangerRequest.setAction(action);
             rangerRequest.setUser(request.getUser());
             rangerRequest.setUserGroups(request.getUserGroups());
             rangerRequest.setClientIPAddress(request.getClientIPAddress());
             rangerRequest.setAccessTime(request.getAccessTime());
-            rangerRequest.setClusterName(getClusterName());
             rangerRequest.setResource(rangerResource);
 
             if (StringUtils.isNotEmpty(classification)) {
