@@ -144,6 +144,13 @@ admin_keytab=$(get_prop 'admin_keytab' $PROPFILE)
 lookup_principal=$(get_prop 'lookup_principal' $PROPFILE)
 lookup_keytab=$(get_prop 'lookup_keytab' $PROPFILE)
 hadoop_conf=$(get_prop 'hadoop_conf' $PROPFILE)
+audit_solr_collection_name=$(get_prop 'audit_solr_collection_name' $PROPFILE)
+audit_solr_config_name=$(get_prop 'audit_solr_config_name' $PROPFILE)
+audit_solr_no_shards=$(get_prop 'audit_solr_no_shards' $PROPFILE)
+audit_solr_no_replica=$(get_prop 'audit_solr_no_replica' $PROPFILE)
+audit_solr_max_shards_per_node=$(get_prop 'audit_solr_max_shards_per_node' $PROPFILE)
+audit_solr_acl_user_list_sasl=$(get_prop 'audit_solr_acl_user_list_sasl' $PROPFILE)
+
 
 DB_HOST="${db_host}"
 
@@ -214,7 +221,7 @@ getPropertyFromFile(){
 #Update Properties to File
 #$1 -> propertyName $2 -> newPropertyValue $3 -> fileName
 updatePropertyToFilePy(){
-        python update_property.py $1 $2 $3
+    python update_property.py $1 "${2}" $3
         check_ret_status $? "Update property failed for: " $1
 }
 
@@ -422,6 +429,50 @@ update_properties() {
                 updatePropertyToFilePy $propertyName $newPropertyValue $to_file_ranger
 	fi
 	
+        if [ "${audit_solr_collection_name}" != "" ]
+        then
+               propertyName=ranger.audit.solr.collection.name
+               newPropertyValue="${audit_solr_collection_name}"
+               updatePropertyToFilePy $propertyName $newPropertyValue $to_file_ranger
+        fi
+
+        if [ "${audit_solr_config_name}" != "" ]
+        then
+               propertyName=ranger.audit.solr.config.name
+               newPropertyValue="${audit_solr_config_name}"
+               updatePropertyToFilePy $propertyName $newPropertyValue $to_file_ranger
+        fi
+
+        if [ "${audit_solr_no_shards}" != "" ]
+        then
+               propertyName=ranger.audit.solr.no.shards
+               newPropertyValue="${audit_solr_no_shards}"
+               updatePropertyToFilePy $propertyName $newPropertyValue $to_file_ranger
+        fi
+
+
+        if [ "${audit_solr_max_shards_per_node}" != "" ]
+        then
+               propertyName=ranger.audit.solr.max.shards.per.node
+               newPropertyValue="${audit_solr_max_shards_per_node}"
+               updatePropertyToFilePy $propertyName $newPropertyValue $to_file_ranger
+        fi
+
+        if [ "${audit_solr_no_replica}" != "" ]
+        then
+               propertyName=ranger.audit.solr.no.replica
+               newPropertyValue="${audit_solr_no_replica}"
+               updatePropertyToFilePy $propertyName $newPropertyValue $to_file_ranger
+        fi
+	
+	if [ "${audit_solr_acl_user_list_sasl}" != "" ]
+        then
+               propertyName=ranger.audit.solr.acl.user.list.sasl
+               newPropertyValue="${audit_solr_acl_user_list_sasl}"
+               updatePropertyToFilePy $propertyName $newPropertyValue $to_file_ranger
+        fi
+
+
 	if [ "${spnego_keytab}" != "" ]
 	then
                 propertyName=ranger.spnego.kerberos.keytab
@@ -518,6 +569,10 @@ update_properties() {
 		propertyName=ranger.jpa.audit.jdbc.driver
 		newPropertyValue="net.sf.log4jdbc.DriverSpy"
 		updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+
+		propertyName=ranger.jpa.jdbc.preferredtestquery
+		newPropertyValue="select 1;"
+		updatePropertyToFilePy $propertyName "${newPropertyValue}" $to_file_default
 	fi
 	if [ "${DB_FLAVOR}" == "ORACLE" ]
 	then
@@ -548,6 +603,10 @@ update_properties() {
 		propertyName=ranger.jpa.audit.jdbc.driver
 		newPropertyValue="oracle.jdbc.OracleDriver"
 		updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+
+		propertyName=ranger.jpa.jdbc.preferredtestquery
+		newPropertyValue="select 1 from dual;"
+		updatePropertyToFilePy $propertyName "${newPropertyValue}" $to_file_default
 	fi
 	if [ "${DB_FLAVOR}" == "POSTGRES" ]
 	then
@@ -573,6 +632,10 @@ update_properties() {
 		propertyName=ranger.jpa.audit.jdbc.driver
 		newPropertyValue="org.postgresql.Driver"
 		updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+
+		propertyName=ranger.jpa.jdbc.preferredtestquery
+		newPropertyValue="select 1;"
+		updatePropertyToFilePy $propertyName "${newPropertyValue}" $to_file_default
 	fi
 
 	if [ "${DB_FLAVOR}" == "MSSQL" ]
@@ -596,6 +659,10 @@ update_properties() {
 		propertyName=ranger.jpa.audit.jdbc.driver
 		newPropertyValue="com.microsoft.sqlserver.jdbc.SQLServerDriver"
 		updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+
+		propertyName=ranger.jpa.jdbc.preferredtestquery
+		newPropertyValue="select 1;"
+		updatePropertyToFilePy $propertyName "${newPropertyValue}" $to_file_default
 	fi
 
 	if [ "${DB_FLAVOR}" == "SQLA" ]
@@ -619,6 +686,10 @@ update_properties() {
 		propertyName=ranger.jpa.audit.jdbc.driver
 		newPropertyValue="sap.jdbc4.sqlanywhere.IDriver"
 		updatePropertyToFilePy $propertyName $newPropertyValue $to_file_default
+
+		propertyName=ranger.jpa.jdbc.preferredtestquery
+		newPropertyValue="select 1;"
+		updatePropertyToFilePy $propertyName "${newPropertyValue}" $to_file_default
 	fi
 
 	if [ "${audit_store}" == "solr" ]
@@ -1384,7 +1455,7 @@ setup_install_files(){
 	fi
 }
 python_command_for_change_password(){
-        $PYTHON_COMMAND_INVOKER db_setup.py -changepassword  "${1}" "${2}" "${3}"
+        $PYTHON_COMMAND_INVOKER db_setup.py -changepassword -pair "${1}" "${2}" "${3}" -pair "${4}" "${5}" "${6}" -pair "${7}" "${8}" "${9}" -pair "${10}" "${11}" "${12}"
 }
 validateDefaultUsersPassword(){
         if [ "${2}" == "" ]
@@ -1399,38 +1470,47 @@ validateDefaultUsersPassword(){
 }
 
 change_default_users_password(){
-        if [ "${rangerAdmin_password}" != "admin" ]
-        then
-                python_command_for_change_password  'admin' 'admin' "${rangerAdmin_password}"
-                if [ "$?" != "0" ]
-                then
-                        exit 1
-                fi
-        fi
-        if [ "${rangerTagsync_password}" != "rangertagsync" ]
-        then
-                python_command_for_change_password 'rangertagsync' 'rangertagsync' "${rangerTagsync_password}"
-                if [ "$?" != "0" ]
-                then
-                        exit 1
-                fi
-        fi
-        if [ "${rangerUsersync_password}" != "rangerusersync" ]
-        then
-                python_command_for_change_password 'rangerusersync' 'rangerusersync' "${rangerUsersync_password}"
-                if [ "$?" != "0" ]
-                then
-                        exit 1
-                fi
-        fi
-        if [ "${keyadmin_password}" != "keyadmin" ]
-        then
-                python_command_for_change_password 'keyadmin' 'keyadmin' "${keyadmin_password}"
-                if [ "$?" != "0" ]
-                then
-                        exit 1
-                fi
-        fi
+	if [ "${rangerAdmin_password}" != "admin" ] && [ "${rangerTagsync_password}" != "rangertagsync" ] && [ "${rangerUsersync_password}" != "rangerusersync" ] && [ "${keyadmin_password}" != "keyadmin" ]
+	then
+		python_command_for_change_password  'admin' 'admin' "${rangerAdmin_password}" 'rangertagsync' 'rangertagsync' "${rangerTagsync_password}" 'rangerusersync' 'rangerusersync' "${rangerUsersync_password}" 'keyadmin' 'keyadmin' "${keyadmin_password}"
+		if [ "$?" != "0" ]
+		then
+			exit 1
+		fi
+	else
+		if [ "${rangerAdmin_password}" != "admin" ]
+		then
+			python_command_for_change_password  'admin' 'admin' "${rangerAdmin_password}"
+			if [ "$?" != "0" ]
+			then
+				exit 1
+			fi
+		fi
+		if [ "${rangerTagsync_password}" != "rangertagsync" ]
+		then
+			python_command_for_change_password 'rangertagsync' 'rangertagsync' "${rangerTagsync_password}"
+			if [ "$?" != "0" ]
+			then
+				exit 1
+			fi
+		fi
+		if [ "${rangerUsersync_password}" != "rangerusersync" ]
+		then
+			python_command_for_change_password 'rangerusersync' 'rangerusersync' "${rangerUsersync_password}"
+			if [ "$?" != "0" ]
+			then
+				exit 1
+			fi
+		fi
+		if [ "${keyadmin_password}" != "keyadmin" ]
+		then
+			python_command_for_change_password 'keyadmin' 'keyadmin' "${keyadmin_password}"
+			if [ "$?" != "0" ]
+			then
+				exit 1
+			fi
+		fi
+	fi
 }
 log " --------- Running Ranger PolicyManager Web Application Install Script --------- "
 log "[I] uname=`uname`"
@@ -1447,10 +1527,10 @@ check_python_command
 check_ranger_version
 if [ "$?" != "0" ]
 then
-        validateDefaultUsersPassword 'admin' "${rangerAdmin_password}"
-        validateDefaultUsersPassword 'rangertagsync' "${rangerTagsync_password}"
-        validateDefaultUsersPassword 'rangerusersync' "${rangerUsersync_password}"
-        validateDefaultUsersPassword 'keyadmin' "${keyadmin_password}"
+	validateDefaultUsersPassword 'admin' "${rangerAdmin_password}"
+	validateDefaultUsersPassword 'rangertagsync' "${rangerTagsync_password}"
+	validateDefaultUsersPassword 'rangerusersync' "${rangerUsersync_password}"
+	validateDefaultUsersPassword 'keyadmin' "${keyadmin_password}"
 fi
 run_dba_steps
 if [ "$?" == "0" ]
@@ -1474,10 +1554,10 @@ then
 	if [ "$?" == "0" ]
 	then
 		$PYTHON_COMMAND_INVOKER db_setup.py -javapatch
-                if [ "$?" == "0" ]
-                then
-                        change_default_users_password
-                fi
+		if [ "$?" == "0" ]
+		then
+			change_default_users_password
+		fi
 	else
 		exit 1
 	fi
