@@ -44,6 +44,7 @@ import org.apache.ranger.common.JSONUtil;
 import org.apache.ranger.common.MessageEnums;
 import org.apache.ranger.common.PropertiesUtil;
 import org.apache.ranger.common.RangerCommonEnums;
+import org.apache.ranger.common.RangerConstants;
 import org.apache.ranger.common.SearchCriteria;
 import org.apache.ranger.common.StringUtil;
 import org.apache.ranger.db.RangerDaoManager;
@@ -55,6 +56,7 @@ import org.apache.ranger.entity.XXTrxLog;
 import org.apache.ranger.entity.XXUser;
 import org.apache.ranger.plugin.model.RangerPluginInfo;
 import org.apache.ranger.plugin.util.RangerRESTUtils;
+import org.apache.ranger.plugin.util.SearchFilter;
 import org.apache.ranger.service.*;
 import org.apache.ranger.solr.SolrAccessAuditsService;
 import org.apache.ranger.util.RestUtil;
@@ -118,6 +120,9 @@ public class AssetMgr extends AssetMgrBase {
 	@Autowired
 	XUgsyncAuditInfoService xUgsyncAuditInfoService;
 
+	@Autowired
+	ServiceMgr serviceMgr;
+
 	private static final Logger logger = Logger.getLogger(AssetMgr.class);
 
 	public File getXResourceFile(Long id, String fileType) {
@@ -656,7 +661,7 @@ public class AssetMgr extends AssetMgrBase {
 		return ret;
 	}
 
-	public void createPluginInfo(String serviceName, String pluginId, HttpServletRequest request, int entityType, Long downloadedVersion, long lastKnownVersion, long lastActivationTime, int httpCode) {
+	public void createPluginInfo(String serviceName, String pluginId, HttpServletRequest request, int entityType, Long downloadedVersion, long lastKnownVersion, long lastActivationTime, int httpCode, String clusterName) {
 		RangerRESTUtils restUtils = new RangerRESTUtils();
 
 		final String ipAddress = getRemoteAddress(request);
@@ -691,10 +696,10 @@ public class AssetMgr extends AssetMgrBase {
 			pluginSvcVersionInfo.setTagDownloadTime(new Date().getTime());
 		}
 
-		createOrUpdatePluginInfo(pluginSvcVersionInfo, entityType == RangerPluginInfo.ENTITY_TYPE_POLICIES, httpCode);
+		createOrUpdatePluginInfo(pluginSvcVersionInfo, entityType == RangerPluginInfo.ENTITY_TYPE_POLICIES, httpCode, clusterName);
 	}
 
-	private void createOrUpdatePluginInfo(final RangerPluginInfo pluginInfo, final boolean isPolicyDownloadRequest, final int httpCode) {
+	private void createOrUpdatePluginInfo(final RangerPluginInfo pluginInfo, final boolean isPolicyDownloadRequest, final int httpCode, String clusterName) {
 		if (logger.isDebugEnabled()) {
 			logger.debug("==> createOrUpdatePluginInfo(pluginInfo = " + pluginInfo + ", isPolicyDownloadRequest = " + isPolicyDownloadRequest + ", httpCode = " + httpCode + ")");
 		}
@@ -715,7 +720,7 @@ public class AssetMgr extends AssetMgrBase {
 			Runnable commitWork = new Runnable() {
 				@Override
 				public void run() {
-					doCreateOrUpdateXXPluginInfo(pluginInfo, isPolicyDownloadRequest, isTagVersionResetNeeded);
+					doCreateOrUpdateXXPluginInfo(pluginInfo, isPolicyDownloadRequest, isTagVersionResetNeeded, clusterName);
 				}
 			};
 			activityLogger.commitAfterTransactionComplete(commitWork);
@@ -733,7 +738,7 @@ public class AssetMgr extends AssetMgrBase {
 				commitWork = new Runnable() {
 					@Override
 					public void run() {
-						doCreateOrUpdateXXPluginInfo(pluginInfo, isPolicyDownloadRequest, false);
+						doCreateOrUpdateXXPluginInfo(pluginInfo, isPolicyDownloadRequest, false, clusterName);
 					}
 				};
 			}
@@ -741,7 +746,7 @@ public class AssetMgr extends AssetMgrBase {
 
 		} else {
 			isTagVersionResetNeeded = false;
-			doCreateOrUpdateXXPluginInfo(pluginInfo, isPolicyDownloadRequest, isTagVersionResetNeeded);
+			doCreateOrUpdateXXPluginInfo(pluginInfo, isPolicyDownloadRequest, isTagVersionResetNeeded, clusterName);
 		}
 		if (logger.isDebugEnabled()) {
 			logger.debug("<== createOrUpdatePluginInfo(pluginInfo = " + pluginInfo + ", isPolicyDownloadRequest = " + isPolicyDownloadRequest + ", httpCode = " + httpCode + ")");
@@ -749,8 +754,9 @@ public class AssetMgr extends AssetMgrBase {
 
 	}
 
-	private XXPluginInfo doCreateOrUpdateXXPluginInfo(RangerPluginInfo pluginInfo, final boolean isPolicyDownloadRequest, final boolean isTagVersionResetNeeded) {
+	private XXPluginInfo doCreateOrUpdateXXPluginInfo(RangerPluginInfo pluginInfo, final boolean isPolicyDownloadRequest, final boolean isTagVersionResetNeeded, String clusterName) {
 		XXPluginInfo ret = null;
+		Map<String, String> infoMap = null;
 
 		if (StringUtils.isNotBlank(pluginInfo.getServiceName())) {
 
@@ -758,6 +764,11 @@ public class AssetMgr extends AssetMgrBase {
 					pluginInfo.getHostName(), pluginInfo.getAppType());
 
 			if (xObj == null) {
+				infoMap = pluginInfo.getInfo();
+				if(!stringUtil.isEmpty(clusterName) && infoMap != null ) {
+					infoMap.put(SearchFilter.CLUSTER_NAME, clusterName);
+					pluginInfo.setInfo(infoMap);
+				}
 				// ranger-admin is restarted, plugin contains latest versions and no earlier record for this plug-in client
 				if (isPolicyDownloadRequest) {
 					if (pluginInfo.getPolicyDownloadedVersion() != null && pluginInfo.getPolicyDownloadedVersion().equals(pluginInfo.getPolicyActiveVersion())) {
@@ -779,6 +790,14 @@ public class AssetMgr extends AssetMgrBase {
 				boolean needsUpdating = false;
 
 				RangerPluginInfo dbObj = pluginInfoService.populateViewObject(xObj);
+
+				infoMap = dbObj.getInfo();
+				if (infoMap != null && !stringUtil.isEmpty(clusterName)) {
+					if(!stringUtil.isEmpty(infoMap.get(SearchFilter.CLUSTER_NAME)) && !stringUtil.equals(infoMap.get(SearchFilter.CLUSTER_NAME) , clusterName) ) {
+						infoMap.put(SearchFilter.CLUSTER_NAME, clusterName);
+						needsUpdating = true;
+					}
+				}
 				if (!dbObj.getIpAddress().equals(pluginInfo.getIpAddress())) {
 					dbObj.setIpAddress(pluginInfo.getIpAddress());
 					needsUpdating = true;
@@ -965,6 +984,37 @@ public class AssetMgr extends AssetMgrBase {
         } else if (!"asc".equalsIgnoreCase(searchCriteria.getSortType()) && !"desc".equalsIgnoreCase(searchCriteria.getSortType())) {
             searchCriteria.setSortType("desc");
         }
+
+        if (!xaBizUtil.isAdmin()) {
+			Long userId = xaBizUtil.getXUserId();
+	        List<String> userZones = rangerDaoManager.getXXSecurityZoneDao().findZoneNamesByUserId(userId);
+			Set<String> zoneNameSet = new HashSet<String>(userZones);
+
+			VXGroupList groupList = xUserMgr.getXUserGroups(userId);
+			for (VXGroup group : groupList.getList()) {
+				List<String> userGroupZones = rangerDaoManager.getXXSecurityZoneDao().findZoneNamesByGroupId(group.getId());
+				for (String zoneName : userGroupZones) {
+					zoneNameSet.add(zoneName);
+				}
+			}
+
+			List<String> zoneNameList = (List<String>) searchCriteria.getParamValue("zoneName");
+
+			if ((zoneNameList == null || zoneNameList.isEmpty())) {
+				if (!zoneNameSet.isEmpty()) {
+					searchCriteria.getParamList().put("zoneName", new ArrayList<String>(zoneNameSet));
+				} else {
+					searchCriteria.getParamList().put("zoneName", null);
+				}
+			} else if (!zoneNameList.isEmpty() && !zoneNameSet.isEmpty()) {
+				for (String znName : zoneNameList) {
+					if (!serviceMgr.isZoneAdmin(znName) && !serviceMgr.isZoneAuditor(znName)) {
+						throw restErrorUtil.createRESTException(HttpServletResponse.SC_FORBIDDEN, "User is not the zone admin or zone auditor of zone " + znName, true);
+					}
+				}
+			}
+        }
+
         if (RangerBizUtil.AUDIT_STORE_SOLR.equalsIgnoreCase(xaBizUtil.getAuditDBType())) {
             return solrAccessAuditsService.searchXAccessAudits(searchCriteria);
         } else {
@@ -972,7 +1022,6 @@ public class AssetMgr extends AssetMgrBase {
         }
     }
 
-
 	public VXTrxLogList getTransactionReport(String transactionId) {
 		List<XXTrxLog> xTrxLogList = rangerDaoManager.getXXTrxLog()
 				.findByTransactionId(transactionId);
@@ -1087,7 +1136,9 @@ public class AssetMgr extends AssetMgrBase {
     }
 
 	public VXUgsyncAuditInfoList getUgsyncAudits(SearchCriteria searchCriteria) {
-
+		if (!msBizUtil.hasModuleAccess(RangerConstants.MODULE_AUDIT)) {
+			throw restErrorUtil.createRESTException(HttpServletResponse.SC_FORBIDDEN, "User is not having permissions on the "+RangerConstants.MODULE_AUDIT+" module.", true);
+		}
 		if (searchCriteria == null) {
 			searchCriteria = new SearchCriteria();
 		}
