@@ -25,11 +25,13 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashSet;
+import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
 import javax.servlet.http.HttpServletResponse;
+import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.io.FilenameUtils;
 import org.apache.commons.io.IOCase;
 import org.apache.commons.lang.StringUtils;
@@ -1146,6 +1148,46 @@ public class RangerBizUtil {
 		}
 	}
 
+	public void createTrxLog(List<XXTrxLog> trxLogList, boolean flush) {
+		if (trxLogList == null) {
+			return;
+		}
+
+		UserSessionBase usb = ContextUtil.getCurrentUserSession();
+		Long authSessionId = null;
+		if (usb != null) {
+			authSessionId = ContextUtil.getCurrentUserSession().getSessionId();
+		}
+		if(guidUtil != null){
+		Long trxId = guidUtil.genLong();
+		for (XXTrxLog xTrxLog : trxLogList) {
+			if (xTrxLog != null) {
+				if ("Password".equalsIgnoreCase(StringUtil.trim(xTrxLog.getAttributeName()))) {
+					if (xTrxLog.getPreviousValue() != null
+							&& !xTrxLog.getPreviousValue().trim().isEmpty()
+							&& !"null".equalsIgnoreCase(xTrxLog
+									.getPreviousValue().trim())) {
+						xTrxLog.setPreviousValue(AppConstants.Masked_String);
+					}
+					if (xTrxLog.getNewValue() != null
+							&& !xTrxLog.getNewValue().trim().isEmpty()
+							&& !"null".equalsIgnoreCase(xTrxLog.getNewValue()
+									.trim())) {
+						xTrxLog.setNewValue(AppConstants.Masked_String);
+					}
+				}
+				xTrxLog.setTransactionId(trxId.toString());
+				if (authSessionId != null) {
+					xTrxLog.setSessionId("" + authSessionId);
+				}
+				xTrxLog.setSessionType("Spring Authenticated Session");
+				xTrxLog.setRequestId(trxId.toString());
+				daoManager.getXXTrxLog().create(xTrxLog, flush);
+			}
+		}
+		}
+	}
+
 	public static int getDBFlavor() {
 		String[] propertyNames = { "xa.db.flavor",
 									"ranger.jpa.jdbc.dialect",
@@ -1297,13 +1339,17 @@ public class RangerBizUtil {
 
 		if (!session.isKeyAdmin() && !session.isUserAdmin()) {
 			throw restErrorUtil.createRESTException(
-					"User is not allowed to update service-def, only Admin can create/update/delete " + objType,
+					"This user is not allowed this operation. Only users with Admin permission have access to this operation " + objType,
 					MessageEnums.OPER_NO_PERMISSION);
 		}
 	}
 
 	public void hasKMSPermissions(String objType, String implClassName) {
 		UserSessionBase session = ContextUtil.getCurrentUserSession();
+		if (session == null) {
+			throw restErrorUtil.createRESTException("UserSession cannot be null, only KeyAdmin can create/update/delete "
+					+ objType, MessageEnums.OPER_NO_PERMISSION);
+		}
 
 		if (session.isKeyAdmin() && !EmbeddedServiceDefsUtil.KMS_IMPL_CLASS_NAME.equals(implClassName)) {
 			throw restErrorUtil.createRESTException("KeyAdmin can create/update/delete only KMS " + objType,
@@ -1417,4 +1463,40 @@ public class RangerBizUtil {
                 }
         }
 
+	public boolean hasModuleAccess(String moduleName) {
+		UserSessionBase currentUserSession = ContextUtil.getCurrentUserSession();
+		if(currentUserSession == null) {
+			return false;
+		}
+		if(!currentUserSession.isUserAdmin() && !currentUserSession.isAuditUserAdmin()) {
+			if(!currentUserSession.getRangerUserPermission().getUserPermissions().contains(moduleName)) {
+				return false;
+			}
+		}
+		return true;
+	}
+
+	public void removeEmptyStrings(List<String> list) {
+		if(!CollectionUtils.isEmpty(list)) {
+			Iterator<String> i = list.iterator();
+			while (i.hasNext()){
+				String item = i.next();
+				if (item == null || StringUtils.isEmpty(StringUtils.trim(item))){
+					i.remove();
+			    }
+			}
+			trimAll(list);
+		}
+	}
+
+	public void trimAll(List<String> list) {
+		if(!CollectionUtils.isEmpty(list)) {
+			for (int i = 0; i < list.size(); i++) {
+				String item=list.get(i);
+				if(item.startsWith(" ") || item.endsWith(" ")) {
+					list.set(i, StringUtils.trim(item));
+				}
+			}
+		}
+	}
 }
