@@ -21,35 +21,26 @@ package org.apache.ranger.biz;
 
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
 import org.apache.commons.collections.CollectionUtils;
-import org.apache.commons.collections.MapUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.ranger.authorization.utils.JsonUtils;
 import org.apache.ranger.common.GUIDUtil;
 import org.apache.ranger.common.MessageEnums;
 import org.apache.ranger.common.RESTErrorUtil;
 import org.apache.ranger.common.RangerAdminTagEnricher;
 import org.apache.ranger.common.RangerServiceTagsCache;
 import org.apache.ranger.db.RangerDaoManager;
-import org.apache.ranger.entity.XXResourceDef;
 import org.apache.ranger.entity.XXService;
-import org.apache.ranger.entity.XXServiceDef;
 import org.apache.ranger.entity.XXServiceResource;
 import org.apache.ranger.entity.XXServiceVersionInfo;
 import org.apache.ranger.entity.XXTag;
-import org.apache.ranger.entity.XXTagAttribute;
-import org.apache.ranger.entity.XXTagAttributeDef;
-import org.apache.ranger.entity.XXServiceResourceElement;
-import org.apache.ranger.entity.XXServiceResourceElementValue;
 import org.apache.ranger.entity.XXTagResourceMap;
 import org.apache.ranger.plugin.model.*;
-import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyResource;
-import org.apache.ranger.plugin.model.RangerTagDef.RangerTagAttributeDef;
 import org.apache.ranger.plugin.model.validation.RangerValidityScheduleValidator;
 import org.apache.ranger.plugin.model.validation.ValidationFailureDetails;
 import org.apache.ranger.plugin.store.AbstractTagStore;
@@ -119,8 +110,6 @@ public class TagDBStore extends AbstractTagStore {
 
 		RangerTagDef ret = rangerTagDefService.create(tagDef);
 
-		createTagAttributeDefs(ret.getId(), tagDef.getAttributeDefs());
-
 		ret = rangerTagDefService.read(ret.getId());
 
 		if (LOG.isDebugEnabled()) {
@@ -140,6 +129,8 @@ public class TagDBStore extends AbstractTagStore {
 
 		if (existing == null) {
 			throw errorUtil.createRESTException("failed to update tag-def [" + tagDef.getName() + "], Reason: No TagDef found with id: [" + tagDef.getId() + "]", MessageEnums.DATA_NOT_UPDATABLE);
+		} else if (!existing.getName().equals(tagDef.getName())) {
+			throw errorUtil.createRESTException("Cannot change tag-def name; existing-name:[" + existing.getName() + "], new-name:[" + tagDef.getName() + "]", MessageEnums.DATA_NOT_UPDATABLE);
 		}
 
 		tagDef.setCreatedBy(existing.getCreatedBy());
@@ -149,10 +140,6 @@ public class TagDBStore extends AbstractTagStore {
 
 		RangerTagDef ret = rangerTagDefService.update(tagDef);
 
-		// TODO: delete attributes might fail; so instead of delete+create, following should be updated to deal with only attributes that changed
-		deleteTagAttributeDefs(ret.getId());
-		createTagAttributeDefs(ret.getId(), tagDef.getAttributeDefs());
-
 		ret = rangerTagDefService.read(ret.getId());
 
 		if (LOG.isDebugEnabled()) {
@@ -176,7 +163,6 @@ public class TagDBStore extends AbstractTagStore {
 					LOG.debug("Deleting tag-def [name=" + name + "; id=" + tagDef.getId() + "]");
 				}
 
-				deleteTagAttributeDefs(tagDef.getId());
 				rangerTagDefService.delete(tagDef);
 			}
 		}
@@ -196,7 +182,6 @@ public class TagDBStore extends AbstractTagStore {
 			RangerTagDef tagDef = rangerTagDefService.read(id);
 
 			if(tagDef != null) {
-				deleteTagAttributeDefs(tagDef.getId());
 				rangerTagDefService.delete(tagDef);
 			}
 		}
@@ -311,8 +296,6 @@ public class TagDBStore extends AbstractTagStore {
 
 		RangerTag ret = rangerTagService.create(tag);
 
-		createTagAttributes(ret.getId(), tag.getAttributes());
-
 		ret = rangerTagService.read(ret.getId());
 
 		if (LOG.isDebugEnabled()) {
@@ -343,9 +326,6 @@ public class TagDBStore extends AbstractTagStore {
 
 		RangerTag ret = rangerTagService.update(tag);
 
-		deleteTagAttributes(existing.getId());
-		createTagAttributes(existing.getId(), tag.getAttributes());
-
 		ret = rangerTagService.read(ret.getId());
 
 		if (LOG.isDebugEnabled()) {
@@ -363,8 +343,6 @@ public class TagDBStore extends AbstractTagStore {
 
 		RangerTag tag = rangerTagService.read(id);
 
-		deleteTagAttributes(id);
-
 		rangerTagService.delete(tag);
 
 		if (LOG.isDebugEnabled()) {
@@ -504,8 +482,6 @@ public class TagDBStore extends AbstractTagStore {
 
 		RangerServiceResource ret = rangerServiceResourceService.create(resource);
 
-		createResourceForServiceResource(ret.getId(), resource);
-
 		ret = rangerServiceResourceService.read(ret.getId());
 
 		if (LOG.isDebugEnabled()) {
@@ -533,9 +509,6 @@ public class TagDBStore extends AbstractTagStore {
 			resource.setResourceSignature(serializer.getSignature());
 		}
 
-		boolean serviceResourceElementUpdateNeeded =
-				!StringUtils.equals(existing.getResourceSignature(), resource.getResourceSignature());
-
 		resource.setCreatedBy(existing.getCreatedBy());
 		resource.setCreateTime(existing.getCreateTime());
 		resource.setGuid(existing.getGuid());
@@ -543,11 +516,6 @@ public class TagDBStore extends AbstractTagStore {
 
 		rangerServiceResourceService.update(resource);
 
-		if (serviceResourceElementUpdateNeeded) {
-			deleteResourceForServiceResource(existing.getId());
-			createResourceForServiceResource(existing.getId(), resource);
-		}
-
 		RangerServiceResource ret = rangerServiceResourceService.read(existing.getId());
 
 		if (LOG.isDebugEnabled()) {
@@ -557,6 +525,24 @@ public class TagDBStore extends AbstractTagStore {
 		return ret;
 	}
 
+
+	@Override
+	public void refreshServiceResource(Long resourceId) throws Exception {
+		XXServiceResource serviceResourceEntity = daoManager.getXXServiceResource().getById(resourceId);
+		String tagsText = null;
+
+		List<RangerTagResourceMap> tagResourceMaps = getTagResourceMapsForResourceId(resourceId);
+		if (tagResourceMaps != null) {
+			List<RangerTag> associatedTags = new ArrayList<>();
+			for (RangerTagResourceMap element : tagResourceMaps) {
+				associatedTags.add(getTag(element.getTagId()));
+			}
+			tagsText = JsonUtils.listToJson(associatedTags);
+		}
+		serviceResourceEntity.setTags(tagsText);
+		daoManager.getXXServiceResource().update(serviceResourceEntity);
+	}
+
 	@Override
 	public void deleteServiceResource(Long id) throws Exception {
 		if (LOG.isDebugEnabled()) {
@@ -566,7 +552,6 @@ public class TagDBStore extends AbstractTagStore {
 		RangerServiceResource resource = getServiceResource(id);
 
 		if(resource != null) {
-			deleteResourceForServiceResource(resource.getId());
 			rangerServiceResourceService.delete(resource);
 		}
 
@@ -584,7 +569,6 @@ public class TagDBStore extends AbstractTagStore {
 		RangerServiceResource resource = getServiceResourceByGuid(guid);
 
 		if(resource != null) {
-			deleteResourceForServiceResource(resource.getId());
 			rangerServiceResourceService.delete(resource);
 		}
 
@@ -725,6 +709,9 @@ public class TagDBStore extends AbstractTagStore {
 
 		RangerTagResourceMap ret = rangerTagResourceMapService.create(tagResourceMap);
 
+		// We also need to update tags stored with the resource
+		refreshServiceResource(tagResourceMap.getResourceId());
+
 		if (LOG.isDebugEnabled()) {
 			LOG.debug("<== TagDBStore.createTagResourceMap(" + tagResourceMap + "): " + ret);
 		}
@@ -747,6 +734,8 @@ public class TagDBStore extends AbstractTagStore {
 		if (tag.getOwner() == RangerTag.OWNER_SERVICERESOURCE) {
 			deleteTag(tagId);
 		}
+		// We also need to update tags stored with the resource
+		refreshServiceResource(tagResourceMap.getResourceId());
 
 		if (LOG.isDebugEnabled()) {
 			LOG.debug("<== TagDBStore.deleteTagResourceMap(" + id + ")");
@@ -1002,31 +991,7 @@ public class TagDBStore extends AbstractTagStore {
 		Map<Long, RangerTagDef> tagDefMap = tagDBRetriever.getTagDefs();
 		Map<Long, RangerTag> tagMap = tagDBRetriever.getTags();
 		List<RangerServiceResource> resources = tagDBRetriever.getServiceResources();
-		List<RangerTagResourceMap> tagResourceMaps = tagDBRetriever.getTagResourceMaps();
-
-		Map<Long, List<Long>> resourceToTagIds = new HashMap<Long, List<Long>>();
-
-		if (CollectionUtils.isNotEmpty(tagResourceMaps)) {
-			Long resourceId = null;
-			List<Long> tagIds = null;
-
-			for (RangerTagResourceMap tagResourceMap : tagResourceMaps) {
-				if (!tagResourceMap.getResourceId().equals(resourceId)) {
-					if (resourceId != null) {
-						resourceToTagIds.put(resourceId, tagIds);
-					}
-
-					resourceId = tagResourceMap.getResourceId();
-					tagIds = new ArrayList<Long>();
-				}
-
-				tagIds.add(tagResourceMap.getTagId());
-			}
-
-			if (resourceId != null) {
-				resourceToTagIds.put(resourceId, tagIds);
-			}
-		}
+		Map<Long, List<Long>> resourceToTagIds = tagDBRetriever.getResourceToTagIds();
 
 		ret = new ServiceTags();
 
@@ -1045,159 +1010,6 @@ public class TagDBStore extends AbstractTagStore {
 
 	}
 
-	private List<XXTagAttributeDef> createTagAttributeDefs(Long tagDefId, List<RangerTagAttributeDef> tagAttrDefList) {
-		if (LOG.isDebugEnabled()) {
-			LOG.debug("==> TagDBStore.createTagAttributeDefs(" + tagDefId + ", attributeDefCount=" + (tagAttrDefList == null ? 0 : tagAttrDefList.size()) + ")");
-		}
-
-		if (tagDefId == null) {
-			throw errorUtil.createRESTException("TagDBStore.createTagAttributeDefs(): Error creating tag-attr def. tagDefId can not be null.", MessageEnums.ERROR_CREATING_OBJECT);
-		}
-
-		List<XXTagAttributeDef> ret = new ArrayList<XXTagAttributeDef>();
-
-		if (CollectionUtils.isNotEmpty(tagAttrDefList)) {
-			for (RangerTagDef.RangerTagAttributeDef attrDef : tagAttrDefList) {
-				XXTagAttributeDef xAttrDef = new XXTagAttributeDef();
-
-				xAttrDef.setTagDefId(tagDefId);
-				xAttrDef.setName(attrDef.getName());
-				xAttrDef.setType(attrDef.getType());
-				xAttrDef = rangerAuditFields.populateAuditFieldsForCreate(xAttrDef);
-
-				xAttrDef = daoManager.getXXTagAttributeDef().create(xAttrDef);
-
-				ret.add(xAttrDef);
-			}
-		}
-
-		if (LOG.isDebugEnabled()) {
-			LOG.debug("<== TagDBStore.createTagAttributeDefs(" + tagDefId + ", attributeDefCount=" + (tagAttrDefList == null ? 0 : tagAttrDefList.size()) + "): retCount=" + ret.size());
-		}
-
-		return ret;
-	}
-
-	private void deleteTagAttributeDefs(Long tagDefId) {
-		if (LOG.isDebugEnabled()) {
-			LOG.debug("==> TagDBStore.deleteTagAttributeDefs(" + tagDefId + ")");
-		}
-
-		if (tagDefId != null) {
-			List<XXTagAttributeDef> tagAttrDefList = daoManager.getXXTagAttributeDef().findByTagDefId(tagDefId);
-
-			if (CollectionUtils.isNotEmpty(tagAttrDefList)) {
-				for (XXTagAttributeDef xAttrDef : tagAttrDefList) {
-					if (LOG.isDebugEnabled()) {
-						LOG.debug("Deleting tag-attribute def [name=" + xAttrDef.getName() + "; id=" + xAttrDef.getId() + "]");
-					}
-					daoManager.getXXTagAttributeDef().remove(xAttrDef);
-				}
-			}
-		}
-
-		if (LOG.isDebugEnabled()) {
-			LOG.debug("<== TagDBStore.deleteTagAttributeDefs(" + tagDefId + ")");
-		}
-	}
-
-	private List<XXTagAttribute> createTagAttributes(Long tagId, Map<String, String> attributes) throws Exception {
-		List<XXTagAttribute> ret = new ArrayList<XXTagAttribute>();
-
-		if(MapUtils.isNotEmpty(attributes)) {
-			for (Map.Entry<String, String> attr : attributes.entrySet()) {
-				XXTagAttribute xTagAttr = new XXTagAttribute();
-
-				xTagAttr.setTagId(tagId);
-				xTagAttr.setName(attr.getKey());
-				xTagAttr.setValue(attr.getValue());
-				xTagAttr = rangerAuditFields.populateAuditFieldsForCreate(xTagAttr);
-
-				xTagAttr = daoManager.getXXTagAttribute().create(xTagAttr);
-
-				ret.add(xTagAttr);
-			}
-		}
-
-		return ret;
-	}
-
-	private void deleteTagAttributes(Long tagId) {
-		List<XXTagAttribute> tagAttrList = daoManager.getXXTagAttribute().findByTagId(tagId);
-		for (XXTagAttribute tagAttr : tagAttrList) {
-			daoManager.getXXTagAttribute().remove(tagAttr);
-		}
-	}
-
-	private void deleteResourceForServiceResource(Long resourceId) {
-		List<XXServiceResourceElement> resElements = daoManager.getXXServiceResourceElement().findByResourceId(resourceId);
-		
-		if(CollectionUtils.isNotEmpty(resElements)) {
-			for(XXServiceResourceElement resElement : resElements) {
-				List<XXServiceResourceElementValue> elementValues = daoManager.getXXServiceResourceElementValue().findByResValueId(resElement.getId());
-				
-				if(CollectionUtils.isNotEmpty(elementValues)) {
-					for(XXServiceResourceElementValue elementValue : elementValues) {
-						daoManager.getXXServiceResourceElementValue().remove(elementValue.getId());
-					}
-				}
-				
-				daoManager.getXXServiceResourceElement().remove(resElement.getId());
-			}
-		}
-	}
-
-	private void createResourceForServiceResource(Long resourceId, RangerServiceResource serviceResource) {
-		String serviceName = serviceResource.getServiceName();
-
-		XXService xService = daoManager.getXXService().findByName(serviceName);
-
-		if (xService == null) {
-			throw errorUtil.createRESTException("No Service found with name: " + serviceName, MessageEnums.ERROR_CREATING_OBJECT);
-		}
-
-		XXServiceDef xServiceDef = daoManager.getXXServiceDef().getById(xService.getType());
-
-		if (xServiceDef == null) {
-			throw errorUtil.createRESTException("No Service-Def found with ID: " + xService.getType(), MessageEnums.ERROR_CREATING_OBJECT);
-		}
-
-		Map<String, RangerPolicy.RangerPolicyResource> resElements = serviceResource.getResourceElements();
-
-		for (Map.Entry<String, RangerPolicyResource> resElement : resElements.entrySet()) {
-			XXResourceDef xResDef = daoManager.getXXResourceDef().findByNameAndServiceDefId(resElement.getKey(), xServiceDef.getId());
-
-			if (xResDef == null) {
-				LOG.error("TagDBStore.createResource: ResourceType is not valid [" + resElement.getKey() + "]");
-				throw errorUtil.createRESTException("Resource Type is not valid [" + resElement.getKey() + "]", MessageEnums.DATA_NOT_FOUND);
-			}
-
-			RangerPolicyResource policyRes = resElement.getValue();
-
-			XXServiceResourceElement resourceElement = new XXServiceResourceElement();
-			resourceElement.setIsExcludes(policyRes.getIsExcludes());
-			resourceElement.setIsRecursive(policyRes.getIsRecursive());
-			resourceElement.setResDefId(xResDef.getId());
-			resourceElement.setResourceId(resourceId);
-
-			resourceElement = rangerAuditFields.populateAuditFieldsForCreate(resourceElement);
-
-			resourceElement = daoManager.getXXServiceResourceElement().create(resourceElement);
-
-			int sortOrder = 1;
-			for (String resVal : policyRes.getValues()) {
-				XXServiceResourceElementValue resourceElementValue = new XXServiceResourceElementValue();
-				resourceElementValue.setResElementId(resourceElement.getId());
-				resourceElementValue.setValue(resVal);
-				resourceElementValue.setSortOrder(sortOrder);
-				resourceElementValue = rangerAuditFields.populateAuditFieldsForCreate(resourceElementValue);
-
-				resourceElementValue = daoManager.getXXServiceResourceElementValue().create(resourceElementValue);
-				sortOrder++;
-			}
-		}
-	}
-
 	@Override
 	public void deleteAllTagObjectsForService(String serviceName) throws Exception {
 
@@ -1210,8 +1022,6 @@ public class TagDBStore extends AbstractTagStore {
 		if (service != null) {
 			Long serviceId = service.getId();
 
-			List<XXTagAttribute> xxTagAttributes = daoManager.getXXTagAttribute().findByServiceIdAndOwner(serviceId, RangerTag.OWNER_SERVICERESOURCE);
-
 			List<XXTag> xxTags = daoManager.getXXTag().findByServiceIdAndOwner(serviceId, RangerTag.OWNER_SERVICERESOURCE);
 
 			List<XXTagResourceMap> xxTagResourceMaps = daoManager.getXXTagResourceMap().findByServiceId(serviceId);
@@ -1227,17 +1037,6 @@ public class TagDBStore extends AbstractTagStore {
 				}
 			}
 
-			if (CollectionUtils.isNotEmpty(xxTagAttributes)) {
-				for (XXTagAttribute xxTagAttribute : xxTagAttributes) {
-					try {
-						daoManager.getXXTagAttribute().remove(xxTagAttribute);
-					} catch (Exception e) {
-						LOG.error("Error deleting RangerTagAttribute with id=" + xxTagAttribute.getId(), e);
-						throw e;
-					}
-				}
-			}
-
 			if (CollectionUtils.isNotEmpty(xxTags)) {
 				for (XXTag xxTag : xxTags) {
 					try {
@@ -1249,32 +1048,6 @@ public class TagDBStore extends AbstractTagStore {
 				}
 			}
 
-			List<XXServiceResourceElementValue> xxServiceResourceElementValues = daoManager.getXXServiceResourceElementValue().findByServiceId(serviceId);
-
-			if (CollectionUtils.isNotEmpty(xxServiceResourceElementValues)) {
-				for (XXServiceResourceElementValue xxServiceResourceElementValue : xxServiceResourceElementValues) {
-					try {
-						daoManager.getXXServiceResourceElementValue().remove(xxServiceResourceElementValue);
-					} catch (Exception e) {
-						LOG.error("Error deleting ServiceResourceElementValue with id=" + xxServiceResourceElementValue.getId(), e);
-						throw e;
-					}
-				}
-			}
-
-			List<XXServiceResourceElement> xxServiceResourceElements = daoManager.getXXServiceResourceElement().findByServiceId(serviceId);
-
-			if (CollectionUtils.isNotEmpty(xxServiceResourceElements)) {
-				for (XXServiceResourceElement xxServiceResourceElement : xxServiceResourceElements) {
-					try {
-						daoManager.getXXServiceResourceElement().remove(xxServiceResourceElement);
-					} catch (Exception e) {
-						LOG.error("Error deleting ServiceResourceElement with id=" + xxServiceResourceElement.getId(), e);
-						throw e;
-					}
-				}
-			}
-
 			List<XXServiceResource> xxServiceResources = daoManager.getXXServiceResource().findByServiceId(serviceId);
 
 			if (CollectionUtils.isNotEmpty(xxServiceResources)) {
