@@ -343,11 +343,23 @@ public class AppConstants extends RangerCommonEnums {
 	 * XA_PERM_TYPE_UPLOAD_NEW_CREDENTIAL is an element of enum XAPermType. Its value is "XA_PERM_TYPE_UPLOAD_NEW_CREDENTIAL".
 	 */
 	public static final int XA_PERM_TYPE_UPLOAD_NEW_CREDENTIAL = 31;
+	/**
+	* XA_PERM_TYPE_REPLADMIN is an element of enum XAPermType. Its value is "XA_PERM_TYPE_REPLADMIN".
+	*/
+	public static final int XA_PERM_TYPE_REPLADMIN = 32;
+	/**
+	 * XA_PERM_TYPE_SERVICEADMIN is an element of enum XAPermType. Its value is "XA_PERM_TYPE_HIVE_SERVICE".
+	 */
+	public static final int XA_PERM_TYPE_SERVICEADMIN = 33;
+	/**
+	 * XA_PERM_TYPE_TEMPUDFADMIN is an element of enum XAPermType. Its value is "XA_PERM_TYPE_TEMPUDFADMIN".
+	 */
+	public static final int XA_PERM_TYPE_TEMPUDFADMIN = 34;
 
 	/**
 	 * Max value for enum XAPermType_MAX
 	 */
-	public static final int XAPermType_MAX = 31;
+	public static final int XAPermType_MAX = 34;
 
 	/***************************************************************
 	 * Enum values for DatabaseFavor
@@ -595,10 +607,18 @@ public class AppConstants extends RangerCommonEnums {
 	public static final int CLASS_TYPE_XA_ACCESS_AUDIT_V4 = 1053;
 	public static final int CLASS_TYPE_XA_ACCESS_AUDIT_V5 = 1054;
 	public static final int CLASS_TYPE_UGYNC_AUDIT_INFO = 1055;
+
+	public static final int CLASS_TYPE_RANGER_SECURITY_ZONE = 1056;
+	public static final int CLASS_TYPE_RANGER_ROLE = 1057;
+	/**
+	 * Class type of RangerSecurityZone
+	 */
+
 	/**
 	 * Max value for enum ClassTypes_MAX
 	 */
-	public static final int ClassTypes_MAX = 1055;
+	public static final int ClassTypes_MAX = 1058;
+
 	
 	/***************************************************************
 	 * Enum values for Default SortOrder
@@ -854,6 +874,18 @@ public class AppConstants extends RangerCommonEnums {
 			// return "Upload New Credential"; //XA_PERM_TYPE_UPLOAD_NEW_CREDENTIAL
 			return "uploadNewCredentials";
 		}
+		if( elementValue == 32 ) {
+			// return "Repl Admin"; //XA_PERM_TYPE_REPL_ADMIN
+			return "repladmin";
+		}
+		if( elementValue == 33 ) {
+			// return "serviceadmin"; //XA_PERM_TYPE_SERVICEADMIN
+			return "serviceadmin";
+		}
+		if( elementValue == 34 ) {
+			// return "tempudfadmin"; //XA_PERM_TYPE_TEMPUDFADMIN
+			return "tempudfadmin";
+		}
 		return null;
 	}
 
@@ -972,6 +1004,12 @@ public class AppConstants extends RangerCommonEnums {
 		if( elementValue == 1055 ) {
 			return "Usersync Audit Info"; //CLASS_TYPE_UGYNC_AUDIT_INFO
 		}
+		if( elementValue == 1056 ) {
+			return "Ranger Security Zone"; //CLASS_TYPE_RANGER_SECURITY_ZONE
+		}
+		if( elementValue == 1057 ) {
+			return "Ranger Role"; //CLASS_TYPE_RANGER_ROLE
+		}
 		return null;
 	}
 
@@ -1158,6 +1196,15 @@ public class AppConstants extends RangerCommonEnums {
 		if("uploadNewCredentials".equalsIgnoreCase(label)) {
 			return AppConstants.XA_PERM_TYPE_UPLOAD_NEW_CREDENTIAL; //XA_PERM_TYPE_UPLOAD_NEW_CREDENTIAL
 		}
+		if(label.equalsIgnoreCase("repladmin")) {
+			return AppConstants.XA_PERM_TYPE_REPLADMIN; //XA_PERM_TYPE_REPLADMIN
+		}
+		if(label.equalsIgnoreCase("serviceadmin")) {
+			return AppConstants.XA_PERM_TYPE_SERVICEADMIN; //XA_PERM_TYPE_SERVICEADMIN
+		}
+		if("tempudfadmin".equalsIgnoreCase(label)) {
+			return AppConstants.XA_PERM_TYPE_TEMPUDFADMIN; //XA_PERM_TYPE_TEMPUDFADMIN
+		}
 		return 0;
 	}
 
