@@ -126,6 +126,9 @@ public class ServiceUtil {
 		mapAccessTypeToPermType.put("getUserTopology", 29);
 		mapAccessTypeToPermType.put("getTopologyInfo", 30);
 		mapAccessTypeToPermType.put("uploadNewCredentials", 31);
+		mapAccessTypeToPermType.put("repladmin",32);
+		mapAccessTypeToPermType.put("serviceadmin",33);
+		mapAccessTypeToPermType.put("tempudfadmin",34);
 
 		version = "0";
 	}
@@ -245,6 +248,7 @@ public class ServiceUtil {
 		toRangerResourceList(resource.getUdfs(), "udf", Boolean.FALSE, Boolean.FALSE, ret.getResources());
 		toRangerResourceList(resource.getTopologies(), "topology", Boolean.FALSE, Boolean.FALSE, ret.getResources());
 		toRangerResourceList(resource.getServices(), "service", Boolean.FALSE, Boolean.FALSE, ret.getResources());
+		toRangerResourceList(resource.getHiveServices(), "hiveservice", Boolean.FALSE, Boolean.FALSE, ret.getResources());
 
 		HashMap<String, List<VXPermMap>> sortedPermMap = new HashMap<String, List<VXPermMap>>();
 		
@@ -371,6 +375,8 @@ public class ServiceUtil {
 				ret.setTopologies(resString);
 			} else if("service".equalsIgnoreCase(resType)) {
 				ret.setServices(resString);
+			} else if(resType.equalsIgnoreCase("hiveservice")) {
+				ret.setHiveServices(resString);
 			}
 		}
 		updateResourceName(ret);
@@ -479,7 +485,7 @@ public class ServiceUtil {
 			}
 		}
 
-		return ret;
+		return ret == null ? 0 : ret;
 	}
 	
 	private RangerBaseModelObject dataObjectToRangerObject(VXDataObject dataObject,RangerBaseModelObject rangerObject) {
@@ -833,6 +839,8 @@ public class ServiceUtil {
 				ret.setTopologies(resString);
 			} else if("service".equalsIgnoreCase(resType)) {
 				ret.setServices(resString);
+			} else if(resType.equalsIgnoreCase("hiveservice")) {
+				ret.setHiveServices(resString);
 			}
 		}
 		updateResourceName(ret);
@@ -854,21 +862,21 @@ public class ServiceUtil {
 		int permGroup = 0;
 		for(RangerPolicy.RangerPolicyItem policyItem : policy.getPolicyItems()) {
 			String ipAddress = null;
-			
-			for(RangerPolicy.RangerPolicyItemCondition condition : policyItem.getConditions()) {
-				if(condition.getType() == "ipaddress") {
-					List<String> values = condition.getValues();
-					if (CollectionUtils.isNotEmpty(values)) {
-						// TODO changes this to properly deal with collection for now just returning 1st item
-						ipAddress = values.get(0);
-					}
-				}
-	
-				if(ipAddress != null && !ipAddress.isEmpty()) {
-					break; // only 1 IP-address per permMap
-				}
-			}
-	
+
+            for (RangerPolicy.RangerPolicyItemCondition condition : policyItem.getConditions()) {
+                if ("ipaddress".equalsIgnoreCase(condition.getType())) {
+                    List<String> values = condition.getValues();
+                    if (CollectionUtils.isNotEmpty(values)) {
+                        // TODO changes this to properly deal with collection for now just returning 1st item
+                        ipAddress = values.get(0);
+                    }
+                }
+
+                if (ipAddress != null && !ipAddress.isEmpty()) {
+                    break; // only 1 IP-address per permMap
+                }
+            }
+
 			for(String userName : policyItem.getUsers()) {
 				for(RangerPolicyItemAccess access : policyItem.getAccesses()) {
 					if(! access.getIsAllowed()) {
@@ -1057,7 +1065,11 @@ public class ServiceUtil {
 		if (vXPolicy.getServices() != null) {
 			toRangerResourceList(vXPolicy.getServices(), "service", Boolean.FALSE, isRecursive, ret.getResources());
 		}
-		
+
+		if (vXPolicy.getHiveServices() != null) {
+			toRangerResourceList(vXPolicy.getHiveServices(), "hiveservice", Boolean.FALSE, isRecursive, ret.getResources());
+		}
+
 		if ( vXPolicy.getPermMapList() != null) {
 			List<VXPermObj> vXPermObjList = vXPolicy.getPermMapList();
 
