@@ -70,7 +70,7 @@ public class StringUtil implements Serializable {
 	}
 
 	public boolean isEmptyOrWildcardAsterisk(String str) {
-		return isEmpty(str) || str.equals(WILDCARD_ASTERISK);
+		return isEmpty(str) || WILDCARD_ASTERISK.equals(str);
 	}
 
 	public boolean equals(String str1, String str2) {
@@ -198,8 +198,8 @@ public class StringUtil implements Serializable {
 			String[] splitValues = value.split(delimiter);
 			String[] returnValues = new String[splitValues.length];
 			int c = -1;
-			for (int i = 0; i < splitValues.length; i++) {
-				String str = splitValues[i].trim();
+			for (String splitValue : splitValues) {
+				String str = splitValue.trim();
 				if (str.length() > 0) {
 					c++;
 					returnValues[c] = str;
@@ -239,7 +239,7 @@ public class StringUtil implements Serializable {
 	 * @return true if it is empty list or null
 	 */
 	public boolean isEmpty(List<?> list) {
-		if (list == null || list.size() == 0) {
+		if (list == null || list.isEmpty()) {
 			return true;
 		}
 		return false;
