@@ -22,8 +22,10 @@ import java.util.List;
 
 import javax.persistence.NoResultException;
 
+import org.apache.commons.collections.ListUtils;
 import org.apache.ranger.common.db.BaseDao;
 import org.apache.ranger.entity.XXPolicy;
+import org.apache.ranger.plugin.model.RangerSecurityZone;
 import org.springframework.stereotype.Service;
 
 /**
@@ -39,14 +41,36 @@ public class XXPolicyDao extends BaseDao<XXPolicy> {
 	}
 
 	public XXPolicy findByNameAndServiceId(String polName, Long serviceId) {
+		return findByNameAndServiceIdAndZoneId(polName, serviceId, RangerSecurityZone.RANGER_UNZONED_SECURITY_ZONE_ID);
+	}
+
+	public XXPolicy findByNameAndServiceIdAndZoneId(String polName, Long serviceId, Long zoneId) {
 		if (polName == null || serviceId == null) {
 			return null;
 		}
+
+		XXPolicy ret;
+
 		try {
-			XXPolicy xPol = getEntityManager()
-					.createNamedQuery("XXPolicy.findByNameAndServiceId", tClass)
-					.setParameter("polName", polName).setParameter("serviceId", serviceId)
+			ret = getEntityManager()
+					.createNamedQuery("XXPolicy.findByNameAndServiceIdAndZoneId", tClass)
+					.setParameter("polName", polName).setParameter("serviceId", serviceId).setParameter("zoneId", zoneId)
 					.getSingleResult();
+
+		} catch (NoResultException e) {
+			ret = null;
+		}
+
+		return ret;
+	}
+
+	public XXPolicy findByPolicyName(String polName) {
+		if (polName == null) {
+			return null;
+		}
+		try {
+			XXPolicy xPol = getEntityManager().createNamedQuery("XXPolicy.findByPolicyName", tClass)
+					.setParameter("polName", polName).getSingleResult();
 			return xPol;
 		} catch (NoResultException e) {
 			return null;
@@ -66,6 +90,17 @@ public class XXPolicyDao extends BaseDao<XXPolicy> {
 		}
 	}
 
+	public List<Long> findPolicyIdsByServiceId(Long serviceId) {
+		List<Long> ret = new ArrayList<Long>();
+		try {
+			ret = getEntityManager()
+					.createNamedQuery("XXPolicy.findPolicyIdsByServiceId", Long.class)
+					.setParameter("serviceId", serviceId).getResultList();
+		} catch (Exception e) {
+		}
+		return ret;
+	}
+
 	public Long getMaxIdOfXXPolicy() {
 		try {
 			return (Long) getEntityManager().createNamedQuery("XXPolicy.getMaxIdOfXXPolicy").getSingleResult();
@@ -148,4 +183,43 @@ public class XXPolicyDao extends BaseDao<XXPolicy> {
 			return new ArrayList<XXPolicy>();
 		}
 	}
+
+	public List<Long> findPolicyIdsByServiceNameAndZoneId(String serviceName, Long zoneId) {
+		List<Long> ret = new ArrayList<Long>();
+		try {
+			ret = getEntityManager()
+					.createNamedQuery("XXPolicy.findPolicyIdsByServiceNameAndZoneId", Long.class)
+					.setParameter("serviceName", serviceName)
+					.setParameter("zoneId", zoneId)
+					.getResultList();
+		} catch (Exception e) {
+		}
+		return ret;
+	}
+
+	public List<XXPolicy> findByRoleId(Long roleId) {
+		List<XXPolicy> ret = ListUtils.EMPTY_LIST;
+		if (roleId != null) {
+			try {
+				ret = getEntityManager().createNamedQuery("XXPolicy.findByRoleId", tClass)
+						.setParameter("roleId", roleId)
+						.getResultList();
+			} catch (NoResultException excp) {
+			}
+		}
+		return ret;
+	}
+	public List<Long> findServiceIdsByRoleId(Long roleId) {
+		List<Long> ret = ListUtils.EMPTY_LIST;
+		if (roleId != null) {
+			try {
+				ret = getEntityManager().createNamedQuery("XXPolicy.findServiceIdsByRoleId", Long.class)
+						.setParameter("roleId", roleId)
+						.getResultList();
+			} catch (NoResultException excp) {
+			}
+		}
+		return ret;
+	}
+
 }
\ No newline at end of file
