@@ -524,7 +524,7 @@ public class AssetREST {
 		ServicePolicies servicePolicies = null;
 
 		try {
-			servicePolicies = serviceREST.getServicePoliciesIfUpdated(repository, lastKnowPolicyVersion, 0L, agentId, "",request);
+			servicePolicies = serviceREST.getServicePoliciesIfUpdated(repository, lastKnowPolicyVersion, 0L, agentId, "", "", false, request);
 		} catch(Exception excp) {
 			logger.error("failed to retrieve policies for repository " + repository, excp);
 		}
@@ -573,6 +573,8 @@ public class AssetREST {
                                 "End Date", null);
 		searchUtil.extractString(request, searchCriteria, "cluster",
 				"Cluster Name", StringUtil.VALIDATION_TEXT);
+		searchUtil.extractString(request, searchCriteria, "zoneName",
+				"Zone Name", StringUtil.VALIDATION_TEXT);
 		return assetMgr.searchXPolicyExportAudits(searchCriteria);
 	}
 
@@ -617,28 +619,31 @@ public class AssetREST {
 		searchUtil.extractString(request, searchCriteria, "accessType",
 				"Access Type", StringUtil.VALIDATION_TEXT);
 		searchUtil.extractString(request, searchCriteria, "aclEnforcer",
-				"Access Type", StringUtil.VALIDATION_TEXT);
+				"Access Enforcer", StringUtil.VALIDATION_TEXT);
 		searchUtil.extractString(request, searchCriteria, "agentId",
-				"Access Type", StringUtil.VALIDATION_TEXT);
+				"Application", StringUtil.VALIDATION_TEXT);
 		searchUtil.extractString(request, searchCriteria, "repoName",
-				"Access Type", StringUtil.VALIDATION_TEXT);
+				"Service Name", StringUtil.VALIDATION_TEXT);
 		searchUtil.extractString(request, searchCriteria, "sessionId",
-				"Access Type", StringUtil.VALIDATION_TEXT);
-		searchUtil.extractString(request, searchCriteria, "requestUser",
-				"Access Type", StringUtil.VALIDATION_TEXT);
+				"Session ID", StringUtil.VALIDATION_TEXT);
+		searchUtil.extractStringList(request, searchCriteria, "requestUser",
+			"Users", "requestUser", null, StringUtil.VALIDATION_TEXT);
+		searchUtil.extractStringList(request, searchCriteria, "excludeUser",
+			"Exclude Users", "-requestUser", null, StringUtil.VALIDATION_TEXT);
 		searchUtil.extractString(request, searchCriteria, "requestData",
-				"Access Type", StringUtil.VALIDATION_TEXT);
+				"Request Data", StringUtil.VALIDATION_TEXT);
 		searchUtil.extractString(request, searchCriteria, "resourcePath",
-				"Access Type", StringUtil.VALIDATION_TEXT);
+				"Resource Name", StringUtil.VALIDATION_TEXT);
 		searchUtil.extractString(request, searchCriteria, "clientIP",
 				"Client IP", StringUtil.VALIDATION_TEXT);
 		searchUtil.extractString(request, searchCriteria, "resourceType",
 				"Resource Type", StringUtil.VALIDATION_TEXT);
-
+		searchUtil.extractString(request,searchCriteria,"excludeServiceUser",
+				"Exclude Service User",StringUtil.VALIDATION_TEXT);
 		searchUtil.extractInt(request, searchCriteria, "auditType", "Audit Type");
                 searchUtil.extractInt(request, searchCriteria, "accessResult", "Result");
-		searchUtil.extractInt(request, searchCriteria, "assetId", "Audit Type");
-		searchUtil.extractLong(request, searchCriteria, "policyId", "Audit Type");
+		searchUtil.extractInt(request, searchCriteria, "assetId", "Asset ID");
+		searchUtil.extractLong(request, searchCriteria, "policyId", "Policy ID");
                 searchUtil.extractInt(request, searchCriteria, "repoType", "Service Type");
 		
 		searchUtil.extractDate(request, searchCriteria, "startDate",
@@ -648,6 +653,10 @@ public class AssetREST {
 
 		searchUtil.extractString(request, searchCriteria, "tags", "tags", null);
 		searchUtil.extractString(request, searchCriteria, "cluster", "Cluster Name", StringUtil.VALIDATION_TEXT);
+		searchUtil.extractStringList(request, searchCriteria, "zoneName", "Zone Name List", "zoneName", null,
+				                               null);
+
+		searchUtil.extractString(request, searchCriteria, "agentHost", "Agent Host Name", StringUtil.VALIDATION_TEXT);
 		
 		boolean isKeyAdmin = msBizUtil.isKeyAdmin();
 		boolean isAuditKeyAdmin = msBizUtil.isAuditKeyAdmin();
