@@ -235,45 +235,56 @@ public class RangerSSOAuthenticationFilter implements Filter {
 		}
 	}
 
-        private String constructForwardableURL(HttpServletRequest httpRequest){
-                String xForwardedProto = "";
-                String xForwardedHost = "";
-                String xForwardedContext = "";
-                Enumeration<?> names = httpRequest.getHeaderNames();
-                while (names.hasMoreElements()) {
-                        String name = (String) names.nextElement();
-                        Enumeration<?> values = httpRequest.getHeaders(name);
-                        String value = "";
-                        if (values != null) {
-                                while (values.hasMoreElements()) {
-                                        value = (String) values.nextElement();
-                                }
-                        }
-                        if (StringUtils.trimToNull(name) != null
-                                        && StringUtils.trimToNull(value) != null) {
-                                if (name.equalsIgnoreCase("x-forwarded-proto")) {
-                                        xForwardedProto = value;
-                                } else if (name.equalsIgnoreCase("x-forwarded-host")) {
-                                        xForwardedHost = value;
-                                } else if (name.equalsIgnoreCase("x-forwarded-context")) {
-                                        xForwardedContext = value;
-                                }
-                        }
-                }
-                if (xForwardedHost.contains(",")) {
-                    if(LOG.isDebugEnabled()) {
-                        LOG.debug("xForwardedHost value is " + xForwardedHost + " it contains multiple hosts, selecting the first host.");
-                    }
-                    xForwardedHost = xForwardedHost.split(",")[0].trim();
-                }
-                String xForwardedURL = "";
-                if (StringUtils.trimToNull(xForwardedProto) != null && StringUtils.trimToNull(xForwardedHost) != null && StringUtils.trimToNull(xForwardedContext) != null) {
-                        xForwardedURL = xForwardedProto + "://" + xForwardedHost
-                                        + xForwardedContext + PROXY_RANGER_URL_PATH
-                                        + httpRequest.getRequestURI();
-                }
-                return xForwardedURL;
-        }
+	private String constructForwardableURL(HttpServletRequest httpRequest) {
+		String xForwardedProto = "";
+		String xForwardedHost = "";
+		String xForwardedContext = "";
+		Enumeration<?> names = httpRequest.getHeaderNames();
+		while (names.hasMoreElements()) {
+			String name = (String) names.nextElement();
+			Enumeration<?> values = httpRequest.getHeaders(name);
+			String value = "";
+			if (values != null) {
+				while (values.hasMoreElements()) {
+					value = (String) values.nextElement();
+				}
+			}
+			if (StringUtils.trimToNull(name) != null && StringUtils.trimToNull(value) != null) {
+				if (name.equalsIgnoreCase("x-forwarded-proto")) {
+					xForwardedProto = value;
+				} else if (name.equalsIgnoreCase("x-forwarded-host")) {
+					xForwardedHost = value;
+				} else if (name.equalsIgnoreCase("x-forwarded-context")) {
+					xForwardedContext = value;
+				}
+			}
+		}
+		if (xForwardedHost.contains(",")) {
+			if (LOG.isDebugEnabled()) {
+				LOG.debug("xForwardedHost value is " + xForwardedHost + " it contains multiple hosts, selecting the first host.");
+			}
+			xForwardedHost = xForwardedHost.split(",")[0].trim();
+		}
+		String xForwardedURL = "";
+		if (StringUtils.trimToNull(xForwardedProto) != null) {
+			//if header contains x-forwarded-host and x-forwarded-context
+			if (StringUtils.trimToNull(xForwardedHost) != null && StringUtils.trimToNull(xForwardedContext) != null) {
+				xForwardedURL = xForwardedProto + "://" + xForwardedHost + xForwardedContext + PROXY_RANGER_URL_PATH + httpRequest.getRequestURI();
+			} else if (StringUtils.trimToNull(xForwardedHost) != null) {
+				//if header contains x-forwarded-host and does not contains x-forwarded-context
+				xForwardedURL = xForwardedProto + "://" + xForwardedHost + httpRequest.getRequestURI();
+			} else {
+				//if header does not contains x-forwarded-host and x-forwarded-context
+				//preserve the x-forwarded-proto value coming from the request.
+				String requestURL = httpRequest.getRequestURL().toString();
+				if (StringUtils.trimToNull(requestURL) != null && requestURL.startsWith("http:")) {
+					requestURL = requestURL.replaceFirst("http", xForwardedProto);
+				}
+				xForwardedURL = requestURL;
+			}
+		}
+		return xForwardedURL;
+	}
 
 	private Authentication getGrantedAuthority(Authentication authentication) {
 		UsernamePasswordAuthenticationToken result=null;
