@@ -22,8 +22,10 @@ import java.util.Collections;
 import java.util.Date;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 
 import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.lang.StringUtils;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.ranger.biz.RangerBizUtil;
@@ -91,6 +93,14 @@ public class RangerPluginInfoService {
 
 		List<XXService> servicesWithTagService = daoManager.getXXService().getAllServicesWithTagService();
 
+                // Rebuild searchFilter without serviceType
+
+                String serviceTypeToSearch = searchFilter.getParam(SearchFilter.SERVICE_TYPE);
+                if (StringUtils.isNotBlank(serviceTypeToSearch)) {
+                        searchFilter.removeParam(SearchFilter.SERVICE_TYPE);
+                }
+                String clusterNameToSearch =  searchFilter.getParam(SearchFilter.CLUSTER_NAME);
+
 		List<XXPluginInfo> xObjList = searchRangerObjects(searchFilter, searchFields, sortFields, retList);
 
 		List<Object[]> objectsList = null;
@@ -126,7 +136,23 @@ public class RangerPluginInfoService {
 			}
 
 			RangerPluginInfo obj = populateViewObjectWithServiceVersionInfo(xObj, xxServiceVersionInfo, hasAssociatedTagService);
-			objList.add(obj);
+
+                        if (StringUtils.isBlank(serviceTypeToSearch) || StringUtils.equals(serviceTypeToSearch, obj.getServiceType())) {
+                                objList.add(obj);
+                        }
+
+			if (StringUtils.isNotBlank(clusterNameToSearch)) {
+				Map<String, String> infoMap = obj.getInfo();
+				Set<Map.Entry<String, String>> infoSet = infoMap.entrySet();
+				for (Map.Entry<String, String> info : infoSet) {
+					if (StringUtils.equals(info.getKey(), SearchFilter.CLUSTER_NAME)) {
+						if (!StringUtils.equals(info.getValue(), clusterNameToSearch)) {
+							objList.remove(obj);
+						}
+						break;
+					}
+				}
+			}
 		}
 
 		retList.setList(objList);
@@ -140,6 +166,11 @@ public class RangerPluginInfoService {
 		ret.setCreateTime(xObj.getCreateTime());
 		ret.setUpdateTime(xObj.getUpdateTime());
 		ret.setServiceName(xObj.getServiceName());
+
+                String serviceType = daoManager.getXXServiceDef().findServiceDefTypeByServiceName(ret.getServiceName());
+                if (StringUtils.isNotBlank(serviceType)) {
+                        ret.setServiceType(serviceType);
+                }
 		ret.setHostName(xObj.getHostName());
 		ret.setAppType(xObj.getAppType());
 		ret.setIpAddress(xObj.getIpAddress());
@@ -166,6 +197,11 @@ public class RangerPluginInfoService {
 		ret.setCreateTime(xObj.getCreateTime());
 		ret.setUpdateTime(xObj.getUpdateTime());
 		ret.setServiceName(xObj.getServiceName());
+
+                String serviceType = daoManager.getXXServiceDef().findServiceDefTypeByServiceName(ret.getServiceName());
+                if (StringUtils.isNotBlank(serviceType)) {
+                        ret.setServiceType(serviceType);
+                }
 		ret.setHostName(xObj.getHostName());
 		ret.setAppType(xObj.getAppType());
 		ret.setIpAddress(xObj.getIpAddress());
