@@ -42,6 +42,7 @@ import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItem;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyResource;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerRowFilterPolicyItem;
 import org.apache.ranger.plugin.model.RangerValiditySchedule;
+import org.apache.ranger.plugin.util.JsonUtilsV2;
 import org.codehaus.jackson.JsonParseException;
 import org.codehaus.jackson.map.JsonMappingException;
 import org.codehaus.jackson.map.ObjectMapper;
@@ -72,17 +73,21 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
         public static final String POLICY_LABELS_CLASS_FIELD_NAME="policyLabels";
         public static final String POLICY_VALIDITYSCHEDULES_CLASS_FIELD_NAME="validitySchedules";
         public static final String POLICY_PRIORITY_CLASS_FIELD_NAME="policyPriority";
+        public static final String POLICY_CONDITION_CLASS_FIELD_NAME="conditions";
 
 	static HashMap<String, VTrxLogAttr> trxLogAttrs = new HashMap<String, VTrxLogAttr>();
 	String actionCreate;
+	String actionImportCreate;
 	String actionUpdate;
 	String actionDelete;
+	String actionImportDelete;
 
 	static {
 		trxLogAttrs.put("name", new VTrxLogAttr("name", "Policy Name", false));
 		trxLogAttrs.put("description", new VTrxLogAttr("description", "Policy Description", false));
 		trxLogAttrs.put("isEnabled", new VTrxLogAttr("isEnabled", "Policy Status", false));
 		trxLogAttrs.put("resources", new VTrxLogAttr("resources", "Policy Resources", false));
+                trxLogAttrs.put("conditions", new VTrxLogAttr("conditions", "Policy Conditions", false));
 		trxLogAttrs.put("policyItems", new VTrxLogAttr("policyItems", "Policy Items", false));
 		trxLogAttrs.put("denyPolicyItems", new VTrxLogAttr("denyPolicyItems", "DenyPolicy Items", false));
 		trxLogAttrs.put("allowExceptions", new VTrxLogAttr("allowExceptions", "Allow Exceptions", false));
@@ -93,11 +98,14 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 		trxLogAttrs.put("policyLabels", new VTrxLogAttr("policyLabels", "Policy Labels", false));
 		trxLogAttrs.put("validitySchedules", new VTrxLogAttr("validitySchedules", "Validity Schedules", false));
 		trxLogAttrs.put("policyPriority", new VTrxLogAttr("policyPriority", "Priority", false));
+		trxLogAttrs.put("zoneName", new VTrxLogAttr("zoneName", "Zone Name", false));
 	}
 	
 	public RangerPolicyService() {
 		super();
 		actionCreate = "create";
+		actionImportCreate = "Import Create";
+		actionImportDelete = "Import Delete";
 		actionUpdate = "update";
 		actionDelete = "delete";
 	}
@@ -191,7 +199,7 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 		field.setAccessible(true);
 		String fieldName = field.getName();
 		XXTrxLog xTrxLog = new XXTrxLog();
-
+                XXService parentObj = daoMgr.getXXService().findByName(vObj.getService());
 		try {
 			VTrxLogAttr vTrxLogAttr = trxLogAttrs.get(fieldName);
 
@@ -202,6 +210,8 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 			if (!isEnum) {
 			    if (POLICY_RESOURCE_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
     				value = processPolicyResourcesForTrxLog(field.get(vObj));
+				} else if (POLICY_CONDITION_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+					value = processPolicyItemsForTrxLog(field.get(vObj));
     			} else if (POLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
     				value = processPolicyItemsForTrxLog(field.get(vObj));
     			} else if (DENYPOLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
@@ -345,8 +355,17 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 				} else if (POLICY_PRIORITY_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					oldValue = processPriorityClassFieldNameForTrxLog(oldPolicy.getPolicyPriority());
 				}
+                                else if (POLICY_CONDITION_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+                                        if (oldPolicy != null) {
+                                                oldValue = processPolicyItemsForTrxLog(oldPolicy.getConditions());
+                                        }
+                                }
 				if (oldValue == null || oldValue.equalsIgnoreCase(value)) {
+                                        if (field.getName().equalsIgnoreCase("zoneName") && !(stringUtil.isEmpty(value))) {
+                                                oldValue=value;
+                                        }  else {
 					return null;
+                }
 				} else if (POLICY_RESOURCE_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					// Compare old and new resources
 					if(compareTwoPolicyResources(value, oldValue)) {
@@ -417,6 +436,16 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 				xTrxLog.setPreviousValue(oldValue);
 				xTrxLog.setNewValue(value);
 			}
+			else if (action == OPERATION_IMPORT_CREATE_CONTEXT) {
+				if (stringUtil.isEmpty(value)) {
+					return null;
+				}
+				xTrxLog.setNewValue(value);
+				actionString = actionImportCreate;
+			} else if (action == OPERATION_IMPORT_DELETE_CONTEXT) {
+				xTrxLog.setPreviousValue(value);
+				actionString = actionImportDelete;
+			}
 		} catch (IllegalArgumentException | IllegalAccessException e) {
 			logger.error("Process field to create trx log failure.", e);
 		}
@@ -425,8 +454,7 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 		xTrxLog.setObjectClassType(AppConstants.CLASS_TYPE_RANGER_POLICY);
 		xTrxLog.setObjectId(vObj.getId());
 		xTrxLog.setObjectName(objectName);
-		
-		XXService parentObj = daoMgr.getXXService().findByName(vObj.getService());
+
 		xTrxLog.setParentObjectClassType(AppConstants.CLASS_TYPE_XA_SERVICE);
 		xTrxLog.setParentObjectId(parentObj.getId());
 		xTrxLog.setParentObjectName(parentObj.getName());
@@ -444,7 +472,7 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
                 if (stringUtil.isEmpty(value) || stringUtil.isEmpty(oldValue)) {
                         return false;
                 }
-                ObjectMapper mapper = new ObjectMapper();
+                ObjectMapper mapper = JsonUtilsV2.getMapper();
                 try {
                         List<String> obj = mapper.readValue(value, new TypeReference<List<String>>() {
                         });
@@ -484,7 +512,7 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 			return false;
 		}
 
-		ObjectMapper mapper = new ObjectMapper();
+		ObjectMapper mapper = JsonUtilsV2.getMapper();
 		try {
 			List<RangerPolicyItem> obj = mapper.readValue(value,
 					new TypeReference<List<RangerPolicyItem>>() {
@@ -531,7 +559,7 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 			return false;
 		}
 
-		ObjectMapper mapper = new ObjectMapper();
+		ObjectMapper mapper = JsonUtilsV2.getMapper();
 		try {
 			Map<String, RangerPolicyResource> obj = mapper.readValue(value,
 					new TypeReference<Map<String, RangerPolicyResource>>() {
@@ -687,7 +715,7 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 		if (stringUtil.isEmpty(value) || stringUtil.isEmpty(oldValue)) {
 			return false;
 		}
-		ObjectMapper mapper = new ObjectMapper();
+		ObjectMapper mapper = JsonUtilsV2.getMapper();
 		try {
 			List<RangerDataMaskPolicyItem> obj = mapper.readValue(value,
 					new TypeReference<List<RangerDataMaskPolicyItem>>() {
@@ -731,7 +759,7 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 		if (stringUtil.isEmpty(value) || stringUtil.isEmpty(oldValue)) {
 			return false;
 		}
-		ObjectMapper mapper = new ObjectMapper();
+		ObjectMapper mapper = JsonUtilsV2.getMapper();
 		try {
 			List<RangerRowFilterPolicyItem> obj = mapper.readValue(value,
 					new TypeReference<List<RangerRowFilterPolicyItem>>() {
