@@ -17,7 +17,6 @@
 
 package org.apache.ranger.service;
 
-import org.apache.commons.collections.MapUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.ranger.authorization.utils.JsonUtils;
 import org.apache.ranger.common.GUIDUtil;
@@ -28,14 +27,14 @@ import org.apache.ranger.common.SearchField.DATA_TYPE;
 import org.apache.ranger.common.SearchField.SEARCH_TYPE;
 import org.apache.ranger.common.SortField.SORT_ORDER;
 import org.apache.ranger.entity.XXPolicyBase;
+import org.apache.ranger.entity.XXSecurityZone;
 import org.apache.ranger.entity.XXService;
 import org.apache.ranger.plugin.model.RangerPolicy;
-import org.apache.ranger.plugin.model.RangerValiditySchedule;
+import org.apache.ranger.plugin.model.RangerSecurityZone;
 import org.apache.ranger.plugin.util.SearchFilter;
 import org.springframework.beans.factory.annotation.Autowired;
 
 import java.util.HashMap;
-import java.util.List;
 import java.util.Map;
 
 public abstract class RangerPolicyServiceBase<T extends XXPolicyBase, V extends RangerPolicy> extends
@@ -58,18 +57,23 @@ public abstract class RangerPolicyServiceBase<T extends XXPolicyBase, V extends
 				"XXService xSvc", "xSvc.id = obj.service"));
 		searchFields
 				.add(new SearchField(SearchFilter.IS_ENABLED, "obj.isEnabled", DATA_TYPE.BOOLEAN, SEARCH_TYPE.FULL));
-		searchFields.add(new SearchField(SearchFilter.IS_RECURSIVE,"xPolRes.isRecursive",DATA_TYPE.BOOLEAN,SEARCH_TYPE.FULL,
-				"XXPolicyResource xPolRes","obj.id=xPolRes.policyId"));
+		//might need updation
+		/*searchFields.add(new SearchField(SearchFilter.IS_RECURSIVE,"xPolRes.isRecursive",DATA_TYPE.BOOLEAN,SEARCH_TYPE.FULL,
+				"XXPolicyResource xPolRes","obj.id=xPolRes.policyId"));*/
 		searchFields.add(new SearchField(SearchFilter.POLICY_ID, "obj.id", DATA_TYPE.INTEGER, SEARCH_TYPE.FULL));
 		searchFields.add(new SearchField(SearchFilter.POLICY_NAME, "obj.name", DATA_TYPE.STRING, SEARCH_TYPE.FULL));
 		searchFields.add(new SearchField(SearchFilter.GUID, "obj.guid", DATA_TYPE.STRING, SEARCH_TYPE.FULL));
 		searchFields.add(new SearchField(SearchFilter.USER, "xUser.name", DATA_TYPE.STRING, SEARCH_TYPE.FULL,
-				"XXUser xUser, XXPolicyItem xPolItem, XXPolicyItemUserPerm userPerm", "obj.id = xPolItem.policyId "
-						+ "and userPerm.policyItemId = xPolItem.id and xUser.id = userPerm.userId"));
+				"XXUser xUser, XXPolicyRefUser refUser", "obj.id = refUser.policyId "
+						+ "and xUser.id = refUser.userId"));
 		searchFields.add(new SearchField(SearchFilter.GROUP, "xGrp.name", DATA_TYPE.STRING, SEARCH_TYPE.FULL,
-				"XXGroup xGrp, XXPolicyItem xPolItem, XXPolicyItemGroupPerm grpPerm", "obj.id = xPolItem.policyId "
-						+ "and grpPerm.policyItemId = xPolItem.id and xGrp.id = grpPerm.groupId"));
-		searchFields.add(new SearchField(SearchFilter.POL_RESOURCE, "resMap.value", DATA_TYPE.STRING,
+				"XXGroup xGrp , XXPolicyRefGroup refGroup", "obj.id = refGroup.policyId "
+						+ "and xGrp.id = refGroup.groupId"));
+		searchFields.add(new SearchField(SearchFilter.ROLE, "xRole.name", DATA_TYPE.STRING, SEARCH_TYPE.FULL,
+				"XXRole xRole , XXPolicyRefRole refRole", "obj.id = reRole.policyId "
+				+ "and xRole.id = refRole.roleId"));
+		//might need updation
+		/*searchFields.add(new SearchField(SearchFilter.POL_RESOURCE, "resMap.value", DATA_TYPE.STRING,
 				SEARCH_TYPE.PARTIAL, "XXPolicyResourceMap resMap, XXPolicyResource polRes",
 				"resMap.resourceId = polRes.id and polRes.policyId = obj.id"));
                 /*searchFields.add(new SearchField(SearchFilter.POLICY_LABELS_PARTIAL, "obj.label_name", DATA_TYPE.STRING,
@@ -77,11 +81,16 @@ public abstract class RangerPolicyServiceBase<T extends XXPolicyBase, V extends
 		searchFields.add(new SearchField(SearchFilter.POLICY_NAME_PARTIAL, "obj.name", DATA_TYPE.STRING,
 				SEARCH_TYPE.PARTIAL));
 		searchFields.add(new SearchField(SearchFilter.POLICY_TYPE, "obj.policyType", DATA_TYPE.INTEGER, SEARCH_TYPE.FULL));
+		searchFields.add(new SearchField(SearchFilter.ZONE_NAME, "xZone.name", DATA_TYPE.STRING, SEARCH_TYPE.FULL,
+				"XXSecurityZone xZone", "xZone.id = obj.zoneId"));
+		searchFields.add(new SearchField(SearchFilter.ZONE_ID, "xZone.id", DATA_TYPE.INTEGER, SEARCH_TYPE.FULL,
+				"XXSecurityZone xZone", "xZone.id = obj.zoneId"));
 
 		sortFields.add(new SortField(SearchFilter.CREATE_TIME, "obj.createTime"));
 		sortFields.add(new SortField(SearchFilter.UPDATE_TIME, "obj.updateTime"));
 		sortFields.add(new SortField(SearchFilter.POLICY_ID, "obj.id", true, SORT_ORDER.ASC));
 		sortFields.add(new SortField(SearchFilter.POLICY_NAME, "obj.name"));
+
 	}
 
 	@Override
@@ -104,6 +113,9 @@ public abstract class RangerPolicyServiceBase<T extends XXPolicyBase, V extends
 		xObj.setResourceSignature(vObj.getResourceSignature());
 		xObj.setIsAuditEnabled(vObj.getIsAuditEnabled());
 		xObj.setIsEnabled(vObj.getIsEnabled());
+		Long zoneId = convertZoneNameToZoneId(vObj.getZoneName(), vObj);
+
+		xObj.setZoneId(zoneId);
 
 		String              validitySchedules = JsonUtils.listToJson(vObj.getValiditySchedules());
 		Map<String, Object> options           = vObj.getOptions();
@@ -118,9 +130,11 @@ public abstract class RangerPolicyServiceBase<T extends XXPolicyBase, V extends
 			options.remove(OPTION_POLICY_VALIDITY_SCHEDULES);
 		}
 
-        xObj.setOptions(JsonUtils.mapToJson(options));
+		xObj.setOptions(JsonUtils.mapToJson(options));
 
-        return xObj;
+		xObj.setPolicyText(JsonUtils.objectToJson(vObj));
+
+		return xObj;
 	}
 
 	@Override
@@ -129,6 +143,7 @@ public abstract class RangerPolicyServiceBase<T extends XXPolicyBase, V extends
 		vObj.setGuid(xObj.getGuid());
 		vObj.setVersion(xObj.getVersion());
 		vObj.setService(xService.getName());
+		vObj.setServiceType(xService.getType().toString());
 		vObj.setName(StringUtils.trim(xObj.getName()));
 		vObj.setPolicyType(xObj.getPolicyType() == null ? RangerPolicy.POLICY_TYPE_ACCESS : xObj.getPolicyType());
 		vObj.setPolicyPriority(xObj.getPolicyPriority() == null ? RangerPolicy.POLICY_PRIORITY_NORMAL : xObj.getPolicyPriority());
@@ -136,21 +151,45 @@ public abstract class RangerPolicyServiceBase<T extends XXPolicyBase, V extends
 		vObj.setResourceSignature(xObj.getResourceSignature());
 		vObj.setIsEnabled(xObj.getIsEnabled());
 		vObj.setIsAuditEnabled(xObj.getIsAuditEnabled());
+		String zoneName = convertZoneIdToZoneName(xObj.getZoneId(), vObj);
+		vObj.setZoneName(zoneName);
 
-		Map<String, Object> options = JsonUtils.jsonToObject(xObj.getOptions(), Map.class);
+		String policyText = xObj.getPolicyText();
 
-		if (MapUtils.isNotEmpty(options)) {
-			String optionPolicyValiditySchedule = (String)options.remove(OPTION_POLICY_VALIDITY_SCHEDULES);
+		RangerPolicy ret = JsonUtils.jsonToObject(policyText, RangerPolicy.class);
 
-			if (StringUtils.isNotBlank(optionPolicyValiditySchedule)) {
-				List<RangerValiditySchedule> validitySchedules = JsonUtils.jsonToRangerValiditySchedule(optionPolicyValiditySchedule);
-
-				vObj.setValiditySchedules(validitySchedules);
-			}
+		if (ret != null) {
+			vObj.setOptions(ret.getOptions());
+			vObj.setValiditySchedules(ret.getValiditySchedules());
+			vObj.setPolicyLabels(ret.getPolicyLabels());
 		}
 
-		vObj.setOptions(options);
-
 		return vObj;
 	}
+
+	private Long convertZoneNameToZoneId(String zoneName, V vObj) {
+		if (StringUtils.isEmpty(zoneName)) return RangerSecurityZone.RANGER_UNZONED_SECURITY_ZONE_ID;
+		XXSecurityZone zone = daoMgr.getXXSecurityZoneDao().findByZoneName(zoneName);
+		if (zone == null) {
+			throw restErrorUtil.createRESTException("No corresponding zone found for policyName: " + vObj.getName()
+					+ "Zone Not Found : " + zoneName, MessageEnums.INVALID_INPUT_DATA);
+		}
+		return zone.getId();
+	}
+
+	private String convertZoneIdToZoneName(Long zoneId, V vObj) {
+		if (zoneId == null) {
+			throw restErrorUtil.createRESTException("No corresponding zone found for policyName: " + vObj.getName()
+					+ "Zone Not Found : " + zoneId, MessageEnums.INVALID_INPUT_DATA);
+		}
+		if (zoneId.equals(RangerSecurityZone.RANGER_UNZONED_SECURITY_ZONE_ID)) {
+			return StringUtils.EMPTY;
+		}
+		XXSecurityZone zone = daoMgr.getXXSecurityZoneDao().findByZoneId(zoneId);
+		if (zone == null) {
+			throw restErrorUtil.createRESTException("No corresponding zone found for policyName: " + vObj.getName()
+					+ "Zone Not Found : " + zoneId, MessageEnums.INVALID_INPUT_DATA);
+		}
+		return zone.getName();
+	}
 }
