@@ -50,6 +50,8 @@ public abstract class XPolicyExportAuditServiceBase<T extends XXPolicyExportAudi
 		mObj.setExportedJson( vObj.getExportedJson());
 		mObj.setHttpRetCode( vObj.getHttpRetCode());
 		mObj.setClusterName( vObj.getClusterName());
+		mObj.setZoneName( vObj.getZoneName());
+		mObj.setPolicyVersion( vObj.getPolicyVersion());
 		return mObj;
 	}
 
@@ -64,6 +66,8 @@ public abstract class XPolicyExportAuditServiceBase<T extends XXPolicyExportAudi
 		vObj.setHttpRetCode( mObj.getHttpRetCode());
 		vObj.setSyncStatus( MapUtil.getPolicyExportAuditSyncStatus(mObj.getHttpRetCode()));
 		vObj.setClusterName( mObj.getClusterName());
+		vObj.setZoneName( mObj.getZoneName());
+		vObj.setPolicyVersion( mObj.getPolicyVersion());
 		return vObj;
 	}
 
