@@ -93,8 +93,8 @@ public class RangerRESTAPIFilter extends LoggingFilter {
 		if (logStdOut) {
 			String path = request.getRequestUri().getPath();
 
-			if ((request.getMediaType() == null || !request.getMediaType()
-					.getType().equals("multipart"))
+			if ((request.getMediaType() == null || !"multipart".equals(request.getMediaType()
+					.getType()))
 					&& !path.endsWith("/service/general/logs")) {
 				try {
 					request = super.filter(request);
@@ -124,7 +124,7 @@ public class RangerRESTAPIFilter extends LoggingFilter {
 				logger.info("DELETE ME: Response= mediaType is null");
 			}
 			if (response.getMediaType() == null
-					|| !response.getMediaType().getType().equals("image")) {
+					|| !"image".equals(response.getMediaType().getType())) {
 
 				response = super.filter(request, response);
 			}
@@ -155,17 +155,17 @@ public class RangerRESTAPIFilter extends LoggingFilter {
 					Annotation[] methodAnnotations = m.getAnnotations();
 					String httpMethod = null;
 					String servicePath = null;
-					for (int ma = 0; ma < methodAnnotations.length; ma++) {
-						if (methodAnnotations[ma] instanceof GET) {
+					for (Annotation methodAnnotation : methodAnnotations) {
+						if (methodAnnotation instanceof GET) {
 							httpMethod = "GET";
-						} else if (methodAnnotations[ma] instanceof PUT) {
+						} else if (methodAnnotation instanceof PUT) {
 							httpMethod = "PUT";
-						} else if (methodAnnotations[ma] instanceof POST) {
+						} else if (methodAnnotation instanceof POST) {
 							httpMethod = "POST";
-						} else if (methodAnnotations[ma] instanceof DELETE) {
+						} else if (methodAnnotation instanceof DELETE) {
 							httpMethod = "DELETE";
-						} else if (methodAnnotations[ma] instanceof Path) {
-							servicePath = ((Path) methodAnnotations[ma])
+						} else if (methodAnnotation instanceof Path) {
+							servicePath = ((Path) methodAnnotation)
 									.value();
 						}
 					}
