@@ -21,21 +21,27 @@ package org.apache.ranger.solr;
 
 import java.io.UnsupportedEncodingException;
 import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.Collection;
 import java.util.List;
+import java.util.Map;
 
+import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.lang.StringUtils;
 import org.apache.log4j.Logger;
 import org.apache.ranger.common.MessageEnums;
 import org.apache.ranger.common.PropertiesUtil;
 import org.apache.ranger.common.RESTErrorUtil;
 import org.apache.ranger.common.SearchCriteria;
 import org.apache.ranger.common.SearchField;
-import org.apache.ranger.common.SortField;
-import org.apache.ranger.common.StringUtil;
 import org.apache.ranger.common.SearchField.DATA_TYPE;
 import org.apache.ranger.common.SearchField.SEARCH_TYPE;
+import org.apache.ranger.common.SortField;
 import org.apache.ranger.common.SortField.SORT_ORDER;
+import org.apache.ranger.common.StringUtil;
 import org.apache.ranger.db.RangerDaoManager;
 import org.apache.ranger.entity.XXServiceDef;
+import org.apache.ranger.plugin.store.EmbeddedServiceDefsUtil;
 import org.apache.ranger.view.VXAccessAudit;
 import org.apache.ranger.view.VXAccessAuditList;
 import org.apache.ranger.view.VXLong;
@@ -50,7 +56,7 @@ import org.springframework.stereotype.Service;
 @Service
 @Scope("singleton")
 public class SolrAccessAuditsService {
-	private static final Logger logger = Logger.getLogger(SolrAccessAuditsService.class);
+	private static final Logger LOGGER = Logger.getLogger(SolrAccessAuditsService.class);
 
 	@Autowired
 	SolrMgr solrMgr;
@@ -67,8 +73,8 @@ public class SolrAccessAuditsService {
 	@Autowired
 	RangerDaoManager daoManager;
 
-	public List<SortField> sortFields = new ArrayList<SortField>();
-	public List<SearchField> searchFields = new ArrayList<SearchField>();
+	private List<SortField> sortFields = new ArrayList<SortField>();
+	private List<SearchField> searchFields = new ArrayList<SearchField>();
 
 	public SolrAccessAuditsService() {
 
@@ -85,11 +91,13 @@ public class SolrAccessAuditsService {
 		searchFields.add(new SearchField("sessionId", "sess",
 				SearchField.DATA_TYPE.STRING, SearchField.SEARCH_TYPE.FULL));
 		searchFields.add(new SearchField("requestUser", "reqUser",
-				SearchField.DATA_TYPE.STRING, SearchField.SEARCH_TYPE.FULL));
-		searchFields.add(new SearchField("requestData", "reqData",
-				SearchField.DATA_TYPE.STRING, SearchField.SEARCH_TYPE.PARTIAL));
-		searchFields.add(new SearchField("resourcePath", "resource",
-				SearchField.DATA_TYPE.STRING, SearchField.SEARCH_TYPE.PARTIAL));
+			SearchField.DATA_TYPE.STR_LIST, SearchField.SEARCH_TYPE.FULL));
+		searchFields.add(new SearchField("excludeUser", "exlUser",
+			SearchField.DATA_TYPE.STR_LIST, SearchField.SEARCH_TYPE.FULL));
+		searchFields.add(new SearchField("requestData", "reqData", SearchField.DATA_TYPE.STRING,
+				SearchField.SEARCH_TYPE.PARTIAL));
+		searchFields.add(new SearchField("resourcePath", "resource", SearchField.DATA_TYPE.STRING,
+				SearchField.SEARCH_TYPE.PARTIAL));
 		searchFields.add(new SearchField("clientIP", "cliIP",
 				SearchField.DATA_TYPE.STRING, SearchField.SEARCH_TYPE.FULL));
 
@@ -104,7 +112,9 @@ public class SolrAccessAuditsService {
 		searchFields.add(new SearchField("repoType", "repoType",
 				SearchField.DATA_TYPE.INTEGER, SearchField.SEARCH_TYPE.FULL));
                 searchFields.add(new SearchField("-repoType", "-repoType",
-                                SearchField.DATA_TYPE.INTEGER, SearchField.SEARCH_TYPE.FULL));
+        SearchField.DATA_TYPE.INTEGER, SearchField.SEARCH_TYPE.FULL));
+                searchFields.add(new SearchField("-requestUser", "-reqUser",
+        		SearchField.DATA_TYPE.STRING, SearchField.SEARCH_TYPE.FULL));
 		searchFields.add(new SearchField("resourceType", "resType",
 				SearchField.DATA_TYPE.STRING, SearchField.SEARCH_TYPE.FULL));
 		searchFields.add(new SearchField("reason", "reason",
@@ -120,25 +130,32 @@ public class SolrAccessAuditsService {
 		searchFields.add(new SearchField("tags", "tags", DATA_TYPE.STRING, SEARCH_TYPE.PARTIAL));
 		searchFields.add(new SearchField("cluster", "cluster",
 				SearchField.DATA_TYPE.STRING, SearchField.SEARCH_TYPE.FULL));
+		searchFields.add(new SearchField("zoneName", "zoneName",
+				SearchField.DATA_TYPE.STR_LIST, SearchField.SEARCH_TYPE.FULL));
+		searchFields.add(new SearchField("agentHost", "agentHost",
+				SearchField.DATA_TYPE.STRING, SearchField.SEARCH_TYPE.PARTIAL));
 
 		sortFields.add(new SortField("eventTime", "evtTime", true,
 				SORT_ORDER.DESC));
 	}
 
+
 	public VXAccessAuditList searchXAccessAudits(SearchCriteria searchCriteria) {
 
 		// Make call to Solr
 		SolrClient solrClient = solrMgr.getSolrClient();
-                final boolean hiveQueryVisibility = PropertiesUtil.getBooleanProperty("ranger.audit.hive.query.visibility", true);
+		final boolean hiveQueryVisibility = PropertiesUtil.getBooleanProperty("ranger.audit.hive.query.visibility", true);
 		if (solrClient == null) {
-			logger.warn("Solr client is null, so not running the query.");
+			LOGGER.warn("Solr client is null, so not running the query.");
 			throw restErrorUtil.createRESTException(
 					"Error connecting to search engine",
 					MessageEnums.ERROR_SYSTEM);
 		}
-
 		List<VXAccessAudit> xAccessAuditList = new ArrayList<VXAccessAudit>();
 
+		Map<String, Object> paramList = searchCriteria.getParamList();
+		updateUserExclusion(paramList);
+
 		QueryResponse response = solrUtil.searchResources(searchCriteria,
 				searchFields, sortFields, solrClient);
 		SolrDocumentList docs = response.getResults();
@@ -151,13 +168,17 @@ public class SolrAccessAuditsService {
                                 }
                                 else if("hive".equalsIgnoreCase(vXAccessAudit.getServiceType()) && ("grant".equalsIgnoreCase(vXAccessAudit.getAccessType()) || "revoke".equalsIgnoreCase(vXAccessAudit.getAccessType()))){
                                         try {
+                                            if (vXAccessAudit.getRequestData() != null) {
                                                 vXAccessAudit.setRequestData(java.net.URLDecoder.decode(vXAccessAudit.getRequestData(), "UTF-8"));
+                                            } else {
+                                                LOGGER.warn("Error in request data of audit from solr. AuditData: "  + vXAccessAudit.toString());
+                                            }
                                         } catch (UnsupportedEncodingException e) {
-                                                logger.warn("Error while encoding request data");
+                                                LOGGER.warn("Error while encoding request data");
                                         }
                                 }
                         }
-			xAccessAuditList.add(vXAccessAudit);
+                        xAccessAuditList.add(vXAccessAudit);
 		}
 
 		VXAccessAuditList returnList = new VXAccessAuditList();
@@ -169,15 +190,66 @@ public class SolrAccessAuditsService {
 		return returnList;
 	}
 
+
+	private void updateUserExclusion(Map<String, Object> paramList) {
+		String val = (String) paramList.get("excludeServiceUser");
+
+		if (val != null && Boolean.valueOf(val.trim())) { // add param to negate requestUsers which will be added as
+			// filter query in solr
+			List<String> excludeUsersList = getExcludeUsersList();
+			if (CollectionUtils.isNotEmpty(excludeUsersList)) {
+				Object oldUserExclusions = paramList.get("-requestUser");
+				if (oldUserExclusions instanceof Collection && (!((Collection<?>)oldUserExclusions).isEmpty())) {
+					excludeUsersList.addAll((Collection<String>)oldUserExclusions);
+					paramList.put("-requestUser", excludeUsersList);
+				} else {
+					paramList.put("-requestUser", excludeUsersList);
+				}
+			}
+		}
+	}
+
+	private List<String> getExcludeUsersList() {
+		//for excluding serviceUsers using existing property in ranger-admin-site
+		List<String> excludeUsersList = new ArrayList<String>(getServiceUserList());
+
+		//for excluding additional users using new property in ranger-admin-site
+		String additionalExcludeUsers = PropertiesUtil.getProperty("ranger.accesslogs.exclude.users.list");
+		List<String> additionalExcludeUsersList = null;
+		if (StringUtils.isNotBlank(additionalExcludeUsers)) {
+			additionalExcludeUsersList = new ArrayList<>(Arrays.asList(StringUtils.split(additionalExcludeUsers, ",")));
+			for (String serviceUser : additionalExcludeUsersList) {
+				if (StringUtils.isNotBlank(serviceUser) && !excludeUsersList.contains(serviceUser.trim())) {
+					excludeUsersList.add(serviceUser);
+				}
+			}
+		}
+		return excludeUsersList;
+	}
+
+	private List<String> getServiceUserList() {
+		String components = EmbeddedServiceDefsUtil.DEFAULT_BOOTSTRAP_SERVICEDEF_LIST;
+		List<String> serviceUsersList = new ArrayList<String>();
+		List<String> componentNames =  Arrays.asList(StringUtils.split(components,","));
+		for(String componentName : componentNames) {
+			String serviceUser = PropertiesUtil.getProperty("ranger.plugins."+componentName+".serviceuser");
+			if(StringUtils.isNotBlank(serviceUser)) {
+				serviceUsersList.add(serviceUser);
+			}
+		}
+		return serviceUsersList;
+	}
+
 	/**
 	 * @param doc
 	 * @return
 	 */
 	private VXAccessAudit populateViewBean(SolrDocument doc) {
 		VXAccessAudit accessAudit = new VXAccessAudit();
+
 		Object value = null;
-		if(logger.isDebugEnabled()) {
-			logger.debug("doc=" + doc.toString());
+		if(LOGGER.isDebugEnabled()) {
+			LOGGER.debug("doc=" + doc.toString());
 		}
 
 		value = doc.getFieldValue("id");
@@ -190,7 +262,22 @@ public class SolrAccessAuditsService {
 		if (value != null) {
 			accessAudit.setClusterName(value.toString());
 		}
-		
+
+		value = doc.getFieldValue("zoneName");
+		if (value != null) {
+			accessAudit.setZoneName(value.toString());
+		}
+
+		value = doc.getFieldValue("agentHost");
+		if (value != null) {
+			accessAudit.setAgentHost(value.toString());
+		}
+
+		value = doc.getFieldValue("policyVersion");
+		if (value != null) {
+			accessAudit.setPolicyVersion(solrUtil.toLong(value));
+		}
+
 		value = doc.getFieldValue("access");
 		if (value != null) {
 			accessAudit.setAccessType(value.toString());
