@@ -135,6 +135,15 @@ public class VXAccessAudit extends VXDataObject implements java.io.Serializable
 	
 	protected String clusterName;
 
+	// Security Zone
+	protected String zoneName;
+	// Host Name
+	protected String agentHost;
+
+	// Policy Version
+
+	protected Long policyVersion;
+
 	/**
 	 * Default constructor. This will set all the attributes to default value.
 	 */
@@ -520,6 +529,43 @@ public class VXAccessAudit extends VXDataObject implements java.io.Serializable
 	    return AppConstants.CLASS_TYPE_XA_ACCESS_AUDIT;
 	}
 
+	/**
+	 * @return the zoneName
+	 */
+	public String getZoneName() {
+		return zoneName;
+	}
+	/**
+	 * @param zoneName
+	 *            the zoneName to set
+	 */
+	public void setZoneName(String zoneName) {
+		this.zoneName = zoneName;
+	}
+
+	public String getAgentHost() {
+		return agentHost;
+	}
+
+	public void setAgentHost(String agentHost) {
+		this.agentHost = agentHost;
+	}
+
+	/**
+	 * @return the policyVersion
+	 */
+	public Long getPolicyVersion() {
+		return policyVersion;
+	}
+	/**
+	 * @param policyVersion
+	 *            the policyVersion to set
+	 */
+	public void setPolicyVersion(Long policyVersion) {
+		this.policyVersion = policyVersion;
+	}
+
+
 	/**
 	 * This return the bean content in string format
 	 * @return formatedStr
@@ -535,6 +581,7 @@ public class VXAccessAudit extends VXDataObject implements java.io.Serializable
 		str += "clientIP={" + clientIP + "} ";
 		str += "clientType={" + clientType + "} ";
 		str += "policyId={" + policyId + "} ";
+		str += "policyVersion={" + policyVersion + "} ";
 		str += "repoName={" + repoName + "} ";
 		str += "repoType={" + repoType + "} ";
 		str += "serviceType={" + serviceType + "} ";
@@ -551,6 +598,8 @@ public class VXAccessAudit extends VXDataObject implements java.io.Serializable
 		str += "eventDuration={" + eventDuration + "}";
 		str += "tags={" + tags + "}";
 		str += "clusterName={" + clusterName + "}";
+		str += "zoneName={" + zoneName + "}";
+		str += "agentHost={" + agentHost + "}";
 		str += "}";
 		return str;
 	}
