@@ -77,6 +77,10 @@ public class VXPolicyExportAudit extends VXDataObject implements java.io.Seriali
 	
 	protected String clusterName;
 
+	protected String zoneName;
+
+	protected Long policyVersion;
+
 	/**
 	 * Default constructor. This will set all the attributes to default value.
 	 */
@@ -219,6 +223,21 @@ public class VXPolicyExportAudit extends VXDataObject implements java.io.Seriali
 		this.clusterName = clusterName;
 	}
 
+	public String getZoneName() {
+		return zoneName;
+	}
+
+	public void setZoneName(String zoneName) {
+		this.zoneName = zoneName;
+	}
+
+	public Long getPolicyVersion() {
+		return policyVersion;
+	}
+
+	public void setPolicyVersion(Long policyVersion) {
+		this.policyVersion = policyVersion;
+	}
 
 	@Override
 	public int getMyClassType( ) {
@@ -241,6 +260,8 @@ public class VXPolicyExportAudit extends VXDataObject implements java.io.Seriali
 		str += "httpRetCode={" + httpRetCode + "} ";
 		str += "syncStatus={" + syncStatus + "} ";
 		str += "clusterName={" + clusterName + "} ";
+		str += "zoneName={" + zoneName + "}";
+		str += "policyVersion={" + policyVersion + "}";
 		str += "}";
 		return str;
 	}
