@@ -64,6 +64,7 @@ define(function(require) {
 				groups 						: 'Groups',
 				group 						: 'Groups',
 				auditLogging 				: 'Audit Logging',
+				isDenyAllElse				: 'Deny All Other Accesses',
 				encrypted 					: 'Encrypt',
 				resourceType 				: 'Resource Type',
 				description 				: 'Description',
@@ -165,7 +166,7 @@ define(function(require) {
 				policyStatus					: 'Policy Status',
 				httpResponseCode				: 'Http Response Code',
 				repositoryName					: 'Repository Name',
-				agentId							: 'Plugin Id',
+				agentId							: 'Plugin ID',
 				agentIp							: 'Plugin IP',
 				createDate						: 'Export Date',
 				attributeName 					: 'Attribute Name',
@@ -177,12 +178,13 @@ define(function(require) {
 				columnType						: 'Column Type',
 				accountName						: 'Account Name',
 				createdDate						: 'Created Date',
-				sessionId						: 'Session Id',
+				sessionId						: 'Session ID',
 				operation						: 'Operation',
 				auditType						: 'Audit Type',
 				user							: 'User',
+				application						: 'Application',
 				actions							: 'Actions',
-				loginId							: 'Login Id',
+				loginId							: 'Login ID',
 				loginType						: 'Login Type',
 				ip								: 'IP',
 				userAgent						: 'User Agent',
@@ -242,6 +244,8 @@ define(function(require) {
                 lastUpdate                      : 'Last Update',
 		  		modules		                	: 'Modules',
                 clusterName                     : 'Cluster Name',
+                zoneName                        : 'Zone Name',
+                policyVersion                   : 'Policy Version',
                 policyLabels					: 'Policy Labels',
                 activeStatus                    : 'Active Status',
                 selectTagService                : 'Tag Service',
@@ -259,10 +263,21 @@ define(function(require) {
                 groupSearchFilter               : 'Group search filter',
                 startDate                       : 'Start Date',
                 endDate                         : 'End Date',
-                                addValidityPeriod				: 'Add Validity Period',
-                                editValidityPeriod				: 'Edit Validity Period',
+                addValidityPeriod               : ' Add Validity Period',
+                editValidityPeriod              : ' Edit Validity Period',
                 totalUsersSynced                : 'Total number of users synced',
                 totalGroupsSynced               : 'Total number of groups synced',
+                addPolicyCondition              : 'Add Policy Condition',
+                editPolicyCondition             : 'Edit Policy Condition',
+                agentHost	                    :'Agent Host Name',
+                addNewRole                      : 'Add New Role',
+                roleName                        : 'Role Name',
+                roleCreate                      : 'Role Create',
+                roleEdit                        : 'Role Edit',
+                roles                           : 'Roles',
+                userWithGrantRolePrivilege      : 'Users (Grant privilege)',
+                groupWithGrantRolePrivilege      : 'Groups (Grant privilege)',
+                applicationType					: 'Application',
 
 			},
 			btn : {
@@ -288,7 +303,7 @@ define(function(require) {
 				// Menu
 				dashboard					: 'Dashboard',
 				policyManager 				: 'Policy Manager',
-				usersOrGroups 				: 'Users/Groups',
+                                usersOrGroupsOrRoles		: 'Users/Groups/Roles',
 				reports 					: 'Reports',
 				config 						: 'Config',
 				accounts					: 'Accounts',
@@ -322,6 +337,7 @@ define(function(require) {
 				searchForPermissions		:"Search for permissions...",
 				searchForYourUser 			:"Search for your users...",
 				searchForYourGroup 			:"Search for your groups...",
+                                searchForYourRole			:"Search for your roles",
 				access						: 'Access',
 				policyCondition				: 'Policy Conditions',
 				permissions					: 'Permissions',
@@ -335,6 +351,7 @@ define(function(require) {
                 serviceTypeMsg              :'Select type of service.',
                 startDate                   :'Set start date.',
                 userMsg                     :'Name of User.',
+                application                 :'Application.',
                 tagsMsg                     :'Tag Name.',
                 endDate                     :'Set end date.',
                 groupNameMsg                :'Name of Group.',
@@ -348,6 +365,8 @@ define(function(require) {
                 udf                         :'Hive udf.',
                 pluginStatus                :'Plugin Status',
                 clusterName                 :'Name of ambari cluster',
+                zoneName                    :"Name of Zone",
+                policyVersion               :'Policy Version',
                 url        					:'Hive url.',
                 rowFilter                   : 'Row Filter',
                 policyLabelsinfo			: 'Label of policy',
@@ -364,7 +383,10 @@ define(function(require) {
                 link                        :'Linker Name.',
                 job                         :'Sqoop Job Name.',
                 project                     :'Kylin Project Level.',
-                nifiResource                :'NiFi Resource Identifier.'
+                nifiResource                :'NiFi Resource Identifier.',
+                securityZone				:'Security Zone',
+                zoneCreate					:'Create Zone',
+                zoneEdit					:'Zone Edit'
                         },
 			msg : {
 				deletePolicyValidationMsg : 'Policy does not have any settings for the specific resource. Policy will be deleted. Press [Ok] to continue. Press [Cancel] to edit the policy.',
@@ -393,8 +415,8 @@ define(function(require) {
 				noRecordsFound			  : 'No Records Found',
 				keyDeleteMsg			  : 'Key deleted successfully',
 				rolloverSuccessfully	  : 'Key rollover successfully',
-				addUserOrGroup			  : 'Please select group/user for the selected permission, else group/user will not be added.',
-				addUserOrGroupForPC		  : 'Please select group/user for the added policy condition, else group/user will not be added.',
+                                addUserOrGroupOrRole	  : 'Please select group/user/role for the selected permission, else group/user will not be added.',
+                                addUserOrGroupOrRoleForPC : 'Please select group/user/role for the added policy condition, else group/user will not be added.',
 				userCreatedSucc		      : 'User created successfully',
 				userUpdatedSucc           :     'User updated successfully',
 				grpUpdatedSucc            : 'Group updated successfully',
@@ -430,15 +452,31 @@ define(function(require) {
                 noDeleteGroupRow        :'Please select group first to delete.',
                 plsSelectUserToSetVisibility :' Please select user to set visibility or selected user is already visible/hidden.',
                 plsSelectGroupToSetVisibility:' Please select group to set visibility or selected group is already visible/hidden.',
-                activationTimeDelayMsg       :'Policy activation time delayed by more than 1hr from last update time.',
+                activationTimeDelayMsg       : 'Policy is updated but not yet used for any enforcement.',
                 pleaseSelectAccessTypeForTagMasking : 'Please select access type first to enable add masking options.',
-                addUserOrGroupForDelegateAdmin      : 'Please select user/group for the selected permission(s)',
+                addUserOrGroupOrRoleForDelegateAdmin      : 'Please select user/group/role for the selected permission(s)',
                 policyLabelsinfo		: 'Enter label of policy',
-                noUserFoundText			: 'No user associate with this group.',
+                noUserFoundText			: 'No user is associated with this group.',
                 showInitialHundredUser  : 'Initially search filter is applied for first hundred users. To get more users click on ',
                 searchForUserSync       :"Search for your user sync audits...",
                 policyExpired           :'Policy Expired',
-                duplicateNewConfigValidationMsg     :'Please make sure the new configuration has no duplicate names'
+                duplicateNewConfigValidationMsg     :'Please make sure the new configuration has no duplicate names',
+                zoneDeleteMsg 		    : 'Zone deleted successfully',
+                zoneNameValidation	    : 'Please select Zone Name.',
+                policyVersionValidation	: 'Please select Policy Version.',
+                zoneServiceNameValidation: 'Please select Service Name for selected zone.',
+                adminUserGroupValidation: 'Please select atleast one Admin Users/Usergroups to Zone else Zone will not be added.',
+                auditorUserGroupValidation: 'Please select atleast one Auditor Users/Usergroups to Zone else Zone will not be added.',
+                selectZoneFile          : 'Selected file does not contain zone details, Please select appropriate file containing zone details',
+                selectOtherFile         : 'Selected file contains zone details, Please select appropriate file without zone details',
+                policyTimeDetails       : '<b>Last Update: </b>Last updated time of policy.<br><b>Download: </b>Time when policy actually downloaded(sync-up with Ranger).<br>\
+                                            <b>Active: </b>Time when policy actually in use for enforcement.',
+                tagPolicyTimeDetails    : '<b>Last Update: </b> Last updated time of Tag-service.<br><b>Download: </b>Time when tag-based policies sync-up with Ranger.<br>\
+                                            <b>Active: </b>Time when tag-based policies in use for enforcement.',
+                noDeleteRoleRow         :'Please select ranger role first to delete.',
+                addRolePermission       : 'Please add permission(s) for the selected role, else role will not be added.',
+                addRole                 : 'Please select role for the selected permission(s), else role will not be added.',
+                addSelectedUserGroupRoles : 'Please add selected user/group/roles to there respective table else user/group/roles will not be added.'
 
 			},
 			plcHldr : {
@@ -450,7 +488,8 @@ define(function(require) {
 				preventNavRepositoryForm : 'Repository form edit is in progress. Please save/cancel changes before navigating away!',
 				preventNavUserForm : 'User form edit is in progress. Please save/cancel changes before navigating away!',
 				preventNavGroupForm : 'Group form edit is in progress. Please save/cancel changes before navigating away!',
-				preventNavUserList : 'Some Users/Groups have been edited. Kindly save your changes before navigating away!'
+				preventNavUserList : 'Some Users/Groups have been edited. Kindly save your changes before navigating away!',
+				preventNavZoneForm : 'Zone form edit is in progress. Please save/cancel changes before navigating away!'
 				
 			},	
 			validationMessages : {
@@ -469,6 +508,10 @@ define(function(require) {
                 lastNameValidationMsg  :'1. Last name should be start with alphabet / numeric / underscore / non-us characters.<br> 2. Allowed special character ._-@ and space. <br>3. Name length should be greater than one.',
                 setTimeZoneErrorMsg    :'Please select Start/End date for Time zone',
                 jsValidationMsg        :'1. JavaScript Condition Examples :\ncountry_code == \'USA\', time_range >= 900 && time_range <= 1800 etc.\n2. Dragging bottom-right corner of javascript condition editor(Textarea) can resizable',
+				emailAddressValidationMsg  :'1. Email address should be start with alphabet / numeric / underscore / non-us characters.<br> 2. Allowed special character <b>.-@</b> .<br>3. Email address length should be greater than 9 characters.<br> 4. Email address examples : abc@de.fg, A-C@D-.FG',
+                nameValidationMsg      :'Name should not start with space, it should be less than 256 characters and special characters are not allowed(except _ - and space).',
+                roleNameValidationMsg :'1. Role name should be start with alphabet / numeric / underscore / non-us characters.<br> 2. Allowed special character ,._\-+/@= and space. <br>3. Name length should be greater than one.',
+                policyNameValidationMsg   :'Please avoid these characters (&, <, >, \', ", `) for policy name.',
 			},
 			serverMsg : {
 
