@@ -236,8 +236,7 @@ define(function(require) {
 	 */
 	XAUtils.notifyError = function(type, text, options) {
 		var html = '<div style="width: 245px;"><div style="min-height: 16px;"><div><span class="icon-warning-sign"></span>\
-			</div><h4 style="margin-top: -19px;margin-left: 15px;">Error</h4><div>'
-                                + _.escape(text) + '</div></div></div>';
+			</div><h4 style="margin-top: -19px;margin-left: 15px;">Error</h4><div>' + text + '</div></div></div>';
 		if (_.isUndefined(options)) {
 			options = {
 				message : {
@@ -406,6 +405,7 @@ define(function(require) {
 	 *            params - The params
 	 */
 	XAUtils.alertPopup = function(params) {
+		bootbox.hideAll();
 		if (params.callback == undefined) {
 			bootbox.alert(params.msg);
 		} else {
@@ -466,40 +466,40 @@ define(function(require) {
 		options = _.isUndefined(options) ? Opt : options;
 		$.msg(options);
 	};
-	XAUtils.showGroups = function(rawValue) {
+        XAUtils.showMoreLessBtnForGroupsUsersRoles = function(rawValue , type) {
 		var showMoreLess = false, id;
 		if (_.isArray(rawValue))
 			rawValue = new Backbone.Collection(rawValue);
 		if (!_.isUndefined(rawValue) && rawValue.models.length > 0) {
 			var groupArr = _.uniq(_.compact(_.map(rawValue.models, function(m,
 					i) {
-				if (m.has('groupName'))
-					return _.escape(m.get('groupName'));
+                                if (m.has('entityName'))
+                                        return _.escape(m.get('entityName'));
 			})));
 			if (groupArr.length > 0) {
 				if (rawValue.first().has('resourceId'))
 					id = rawValue.first().get('resourceId');
 				else
-					id = rawValue.first().get('userId');
+                                        id = rawValue.first().get('modelId');
 			}
 			var newGroupArr = _.map(groupArr, function(name, i) {
 				if (i >= 4)
-					return '<span class="label label-info float-left-margin-2" policy-group-id="'
+                                        return '<span class="label label-info float-left-margin-2" data-name='+type+' model-'+ type +'-id="'
 							+ id + '" style="display:none;">' + name
 							+ '</span>';
 				else if (i == 3 && groupArr.length > 4) {
 					showMoreLess = true;
-					return '<span class="label label-info float-left-margin-2" policy-group-id="'
+                                        return '<span class="label label-info float-left-margin-2" data-name='+type+' model-'+ type +'-id="'
 							+ id + '">' + name + '</span>';
 				} else
-					return '<span class="label label-info float-left-margin-2" policy-group-id="'
+                                        return '<span class="label label-info float-left-margin-2" data-name='+type+' model-'+ type +'-id="'
 							+ id + '">' + name + '</span>';
 			});
 			if (showMoreLess) {
 				newGroupArr
-						.push('<span class="float-left-margin-2"><a href="javascript:void(0);" data-id="showMore" class="" policy-group-id="'
+                                                .push('<span class="float-left-margin-2"><a href="javascript:void(0);" data-id="showMore" class="" data-name='+type+' model-'+ type +'-id="'
 								+ id
-								+ '"><code style=""> + More..</code></a></span><span class="float-left-margin-2"><a href="javascript:void(0);" data-id="showLess" class="" policy-group-id="'
+                                                                + '"><code style=""> + More..</code></a></span><span class="float-left-margin-2"><a href="javascript:void(0);" data-id="showLess" class="" data-name='+type+' model-'+ type +'-id="'
 								+ id
 								+ '" style="display:none;"><code> - Less..</code></a></span>');
 			}
@@ -509,7 +509,7 @@ define(function(require) {
 		} else
 			return '--';
 	};
-	XAUtils.showGroupsOrUsersForPolicy = function(rawValue, model, showGroups, rangerServiceDefModel) {
+        XAUtils.showGroupsOrUsersForPolicy = function(rawValue, model, showType, rangerServiceDefModel) {
 		var showMoreLess = false, groupArr = [], items = [];
 		var itemList = ['policyItems','allowExceptions','denyPolicyItems','denyExceptions','dataMaskPolicyItems','rowFilterPolicyItems']
 		if(!_.isUndefined(rangerServiceDefModel)){
@@ -521,7 +521,7 @@ define(function(require) {
 				: this.isMaskingPolicy(model.get('policyType')) ? _.difference(itemList, ["rowFilterPolicyItems"])
 				: this.isRowFilterPolicy(model.get('policyType')) ? _.difference(itemList, ["dataMaskPolicyItems"]) : itemList; 
 						
-		var type = _.isUndefined(showGroups) || showGroups ? 'groups' : 'users';
+                var type = _.isUndefined(showType) || (showType == 'groups') ? 'groups' : ((showType == 'users') ? 'users' : 'roles');
 		_.each(itemList, function(item){
 		    if(!_.isUndefined(model.get(item)) && !_.isEmpty(model.get(item))) {
 		    	items =_.union(items,  model.get(item))
@@ -655,11 +655,13 @@ define(function(require) {
 				// _.filter(policyItems,function(m){if(!_.isEmpty(m.groups))
 				// return m;});
 				_.each(policyItems, function(obj) {
-					var groupNames = null, userNames = null;
+                                        var groupNames = null, userNames = null, roleNames = null;
 					if (!_.isEmpty(obj.groups))
 						groupNames = obj.groups;
 					if (!_.isEmpty(obj.users))
 						userNames = obj.users;
+                                        if (!_.isEmpty(obj.roles))
+                                                roleNames = obj.roles;
 					var m = new Backbone.Model({
 						groupName : groupNames,
 						userName : userNames,
@@ -667,6 +669,7 @@ define(function(require) {
 						conditions : obj.conditions,
 						delegateAdmin : obj.delegateAdmin,
 						editMode : true,
+                                                roleName : roleNames,
 					});
 					if(that.isMaskingPolicy(model.get('policyType'))){
 						m.set('dataMaskInfo', obj.dataMaskInfo)
@@ -759,12 +762,17 @@ define(function(require) {
 	XAUtils.addVisualSearch = function(searchOpt, serverAttrName, collection,
 			pluginAttr) {
 		var visualSearch, that = this;
-		var search = function(searchCollection, serverAttrName, searchOpt,
-				collection) {
+		var supportMultipleItems = pluginAttr.supportMultipleItems || false;
+		var multipleFacet = serverAttrName.filter(function(elem) { 
+			return elem['addMultiple'];
+		}).map(function(elem) {
+			return elem.text;
+		});
+		var search = function(searchCollection, collection) {
 			var params = {};
-                        if($('.popover')){
-                                $('.popover').remove();
-                        }
+			if($('.popover')){
+					$('.popover').remove();
+			}
 			searchCollection.each(function(m) {
 				var serverParamName = _.findWhere(serverAttrName, {
 					text : m.attributes.category
@@ -779,8 +787,20 @@ define(function(require) {
 					$.extend(params, extraParam);
 				} else {
 					if (!_.isUndefined(serverParamName)) {
-						extraParam[serverParamName.label] = m.get('value');
-						$.extend(params, extraParam);
+						var oldValue = params[serverParamName.label];
+						var newValue = m.get('value');
+						if (oldValue && serverParamName.addMultiple) {
+							// if a value is already there
+							if (Array.isArray(oldValue)) {
+								// if it's a list, append to the end
+								oldValue.push(newValue);
+							} else {
+								// convert to a list
+								params[serverParamName.label] = [oldValue, newValue];
+							}
+						} else {
+							params[serverParamName.label] = newValue;
+						}
 					}
 				}
 			});
@@ -789,6 +809,7 @@ define(function(require) {
 			collection.fetch({
 				reset : true,
 				cache : false,
+				traditional: supportMultipleItems, // for sending multiple values without []
 				error : function(coll, response, options) {
 					that.blockUI('unblock');
                                         if(response && response.responseJSON && response.responseJSON.msgDesc){
@@ -804,7 +825,7 @@ define(function(require) {
 		var callbackCommon = {
 			search : function(query, searchCollection) {
 				collection.VSQuery = query;
-				search(searchCollection, serverAttrName, searchOpt, collection);
+				search(searchCollection, collection);
 			},
 			clearSearch : function(callback) {
                                 //Remove search history when click on clear search
@@ -821,8 +842,9 @@ define(function(require) {
 				// console.log(visualSearch);
 				var searchOptTemp = $.extend(true, [], searchOpt);
 				visualSearch.searchQuery.each(function(m) {
-					if ($.inArray(m.get('category'), searchOptTemp) >= 0) {
-						searchOptTemp.splice($.inArray(m.get('category'),
+					var cat = m.get('category');
+					if ($.inArray(cat, searchOptTemp) >= 0 && $.inArray(cat, multipleFacet) < 0) {
+						searchOptTemp.splice($.inArray(cat,
 								searchOptTemp), 1);
 					}
 				});
@@ -839,7 +861,15 @@ define(function(require) {
 					text : removedFacet.get('category')
 				});
 				if (!_.isUndefined(removedFacetSeverName)) {
-					delete collection.queryParams[removedFacetSeverName.label];
+					var queryValue = collection.queryParams[removedFacetSeverName.label];
+					if ($.inArray(removedFacetSeverName.text, multipleFacet) && Array.isArray(queryValue)) {
+						var idx = queryValue.indexOf(removedFacet.get("value"));
+						if (idx != -1) {
+							queryValue.splice(idx);
+						}
+					} else {
+						delete collection.queryParams[removedFacetSeverName.label];
+					}
 					collection.state.currentPage = collection.state.firstPage;
 				}
 				// TODO Added for Demo to remove datapicker popups
@@ -856,8 +886,7 @@ define(function(require) {
 		}));
 
 		if (visualSearch.searchQuery.length > 0) // For On Load Visual Search
-			search(visualSearch.searchQuery, serverAttrName, searchOpt,
-					collection);
+			search(visualSearch.searchQuery, collection);
 
 		return visualSearch;
 	};
@@ -1106,6 +1135,9 @@ define(function(require) {
 	XAUtils.getRangerServiceDef = function(name) {
 		return "service/plugins/definitions/name/" + name;
 	};
+	XAUtils.getZonesURL = function(zoneId) {
+		return "service/zones/" + zoneId;
+	};
 	XAUtils.filterAllowedActions = function(controller) {
 		var SessionMgr = require('mgrs/SessionMgr');
 			var XAGlobals = require('utils/XAGlobals');
@@ -1262,6 +1294,22 @@ define(function(require) {
 		}
 		return singleValue;
 	};
+	XAUtils.hideIfNull = function(obj, form){
+		//resorces hide show
+		var hideIfNull = false;
+		if(!_.isEmpty(obj.uiHint)){
+			var UIHint = JSON.parse(obj.uiHint);
+			if(!_.isUndefined(form.model.get('resources')) && !_.isEmpty(form.model.get('resources')) &&
+					_.has(form.model.get('resources'), obj.name)){
+				 hideIfNull = false;
+			}else{
+				if(!_.isUndefined(UIHint.hideIfNull) && ! obj.mandatory){
+					hideIfNull = UIHint.hideIfNull;
+				}
+			}
+		}
+		return hideIfNull;
+	};
 	XAUtils.getBaseUrl = function (){
 		if(!window.location.origin){
 			window.location.origin = window.location.protocol + "//" + window.location.hostname + (window.location.port ? ':' + window.location.port: '');
@@ -1463,8 +1511,232 @@ define(function(require) {
                         }
                     }
                 },
-            }
+            };
+
         return opts;
     }
+
+    //get policy conditions details
+    XAUtils.getPolicyConditionDetails = function(policyCondtions, serviceDef){
+        var condtionsDetails = [];
+        _.each(policyCondtions, function(val){
+        var conditionsVal = serviceDef.get('policyConditions').find(function(m){return m.name == val.type});
+            condtionsDetails.push({'name' : conditionsVal.label, 'values' : val.values});
+        })
+        return condtionsDetails;
+    }
+
+    //get list of all tag base services
+    XAUtils.getTagBaseServices = function(){
+        return {
+            closeOnSelect : true,
+            placeholder : 'Select Tag Services',
+            width :'600px',
+            allowClear: true,
+            multiple: true,
+            tokenSeparators: ["," , " "],
+            initSelection : function (element, callback) {
+                var tags = [];
+                _.each(element.val().split(','), function(name) {
+                    tags.push({
+                        'id': _.escape(name),
+                        'text': _.escape(name)
+                    });
+                });
+                callback(tags)
+            },
+            ajax: {
+                url: "service/plugins/services",
+                dataType: 'json',
+                data: function (term, page) {
+                    return { serviceNamePartial : term, serviceType : 'tag' };
+                },
+                results: function (data, page) {
+                    var results = [];
+                    if(data.resultSize != "0"){
+                        results = data.services.map(function(m, i){ return {id : _.escape(m.name), text: _.escape(m.name) };    });
+                        return {results : results};
+                    }
+                    return {results : results};
+                },
+                transport : function (options) {
+                                            $.ajax(options).fail(function(respones) {
+                        XAUtils.defaultErrorHandler('error',respones);
+                        this.success({
+                            resultSize : 0
+                        });
+                    });
+                }
+            },
+            formatResult : function(result){
+                return result.text;
+            },
+            formatSelection : function(result){
+                return result.text;
+            },
+            formatNoMatches: function(result){
+                return 'No tag service found.';
+            }
+        };
+    }
+
+    //Custom popover
+    XAUtils.customPopover = function($element, title, msg, placement){
+        $element.popover({
+            trigger: "manual",
+            title:title,
+            html: true,
+            animation:false,
+            content: msg,
+            container:'body',
+            placement: placement,
+        }).on("mouseenter", function () {
+            var _this = this;
+            $(this).popover("show");
+            $(".popover").on("mouseleave", function () {
+                $(_this).popover('hide');
+            });
+        }).on("mouseleave", function () {
+            var _this = this;
+            setTimeout(function () {
+                if (!$(".popover:hover").length) {
+                    $(_this).popover("hide");
+                }
+            }, 300);
+        });
+    }
+
+    XAUtils.getUsersGroupsList = function($select, domElement){
+        var that = domElement,
+            tags = [],
+            placeholder = $select === 'users' ? "Select User" : $select === 'groups' ? "Select Group" : "Select Role",
+            searchUrl = $select === 'users' ? "service/xusers/lookup/users" : $select === 'groups' ? "service/xusers/lookup/groups"
+                : "service/roles/roles";
+            // if(that.model && !_.isEmpty(that.model.get('name'))){
+            //     tags.push({
+            //         'id': _.escape(that.model.get('name')),
+            //         'text': _.escape(that.model.get('name'))
+            //     });
+            //     domElement.ui['selectUsersOrGroups'].val(tags.map(function(val) {
+            //         return val.text
+            //     }));
+            // }
+
+        return {
+            closeOnSelect : true,
+            placeholder   : placeholder,
+            tags : true,
+            width : '300px',
+            initSelection: function(element, callback) {
+                callback(tags);
+            },
+            ajax: {
+                url: searchUrl,
+                dataType: 'json',
+                data: function(term, page) {
+                    return {
+                        name: term,
+                        isVisible : XAEnums.VisibilityStatus.STATUS_VISIBLE.value,
+                    };
+                },
+                results: function(data, page) {
+                    var results = [],
+                        selectedVals = [];
+                    //Get selected values of groups/users dropdown
+                    if (data.totalCount != "0") {
+                        //remove users {USER} and {OWNER}
+                        if ($select == 'users' || $select == 'groups') {
+                            data.vXStrings = _.reject(data.vXStrings, function(m){return (m.value == '{USER}' || m.value == '{OWNER}')})
+                            results = data.vXStrings.map(function(m) {
+                                return {
+                                    id: _.escape(m.value),
+                                    text: _.escape(m.value)
+                                };
+                            });
+                        } else {
+                            if(that.model && !_.isEmpty(that.model.get('name'))){
+                                data.roles = _.reject(data.roles, function(m){
+                                    return (m.name == that.model.get('name'))
+                                })
+                            }
+                            results = data.roles.map(function(m){
+                                return {
+                                    id : _.escape(m.name),
+                                    text: _.escape(m.name)
+                                };
+                            });
+                        }
+                        //remove selected values
+                        if(that.collection && that.collection.models){
+                            _.filter(that.collection.models, function(model){
+                                if(model && !_.isUndefined(model.get('name'))){
+                                    selectedVals.push(model.get('name'));
+                                }
+                            })
+                        }
+                        if (!_.isEmpty(selectedVals)) {
+                            results = XAUtils.filterResultByText(results, selectedVals);
+                        }
+                        return {
+                            results: results
+                        };
+                    }
+                    return {
+                        results: results
+                    };
+                },
+                transport: function(options) {
+                    $.ajax(options).fail(function(respones) {
+                        XAUtils.defaultErrorHandler('error', respones);
+                        this.success({
+                            resultSize: 0
+                        });
+                    });
+                }
+            },
+            formatResult: function(result) {
+                return result.text;
+            },
+            formatSelection: function(result) {
+                return result.text;
+            },
+            formatNoMatches: function(result) {
+                return $select === 'users' ? "No user found." : $select === 'groups' ? "No group found." : "No role found.";
+            }
+
+        }
+    }
+
+    //string contain escape character or not
+    XAUtils.checkForEscapeCharacter = function(policyName){
+        var escapeCharacter = ["&amp;", "&lt;", "&gt;", "&quot;", "&#96;", "&#x27;"];
+        return _.some(escapeCharacter, function(m){
+            return policyName.includes(m);
+        });
+    }
+
+    //remove sort caret on grids
+    XAUtils.backgirdSort = function(col){
+        col.on('backgrid:sort', function(model) {
+            // No ids so identify model with CID
+            var cid = model.cid;
+            var filtered = model.collection.filter(function(model) {
+                return model.cid !== cid;
+            });
+            _.each(filtered, function(model) {
+               model.set('direction', null);
+            });
+        });
+    }
+
+    //Scroll up for roles create page
+    XAUtils.scrollToRolesField = function(field) {
+        $("html, body").animate({
+            scrollTop : field.position().top - 150
+        }, 1100, function() {
+            field.focus();
+        });
+    };
+
 	return XAUtils;
 });
\ No newline at end of file
