@@ -26,6 +26,7 @@ define(function(require){
         var TopNav_tmpl = require('hbs!tmpl/common/TopNav_tmpl');
         var SessionMgr  = require('mgrs/SessionMgr');
         var XAUtil = require('utils/XAUtils');
+        var App    =require('App');
 	require('jquery.cookie');
 	var TopNav = Backbone.Marionette.ItemView.extend(
 	/** @lends TopNav */
@@ -35,7 +36,8 @@ define(function(require){
     	template: TopNav_tmpl,
     	templateHelpers : function(){
         return{
-                showPermissionTab : XAUtil.isAuditorOrSystemAdmin(SessionMgr)
+                showPermissionTab : XAUtil.isAuditorOrSystemAdmin(SessionMgr),
+                hideSecurityZoneTab : (SessionMgr.isKeyAdmin() || SessionMgr.isKMSAuditor()) ? true : false,
 		}
     	},
         
