@@ -33,9 +33,11 @@ define(function(require){
 	var VXAuditMapList	= require('collections/VXAuditMapList');
 	var VXUserList		= require('collections/VXUserList');
 	var PermissionList 	= require('views/policies/PermissionList');
-  var vPolicyTimeList 	= require('views/policies/PolicyTimeList');
+    var vPolicyTimeList 	= require('views/policies/PolicyTimeList');
 	var RangerPolicyResource		= require('models/RangerPolicyResource');
 	var BackboneFormDataType	= require('models/BackboneFormDataType');
+    var App             = require('App');
+    var vPolicyCondition = require('views/policies/RangerPolicyConditions');
 
 	require('backbone-forms.list');
 	require('backbone-forms.templates');
@@ -64,9 +66,14 @@ define(function(require){
 			}
 			return { 'id' : this.model.id,
 					'policyType' : policyType.label,
-                                        'conditionType' : conditionType,
-          'policyTimeBtnLabel': (this.model.has('validitySchedules') && this.model.get('validitySchedules').length > 0) ? localization.tt('lbl.editValidityPeriod')
-                  : localization.tt('lbl.addValidityPeriod')
+					'conditionType' : conditionType,
+					'policyTimeBtnLabel': (this.model.has('validitySchedules') && this.model.get('validitySchedules').length > 0) ? localization.tt('lbl.editValidityPeriod')
+						: localization.tt('lbl.addValidityPeriod'),
+					'policyConditionHideShow' : (this.rangerServiceDefModel.has('policyConditions') && !_.isEmpty(this.rangerServiceDefModel.get('policyConditions'))) ?
+					true : false,
+					'policyConditionIconClass': (this.model.has('conditions') && this.model.get('conditions').length > 0) ? 'icon-pencil' : 'icon-plus',
+					'conditionsData': (this.model.has('conditions') && this.model.get('conditions').length > 0) ?
+						XAUtil.getPolicyConditionDetails(this.model.get('conditions'), this.rangerServiceDefModel) : [],
 				};
 		},
 		initialize: function(options) {
@@ -104,7 +111,10 @@ define(function(require){
 		ui : {
 			'denyConditionItems' : '[data-js="denyConditionItems"]',
 			'allowExcludePerm' : '[data-js="allowExcludePerm"]',
-      'policyTimeBtn'      : '[data-js="policyTimeBtn"]'
+      		'policyTimeBtn'      : '[data-js="policyTimeBtn"]',
+			'policyConditions' : '[data-js="customPolicyConditions"]',
+            'conditionData' : '[data-id="conditionData"]',
+            'isDenyAllElse' : '[data-js="isDenyAllElse"]',
 		},
 		/** fields for the form
 		*/
@@ -119,10 +129,11 @@ define(function(require){
 
 			var formDataType = new BackboneFormDataType();
 			attrs = formDataType.getFormElements(this.rangerServiceDefModel.get('resources'),this.rangerServiceDefModel.get('enums'), attrs, this, true);
-
-			var attr1 = _.pick(_.result(this.model,'schemaBase'),basicSchema);
-			var attr2 = _.pick(_.result(this.model,'schemaBase'),schemaNames);
-			return _.extend(attr1,_.extend(attrs,attr2));
+                        if(this.model.schemaBase){
+                                var attr1 = _.pick(_.result(this.model,'schemaBase'),basicSchema);
+                                var attr2 = _.pick(_.result(this.model,'schemaBase'),schemaNames);
+                                return _.extend(attr1,_.extend(attrs,attr2));
+                        }
 		},
 		/** on render callback */
 		render: function(options) {
@@ -132,20 +143,27 @@ define(function(require){
                         if(!_.isUndefined(this.initilializePathPlugin) && this.initilializePathPlugin){
 				this.initializePathPlugins(this.pathPluginOpts);
 			}
-			this.renderCustomFields();
+			if(XAUtil.isAccessPolicy(this.model.get('policyType'))){
+				this.evdenyAccessChange();
+			}
 			if(!this.model.isNew()){
 				this.setUpSwitches();
 			}
+			this.renderCustomFields();
 			//checkParent
 			this.renderParentChildHideShow();
 
 			//to show error msg on below the field(only for policy name)
-			this.fields.isEnabled.$el.find('.control-label').removeClass();
-			this.fields.name.$el.find('.help-inline').removeClass('help-inline').addClass('help-block margin-left-5')
-			this.initializePlugins();
-                        this.setPolicyValidityTime();
-
-		},
+            if(this.fields.isEnabled){
+                    this.fields.isEnabled.$el.find('.control-label').removeClass();
+            }
+            if(this.fields.name){
+                    this.fields.name.$el.find('.help-inline').removeClass('help-inline').addClass('help-block margin-left-5');
+            }
+            this.initializePlugins();
+            this.setPolicyValidityTime();
+            this.setPolicyCondition();
+        },
             setPolicyValidityTime : function(){
               var that = this;
               this.$el.find(this.ui.policyTimeBtn).on('click', function(e){
@@ -188,6 +206,68 @@ define(function(require){
                 });
               });
             },
+
+        setPolicyCondition : function(){
+            var that = this;
+            this.$el.find(this.ui.policyConditions).on('click', function(e){
+                var view = new vPolicyCondition({
+                    rangerServiceDefModel : that.rangerServiceDefModel,
+                    model : that.model
+                });
+                var modal = new Backbone.BootstrapModal({
+                  content   : view,
+                    title : 'Policy Conditions',
+                    okText  :"Save",
+                    animate : true,
+                    focusOk:false,
+                    escape:false,
+                    modalOptions:{
+                        backdrop: 'static',
+                    },
+                }).open();
+                modal.$el.addClass('modal-policy-conditions');
+                $('body').addClass('hideBodyScroll')
+                //To prevent modal being close by click out of modal
+                modal.$el.find('.cancel, .close').on('click', function(e){
+                  modal._preventClose = false;
+                  $('body').removeClass('hideBodyScroll');
+                  $('[data-js="customPolicyConditions"]').addClass('dirtyField');
+                });
+                modal.$el.find('.ok').on('click', function(e){
+                    modal._preventClose = false;
+                    $('body').removeClass('hideBodyScroll');
+                    $('[data-js="customPolicyConditions"]').addClass('dirtyField');
+                    var conditions = [], $data = [];
+                    _.each(modal.$el.find('[data-id="inputField"],[data-id="textAreaContainer"]'), function(m, context){
+                        var inputFieldName = m.name;
+                        if(m.value !== " " && !_.isEmpty(m.value)){
+                            conditions.push({type : inputFieldName, values : (m.value.split(',')).filter(Boolean)});
+                        }
+                    });
+                    that.model.set('conditions',conditions);
+                    if(conditions.length > 0){
+                        that.$el.find('[data-id="policyCondIcon"]').removeClass('icon-plus').addClass('icon-pencil');
+                    } else {
+                        that.$el.find('[data-id="policyCondIcon"]').removeClass('icon-pencil').addClass('icon-plus');
+                    }
+                    _.each(that.model.get('conditions'), function(val){
+                        console.log(that);
+                        var conditionName = that.rangerServiceDefModel.get('policyConditions').find(function(m){return m.name == val.type});
+                        $data.push('<tr><td width="40%">'+_.escape(conditionName.label)+'</td><td width="60%">'+(val.values).toString()+'</td></tr>')
+                    });
+                    if($data.length > 0){
+                        that.$el.find(that.ui.conditionData).html($data);
+                    }else{
+                        that.$el.find(that.ui.conditionData).html('<tr><td> No Conditions </td></tr>');
+                    }
+                });
+                modal.on('shown', function(a){
+                  this.preventClose();
+                });
+
+            })
+        },
+
 		initializePlugins : function() {
 			var that = this;
 			this.$(".wrap-header").each(function(i, ele) {
@@ -245,6 +325,22 @@ define(function(require){
 		evIsEnabledChange : function(form, fieldEditor){
 			XAUtil.checkDirtyFieldForToggle(fieldEditor.$el);
 		},
+		evdenyAccessChange : function(){
+			var that =this;
+			this.$el.find(this.ui.isDenyAllElse).toggles({
+			    	on : that.model.has('isDenyAllElse') ? that.model.get('isDenyAllElse') : false,
+			    	text : {on : 'True', off : 'False' },
+			    	width : 80,
+			}).on('click', function(e){
+				XAUtil.checkDirtyFieldForToggle(that.$el.find(that.ui.isDenyAllElse));
+				if(that.$el.find(that.ui.isDenyAllElse).find('.toggle-slide').hasClass('active')) {
+					that.$el.find(that.ui.denyConditionItems).hide();
+				} else {
+					that.$el.find(that.ui.denyConditionItems).show();
+				}
+			});
+
+		},
 		setupForm : function() {
 			if(!this.model.isNew()){
 				this.selectedResourceTypes = {};
@@ -317,7 +413,10 @@ define(function(require){
 			if( !enableDenyAndExceptionsInPolicies ){
 				this.$el.find(this.ui.allowExcludePerm).hide();
 				this.$el.find(this.ui.denyConditionItems).remove();
-			} 
+			}
+			if(enableDenyAndExceptionsInPolicies && this.$el.find(this.ui.isDenyAllElse).find('.toggle-slide').hasClass('active')){
+				this.$el.find(this.ui.denyConditionItems).hide();
+			}
 	
                         that.$('[data-customfields="groupPerms"]').html(new PermissionList({
                                 collection : that.formInputList,
@@ -485,11 +584,13 @@ define(function(require){
 //					}
 				}
 			});
-                        if(this.model.has('policyLabels')){
-                            var policyLabel =[];
-                            policyLabel= this.model.get('policyLabels').split(',');
-                            this.model.set('policyLabels', policyLabel);
-                        }
+            if(this.model.has('policyLabels')){
+                var policyLabel = _.isEmpty(this.model.get('policyLabels')) ? [] : this.model.get('policyLabels').split(',');
+                this.model.set('policyLabels', policyLabel);
+            }
+            if(!_.isUndefined(App.vZone) && App.vZone.vZoneName){
+                this.model.set('zoneName', App.vZone.vZoneName);
+            }
 			this.model.set('resources',resources);
 			this.model.unset('path');
 			
@@ -500,20 +601,35 @@ define(function(require){
 			}else if( XAUtil.isRowFilterPolicy(this.model.get('policyType')) ){
 				this.model.set('rowFilterPolicyItems', this.setPermissionsToColl(this.formInputList, new RangerPolicyItem()));
 			}else{
+	            if(this.$el.find(this.ui.isDenyAllElse).find('.toggle-slide').hasClass('active')) {
+	            	this.model.set('isDenyAllElse',true);
+	            } else {
+	            	this.model.set('isDenyAllElse',false);
+	            }
 				this.model.set('policyItems', this.setPermissionsToColl(this.formInputList, new RangerPolicyItem()));
-				this.model.set('denyPolicyItems', this.setPermissionsToColl(this.formInputDenyList, new RangerPolicyItem()));
 				this.model.set('allowExceptions', this.setPermissionsToColl(this.formInputAllowExceptionList, new RangerPolicyItem()));
-				this.model.set('denyExceptions', this.setPermissionsToColl(this.formInputDenyExceptionList, new RangerPolicyItem()));
+				if(!this.model.get('isDenyAllElse')){
+					this.model.set('denyPolicyItems', this.setPermissionsToColl(this.formInputDenyList, new RangerPolicyItem()));
+					this.model.set('denyExceptions', this.setPermissionsToColl(this.formInputDenyExceptionList, new RangerPolicyItem()));
+				}else{
+					this.model.set('denyPolicyItems',[]);
+					this.model.set('denyExceptions',[]);
+				}
 			}
 			this.model.set('service',this.rangerService.get('name'));
-                        this.model.set('name', _.escape(this.model.get('name')));
+            var policyName = this.model.get('name');
+            if(this.model.has('id') && XAUtil.checkForEscapeCharacter(policyName)){
+                policyName = _.unescape(policyName);
+            }
+            this.model.set('name', _.escape(policyName));
                         if(this.model.has('policyPriority')){
                                 this.model.set('policyPriority', this.model.get('policyPriority') ? 1 : 0);
                         }
+
 		},
 		setPermissionsToColl : function(list, policyItemList) {
 			list.each(function(m){
-				if(!_.isUndefined(m.get('groupName')) || !_.isUndefined(m.get("userName"))){ //groupName or userName
+                                if(!_.isUndefined(m.get('groupName')) || !_.isUndefined(m.get("userName")) || !_.isUndefined(m.get('roleName'))){ //groupName or userName
 					var RangerPolicyItem=Backbone.Model.extend()
 					var policyItem = new RangerPolicyItem();
 					if(!_.isUndefined(m.get('groupName')) && !_.isNull(m.get('groupName'))){
@@ -522,6 +638,9 @@ define(function(require){
 					if(!_.isUndefined(m.get('userName')) && !_.isNull(m.get('userName'))){
 						policyItem.set("users",m.get("userName"));
 					}
+                                        if(!_.isUndefined(m.get('roleName')) && !_.isNull(m.get('roleName'))){
+                                                policyItem.set("roles",m.get("roleName"));
+                                        }
 					if(!(_.isUndefined(m.get('conditions')) && _.isEmpty(m.get('conditions')))){
 						var RangerPolicyItemConditionList = Backbone.Collection.extend();
 						var rPolicyItemCondList = new RangerPolicyItemConditionList(m.get('conditions'))
@@ -769,26 +888,34 @@ define(function(require){
 		},
 		formValidation : function(coll){
                         var groupSet = false , permSet = false , groupPermSet = false , delegateAdmin = false ,
-			userSet=false, userPerm = false, userPermSet =false,breakFlag =false, condSet = false,customMaskSet = true;
+                        userSet=false, userPerm = false, userPermSet =false,breakFlag =false, condSet = false,customMaskSet = true,
+                        roleSet = false, rolePermSet = false, rolePerm = false;
 			console.log('validation called..');
 			coll.each(function(m){
 				if(_.isEmpty(m.attributes)) return;
-                                if(m.has('groupName') || m.has('userName') || m.has('accesses') || m.has('delegateAdmin') ){
+                if(m.has('groupName') || m.has('userName') || m.has('accesses') || m.has('delegateAdmin') || m.has('roleName')){
 					if(! breakFlag){
 						groupSet = m.has('groupName') ? true : false;
 						userSet = m.has('userName') ? true : false;
+                                                roleSet = m.has('roleName') ? true : false;
                                                 permSet = m.has('accesses') ? true : false;
                                                 delegateAdmin = m.has('delegateAdmin') ? m.get('delegateAdmin') : false;
 						if(groupSet && permSet){
 							groupPermSet = true;
 							userPermSet = false;
+                                                        rolePermSet = false;
 						}else if(userSet && permSet){
 							userPermSet = true;
 							groupPermSet = false;
+                                                        rolePermSet = false;
+                                                }else if(roleSet && permSet){
+                                                        rolePermSet = true;
+                                                        userPermSet = false;
+                                                        groupPermSet = false;
 						}else{
-                                                        if(!((userSet || groupSet) && delegateAdmin)){
-                                                                breakFlag=true;
-                                                        }
+                            if(!((userSet || groupSet || roleSet) && delegateAdmin)){
+                                    breakFlag=true;
+                            }
 						}
 					}
 				}
@@ -808,20 +935,27 @@ define(function(require){
 						userSet 		: userSet, isUsers:userPermSet,
 						auditLoggin 	: auditStatus,
 						condSet			: condSet,
-                                                customMaskSet   : customMaskSet,
-                                                delegateAdmin	: delegateAdmin,
+                        customMaskSet   : customMaskSet,
+                        delegateAdmin	: delegateAdmin,
+                        roleSet : roleSet, rolePermSet : rolePermSet,
 					};
-			if(groupSet || userSet){
+                        if(groupSet || userSet || roleSet){
 				obj['permSet'] = groupSet ? permSet : false;
 				obj['userPerm'] = userSet ? permSet : false;
+                                obj['rolePerm'] = roleSet ? permSet : false;
 			}else{
 				obj['permSet'] = permSet;
 				obj['userPerm'] = userSet;
+                                obj['rolePerm'] = roleSet;
 			}
 			return obj;
 		},
 		getPolicyBaseFieldNames : function(){
-                        return ['description','isAuditEnabled'];
+			var baseField = ['description','isAuditEnabled', 'isDenyAllElse'];
+			if(XAUtil.isMaskingPolicy(this.model.get('policyType')) || XAUtil.isRowFilterPolicy(this.model.get('policyType'))){
+				baseField = _.without(baseField, 'isDenyAllElse');
+			}
+			return baseField;
 		},
 		getResources : function(){
 			if(XAUtil.isMaskingPolicy(this.model.get('policyType'))){
