@@ -49,7 +49,8 @@ define(function(require) {
 			return {
 				PolicyDetails: this.policyDetails,
                 isDelegatAdmin: isDelegatAdminChk,
-                policyType: policyType.label
+                policyType: policyType.label,
+                isDenyAllElse : this.policy.has('isDenyAllElse') && !_.isUndefined(this.policy.get('isDenyAllElse')) ? true : false,
 			};
 		},
 
@@ -114,6 +115,7 @@ define(function(require) {
 			var self = this , resourceDef;
 			var details = this.policyDetails = {};
 			details.id = this.policy.get('id');
+			details.version = this.policy.get('version');
 			details.name = this.policy.get('name');
 			details.isEnabled = this.policy.get('isEnabled') ? localization.tt('lbl.ActiveStatus_STATUS_ENABLED') : localization.tt('lbl.ActiveStatus_STATUS_DISABLED');
                         details.policyPriority = this.policy.get('policyPriority') == 1 ? localization.tt('lbl.override') : localization.tt('lbl.normal');
@@ -139,14 +141,16 @@ define(function(require) {
 					resource.label = def.label;
 					resource.values = policyResources.values;
 					if(def.recursiveSupported){
-						details.isRecursive = policyResources.isRecursive ? 'ON': 'OFF';
-					} else if(def.excludesSupported){
+						resource.Rec_Recursive = policyResources.isRecursive ? XAEnums.RecursiveStatus.STATUS_RECURSIVE.label : XAEnums.RecursiveStatus.STATUS_NONRECURSIVE.label;
+					}
+					if(def.excludesSupported){
 						resource.Rec_Exc = policyResources.isExcludes ? XAEnums.ExcludeStatus.STATUS_EXCLUDE.label : XAEnums.ExcludeStatus.STATUS_INCLUDE.label;
 					}
 					details.resources.push(resource);
 				}
 			}, this);
-                        details.policyLabels = this.policy.get('policyLabels');
+            details.policyLabels = this.policy.get('policyLabels');
+            details.zoneName = this.policy.get('zoneName');
 			var perm = details.permissions = this.getPermHeaders();
 			perm.policyItems	 = this.policy.get('policyItems');
 			perm.allowException  = this.policy.get('allowExceptions');
@@ -171,6 +175,12 @@ define(function(require) {
                         if(this.policy.has('validitySchedules')){
                                 details.validitySchedules = this.policy.get('validitySchedules');
                         }
+            if(this.policy.has('conditions') && this.policy.get('conditions').length > 0 && self.serviceDef){
+                details.conditions = XAUtils.getPolicyConditionDetails(this.policy.get('conditions'), self.serviceDef);
+            }
+            if(this.policy.has('isDenyAllElse')) {
+            	details.isDenyAllElse = this.policy.get('isDenyAllElse') ? 'TRUE' : 'FALSE';
+            }
 			//get policyItems
 			this.createPolicyItems();
 			
@@ -192,6 +202,11 @@ define(function(require) {
                 items.push({'itemName': 'allowExceptions',title : 'Exclude from Allow Conditions'},
                           {'itemName': 'denyPolicyItems',title : 'Deny Condition'},
                           {'itemName': 'denyExceptions',title : 'Exclude from Deny Conditions'});
+                if(this.policy.has('isDenyAllElse') && this.policy.get('isDenyAllElse')){
+                	items = _.reject(items, function(m){
+                		return m.itemName == 'denyPolicyItems' || m.itemName == 'denyExceptions'
+                	})
+                }
             }
 			_.each(items, function(item){
                 if(!_.isUndefined(this.policy.get(item.itemName))){
@@ -236,6 +251,7 @@ define(function(require) {
 			}
 			permList.unshift(localization.tt('lbl.selectUser'));
 			permList.unshift(localization.tt('lbl.selectGroup'));
+                        permList.unshift(localization.tt('lbl.selectRole'));
 			return {
 				header : permList,
 				policyCondition : policyCondition
@@ -261,6 +277,9 @@ define(function(require) {
 		getPolicyByVersion : function(ver, e){
 			//to support old policy log after updating that policy.
 			this.policy.set('serviceType',undefined);
+			if(this.policy.has('conditions')){
+				this.policy.set('conditions', '');
+			}
 			this.policy.fetchByVersion(ver, {
 				cache : false,
 				async : false
