@@ -56,16 +56,26 @@ define(function(require){
 				rangerPolicyType : this.collection.queryParams['policyType'],
 				isRenderAccessTab : XAUtil.isRenderMasking(this.rangerServiceDefModel.get('dataMaskDef')) ? true 
                                         : XAUtil.isRenderRowFilter(this.rangerServiceDefModel.get('rowFilterDef')) ? true : false,
-                isNotAuditorAdminOrKmsAuditor : !(XAUtil.isAuditorOrKMSAuditor(SessionMgr))
+                isAddNewPolicyButtonShow : !(XAUtil.isAuditorOrKMSAuditor(SessionMgr)) && this.rangerService.get('isEnabled')
 			};
 		},
         
-    	breadCrumbs : function(){
-    		if(this.rangerService.get('type') == XAEnums.ServiceType.SERVICE_TAG.label){
-    			return [XALinks.get('TagBasedServiceManager'),XALinks.get('ManagePolicies',{model : this.rangerService})];
-    		}
-    		return [XALinks.get('ServiceManager'),XALinks.get('ManagePolicies',{model : this.rangerService})];
-   		},        
+        breadCrumbs : function(){
+            if(this.rangerService.get('type') == XAEnums.ServiceType.SERVICE_TAG.label){
+                if(App.vZone && App.vZone.vZoneName){
+                    return [XALinks.get('TagBasedServiceManager', App.vZone.vZoneName),XALinks.get('ManagePolicies',{model : this.rangerService})];
+                }else{
+                    return [XALinks.get('TagBasedServiceManager'),XALinks.get('ManagePolicies',{model : this.rangerService})];
+                }
+            }else{
+                if(App.vZone && App.vZone.vZoneName){
+                    return [XALinks.get('ServiceManager', App.vZone.vZoneName),
+                        XALinks.get('ManagePolicies',{model : this.rangerService})];
+                }else{
+                    return [XALinks.get('ServiceManager'),XALinks.get('ManagePolicies',{model : this.rangerService})];
+                }
+            }
+        },
 
 		/** Layout sub regions */
     	regions: {
@@ -124,6 +134,9 @@ define(function(require){
 			if(!_.isUndefined(policyType)){
 				this.collection.queryParams['policyType'] = policyType;
 			}
+            if(!_.isUndefined(App.vZone) && App.vZone.vZoneName){
+                this.collection.queryParams['zoneName'] = App.vZone.vZoneName;
+            }
 			this.collection.fetch({
 				cache : false,
 			});
@@ -168,7 +181,7 @@ define(function(require){
 				gridOpts : {
 					row: Backgrid.Row.extend({}),
 					header : XABackgrid,
-					emptyText : 'No Policies found!'
+					emptyText : 'No Policies found!' + (this.rangerService.get('isEnabled') ? '' : ' The service is disabled!')
 				},
 			}));
 		},
@@ -250,21 +263,21 @@ define(function(require){
 					label	: localization.tt("lbl.policyName"),
 					editable: false,
 					sortable : false
-                                },
-                                policyLabels: {
-                                    cell	: Backgrid.HtmlCell.extend({className: 'cellWidth-1'}),
-                                    label : localization.tt("lbl.policyLabels"),
-                                    formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
-                                        fromRaw: function (rawValue, model) {
-                                            if(!_.isUndefined(rawValue) && rawValue.length != 0){
-                                                return XAUtil.showMoreAndLessButton(rawValue, model)
-                                            }else{
-                                                return '--';
-                                            }
-                                        }
-                                    }),
-                                    editable : false,
-                                    sortable : false
+                },
+                policyLabels: {
+                    cell	: Backgrid.HtmlCell.extend({className: 'cellWidth-1'}),
+                    label : localization.tt("lbl.policyLabels"),
+                    formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
+                        fromRaw: function (rawValue, model) {
+                            if(!_.isUndefined(rawValue) && rawValue.length != 0){
+                                return XAUtil.showMoreAndLessButton(rawValue, model)
+                            }else{
+                                return '--';
+                            }
+                        }
+                    }),
+                    editable : false,
+                    sortable : false
                 },
 				isEnabled:{
 					label:localization.tt('lbl.status'),
@@ -292,6 +305,18 @@ define(function(require){
 					drag : false,
 					sortable : false
 				},
+                                roles : {
+                                        reName : 'roleName',
+                                        cell	: Backgrid.HtmlCell.extend({className: 'cellWidth-1'}),
+                                        label : localization.tt("lbl.roles"),
+                                        formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
+                                                fromRaw: function (rawValue, model) {
+                                                        return XAUtil.showGroupsOrUsersForPolicy(model.get('policyItems'), model, 'roles', that.rangerServiceDefModel);
+                                                }
+                                        }),
+                                        editable : false,
+                                        sortable : false
+                                },
 				policyItems : {
 					reName : 'groupName',
 					cell	: Backgrid.HtmlCell.extend({className: 'cellWidth-1'}),
@@ -299,7 +324,7 @@ define(function(require){
 					formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
 						fromRaw: function (rawValue, model) {
 							if(!_.isUndefined(rawValue)){
-								return XAUtil.showGroupsOrUsersForPolicy(rawValue, model, true, that.rangerServiceDefModel);
+                                                                return XAUtil.showGroupsOrUsersForPolicy(rawValue, model, 'groups', that.rangerServiceDefModel);
 							}
 							return '--';
 						}
@@ -314,12 +339,12 @@ define(function(require){
 					label : localization.tt("lbl.users"),
 					formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
 						fromRaw: function (rawValue, model) {
-								return XAUtil.showGroupsOrUsersForPolicy(model.get('policyItems'), model, false, that.rangerServiceDefModel);
-						}
-					}),
-					editable : false,
-					sortable : false
-				},
+                                                                return XAUtil.showGroupsOrUsersForPolicy(model.get('policyItems'), model, 'users', that.rangerServiceDefModel);
+                                                }
+                                        }),
+                                        editable : false,
+                                        sortable : false
+                                },
 			};
 			cols['permissions'] = {
 				cell :  "html",
@@ -392,7 +417,7 @@ define(function(require){
 			$td.find('[data-id="showMore"]['+attrName+'="'+id+'"]').parents('div[data-id="groupsDiv"]').removeClass('set-height-groups');
 		},
                 attributName :function(e){
-                    var attrName = ['policy-groups-id', 'policy-users-id', 'policy-label-id'], attributeName = "";
+                    var attrName = ['policy-groups-id', 'policy-users-id', 'policy-label-id' , 'policy-roles-id'], attributeName = "";
                     attributeName =_.filter(attrName, function(name){
                         if($(e.currentTarget).attr(name)){
                             return name;
