@@ -28,6 +28,7 @@ define(function(require){
 	var XAEnums			= require('utils/XAEnums');
 	var XALinks 		= require('modules/XALinks');
 	var localization	= require('utils/XALangSupport');
+	var SessionMgr		= require('mgrs/SessionMgr');
 
 	var VPasswordChange	= require("models/VXPasswordChange");
 	var UserProfileForm = require('views/user/UserProfileForm');
@@ -121,6 +122,7 @@ define(function(require){
 				wait: true,
 				success: function () {
 					XAUtil.notifySuccess('Success', "User profile updated successfully !!");
+					SessionMgr.updateUserProfile();
 					App.appRouter.navigate("#!/policymanager/resource",{trigger: true});
 					Communicator.vent.trigger('ProfileBar:rerender');
 				},
@@ -171,7 +173,7 @@ define(function(require){
 						that.form.fields.newPassword.setError(localization.tt('validationMessages.newPasswordError'));
 						that.form.fields.reEnterPassword.setError(localization.tt('validationMessages.newPasswordError'));
 					}else if((msResponse.responseJSON.msgDesc) == "serverMsg.userMgrOldPassword"){
-						that.form.fields.oldPassword.setError(localization.tt('validationMessages.oldPasswordRepeatError'));
+						that.form.fields.newPassword.setError(localization.tt('validationMessages.oldPasswordRepeatError'));
                                         }else if(msResponse.status == 419){
                                                 XAUtil.defaultErrorHandler(options , msResponse);
 					} else {
