@@ -28,14 +28,16 @@ define(function(require){
 	var XABackgrid		= require('views/common/XABackgrid');
 	var localization	= require('utils/XALangSupport');
 	var SessionMgr  	= require('mgrs/SessionMgr');
+	var App				= require('App');
 
 	var VXGroupList		= require('collections/VXGroupList');
 	var VXGroup			= require('models/VXGroup');
 	var VXUserList		= require('collections/VXUserList');
 	var XATableLayout	= require('views/common/XATableLayout');
 	var vUserInfo		= require('views/users/UserInfo');
-
 	var VXUser          = require('models/VXUser');
+        var VXRoleList		= require('collections/VXRoleList');
+        var VXRole			= require('models/VXRole');
 
 	var UsertablelayoutTmpl = require('hbs!tmpl/users/UserTableLayout_tmpl');
 
@@ -64,8 +66,10 @@ define(function(require){
     		btnShowHide		: '[data-action="showHide"]',
 			visibilityDropdown		: '[data-id="visibilityDropdown"]',
 			addNewBtnDiv	: '[data-id="addNewBtnDiv"]',
-                        deleteUser: '[data-id="deleteUserGroup"]',
-                       showUserList:'[data-js="showUserList"]',
+            deleteUser: '[data-id="deleteUserGroup"]',
+            showUserList:'[data-js="showUserList"]',
+            addNewRoles: '[data-id="addNewRoles"]',
+            hideShowVisibility: '[data-id="hideShowVisibility"]'
     	},
 
 		/** ui events hash */
@@ -88,8 +92,9 @@ define(function(require){
 		initialize: function(options) {
 			console.log("initialized a UserTableLayout Layout");
 
-			_.extend(this, _.pick(options, 'groupList','tab'));
+                        _.extend(this, _.pick(options, 'groupList','tab', 'roleList'));
 			this.showUsers = this.tab == 'usertab' ? true : false;
+                        this.showGroups = this.tab == 'grouptab' ? true : false;
 			this.chgFlags = [];
 			if(_.isUndefined(this.groupList)){
 				this.groupList = new VXGroupList();
@@ -111,11 +116,14 @@ define(function(require){
 			this.initializePlugins();
 			if(this.tab == 'grouptab'){
 				this.renderGroupTab();
-			} else {
+                        } else if(this.tab == 'usertab'){
 				this.renderUserTab();
+                        } else{
+                                this.renderRoleTab();
 			}
 			this.bindEventToColl(this.collection);
 			this.bindEventToColl(this.groupList);
+                        this.bindEventToColl(this.roleList);
 			this.addVisualSearch();
 		},
 		bindEventToColl : function(coll){
@@ -127,17 +135,29 @@ define(function(require){
 					coll.deselect(model);
 				}, this);
 			}, this);
+			this.listenTo(coll, 'model:highlightUserGroupTableRow', function(){
+				this.$el.find('.table tr:last').addClass("alert");
+				var self = this;
+				setTimeout(function () {
+					self.$el.find('.table tr:last').removeClass("alert");
+				}, 6000);
+				XAUtil.scrollToField(this.$el.find('.table tr:last'));
+			})
 		},
 		onTabChange : function(e){
 			var that = this;
 			this.chgFlags = [];
 			this.showUsers = $(e.currentTarget).attr('href') == '#users' ? true : false;
+                        this.showGroups = $(e.currentTarget).attr('href') == '#groups' ? true : false;
 			if(this.showUsers){				
 				this.renderUserTab();
 				this.addVisualSearch();
-			} else {				
+                        } else if(this.showGroups){
 				this.renderGroupTab();
 				this.addVisualSearch();
+                        }else{
+                                this.renderRoleTab();
+                                this.addVisualSearch();
 			}
 			$(this.rUserDetail.el).hide();
 		},
@@ -212,6 +232,8 @@ define(function(require){
 		},
 		renderUserTab : function(){
 			var that = this;
+                        this.ui.addNewRoles.hide();
+                        this.ui.hideShowVisibility.show();
 			if(_.isUndefined(this.collection)){
 				this.collection = new VXUserList();
 			}	
@@ -219,11 +241,21 @@ define(function(require){
 			this.renderUserListTable();
 			_.extend(this.collection.queryParams, XAUtil.getUserDataParams())
 			this.collection.fetch({
-				//cache:true,
 				reset: true,
 				cache: false
-//				data : XAUtil.getUserDataParams(),
-			}).done(function(){
+			}).done(function(userList){
+				if(App.usersGroupsListing && !_.isEmpty(App.usersGroupsListing) && App.usersGroupsListing.showLastPage){
+					if(userList.state.totalRecords > userList.state.pageSize){
+						that.collection.getLastPage({
+							cache : false,
+						}).done(function(m){
+							App.usersGroupsListing={};
+							(_.last(m.models)).trigger("model:highlightUserGroupTableRow");
+						});
+					}else{
+						_.last(userList.models).trigger("model:highlightUserGroupTableRow");
+					}
+				}
 				if(!_.isString(that.ui.addNewGroup)){
 					that.ui.addNewGroup.hide();
 					that.ui.addNewUser.show();
@@ -234,16 +266,29 @@ define(function(require){
 		},
 		renderGroupTab : function(){
 			var that = this;
+                        this.ui.addNewRoles.hide();
+                        this.ui.hideShowVisibility.show();
 			if(_.isUndefined(this.groupList)){
 				this.groupList = new VXGroupList();
 			}
 			this.groupList.selectNone();
 			this.renderGroupListTable();
 			this.groupList.fetch({
-				//cache:true,
 				reset:true,
-				cache: false
-			}).done(function(){
+				cache: false,
+			}).done(function(groupList){
+				if(App.usersGroupsListing && !_.isEmpty(App.usersGroupsListing) && App.usersGroupsListing.showLastPage){
+					if(groupList.state.totalRecords > groupList.state.pageSize){
+						that.groupList.getLastPage({
+							cache : false,
+						}).done(function(m){
+							(_.last(m.models)).trigger("model:highlightUserGroupTableRow");
+						});
+					}else{
+						(_.last(groupList.models)).trigger("model:highlightUserGroupTableRow");
+					}
+					App.usersGroupsListing={};
+				}
 				that.ui.addNewUser.hide();
 				that.ui.addNewGroup.show();
 				that.$('.wrap-header').text('Group List');
@@ -252,6 +297,39 @@ define(function(require){
 				that.checkRoleKeyAdmin();
 			});
 		},
+                renderRoleTab : function(){
+                        var that = this;
+                        this.ui.hideShowVisibility.hide();
+                        if(_.isUndefined(this.roleList)){
+                                this.roleList = new VXRoleList();
+                        }
+                        this.renderRoleListTable();
+                        this.roleList.fetch({
+                                reset:true,
+                                cache: false,
+                        }).done(function(roleList){
+                                if(App.usersGroupsListing && !_.isEmpty(App.usersGroupsListing) && App.usersGroupsListing.showLastPage){
+                                        if(roleList.state.totalRecords > roleList.state.pageSize){
+                                                that.roleList.getLastPage({
+                                                        cache : false,
+                                                }).done(function(m){
+                                                        (_.last(m.models)).trigger("model:highlightUserGroupTableRow");
+                                                });
+                                        }else{
+                                                (_.last(roleList.models)).trigger("model:highlightUserGroupTableRow");
+                                        }
+                                        App.usersGroupsListing={};
+                                }
+                                that.ui.addNewUser.hide();
+                                that.ui.addNewGroup.hide();
+                                that.ui.addNewRoles.show();
+                                that.$('.wrap-header').text('Role List');
+                                that.$('ul').find('[data-js="roles"]').addClass('active');
+                                that.$('ul').find('[data-js="users"]').removeClass();
+                                that.$('ul').find('[data-js="groups"]').removeClass();
+                                // that.checkRoleKeyAdmin();
+                        });
+                },
 		renderUserListTable : function(){
 			var that = this;
 			var tableRow = Backgrid.Row.extend({
@@ -346,8 +424,8 @@ define(function(require){
 					label : localization.tt("lbl.groups"),
 					formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
 						fromRaw: function (rawValue,model) {
-							if(!_.isUndefined(rawValue)){
-								return XAUtil.showGroups(_.map(rawValue,function(name){return {'userId': model.id,'groupName': name}}));
+                                                        if(!_.isUndefined(rawValue) && !_.isEmpty(rawValue)){
+                                                                return XAUtil.showMoreLessBtnForGroupsUsersRoles(_.map(rawValue,function(name){return {'modelId': model.id,'entityName': name}}) , 'groups');
 							}
 							else
 							return '--';
@@ -494,6 +572,104 @@ define(function(require){
 			return this.groupList.constructor.getTableCols(cols, this.groupList);
 		},
 
+                renderRoleListTable : function(){
+                        var that = this;
+
+                        var tableRow = Backgrid.Row.extend({
+                                render: function () {
+                                        tableRow.__super__.render.apply(this, arguments);
+                                        return this;
+                                },
+
+                        });
+                        this.rTableList.show(new XATableLayout({
+                                columns: this.getRoleColumns(),
+                                collection: this.roleList,
+                                includeFilter : false,
+                                gridOpts : {
+                                        row: tableRow,
+                                        header : XABackgrid,
+                                        emptyText : 'No Groups found!'
+                                }
+                        }));
+                },
+
+                getRoleColumns : function(){
+                        var cols = {
+
+                                select : {
+                                        label : localization.tt("lbl.isVisible"),
+                                        cell: "select-row",
+                                    headerCell: "select-all",
+                                        click : false,
+                                        drag : false,
+                                        editable : false,
+                                        sortable : false
+                                },
+                                name : {
+                                        label	: localization.tt("lbl.roleName"),
+                                        href: function(model){
+                                                return '#!/roles/'+ model.id;
+                                        },
+                                        editable:false,
+                                        sortable:false,
+                                        cell :'uri'
+                                },
+                                users : {
+                                        cell	: Backgrid.HtmlCell.extend({className: 'cellWidth-1'}),
+                                        label : localization.tt("lbl.users"),
+                                        formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
+                                                fromRaw: function (rawValue, model) {
+                                                        if(!_.isUndefined(rawValue) && rawValue.length != 0){
+                                                                return XAUtil.showMoreLessBtnForGroupsUsersRoles(_.map(rawValue,function(m){return {'modelId': model.id,'entityName': m.name}}), 'users');
+                                                        }else{
+                                                                return '--';
+                                                        }
+                                                }
+                                        }),
+                                        editable : false,
+                                        sortable : false
+                                },
+                                groups : {
+                                        cell	: Backgrid.HtmlCell.extend({className: 'cellWidth-1'}),
+                                        label : localization.tt("lbl.groups"),
+                                        formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
+                                                fromRaw: function (rawValue, model) {
+                                                        if(!_.isUndefined(rawValue) && rawValue.length != 0){
+								return XAUtil.showMoreLessBtnForGroupsUsersRoles(_.map(rawValue,function(m){return {'modelId': model.id,'entityName': m.name}}), 'groups');
+                                                        }else{
+                                                                return '--';
+                                                        }
+                                                }
+                                        }),
+                                        editable : false,
+                                        sortable : false
+                                },
+                                roles : {
+                                        cell	: Backgrid.HtmlCell.extend({className: 'cellWidth-1'}),
+                                        label : localization.tt("lbl.roles"),
+                                        formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
+                                                fromRaw: function (rawValue, model) {
+                                                        if(!_.isUndefined(rawValue) && rawValue.length != 0){
+								return XAUtil.showMoreLessBtnForGroupsUsersRoles(_.map(rawValue,function(m){return {'modelId': model.id,'entityName': m.name}}), 'roles');
+                                                        }else{
+                                                                return '--';
+                                                        }
+                                                }
+                                        }),
+                                        editable : false,
+                                        sortable : false
+                                },
+                        };
+            if(!SessionMgr.isSystemAdmin()){
+                delete cols.select;
+            }
+            if(XAUtil.isAuditorOrKMSAuditor(SessionMgr)){
+                cols.name.cell = 'string';
+            }
+                        return this.roleList.constructor.getTableCols(cols, this.roleList);
+                },
+
         showUserList :function(e){
             XAUtil.blockUI();
             var that = this , name , msg = "", content = "" , totalRecords, infoMsg = ""; this.copyUserLists = [];
@@ -510,9 +686,9 @@ define(function(require){
             }).then(function(){
                 XAUtil.blockUI('unblock');
                 totalRecords = this.state.totalRecords;
-                var title =  "<h4>User's List: " + name + "</h4>";
+                var title =  "<h4>User's List: " + _.escape(name) + "</h4>";
                     _.each(that.grpUserList.models , function(model){
-                        msg +='<span class="link-tag userLists span-margin setEllipsis" title="'+ model.get('name') +'"><a href="#!/user/'+ model.id+'">'+ model.get('name') + '</a></span>';
+                        msg +='<span class="link-tag userLists span-margin setEllipsis" title="'+ _.escape(model.get('name')) +'"><a href="#!/user/'+ model.id+'">'+ _.escape(model.get('name')) + '</a></span>';
                         that.copyUserLists.push(model.get('name'));
                     });
                     var html = '<div class="row-fluid">\
@@ -568,7 +744,7 @@ define(function(require){
                     modal.$el.find('.modal-body').removeClass('pointer-event');
                     modal.$el.find('.loaderForModal').remove();
                     _.each(this.models, function(m){
-                        tag +='<span class="link-tag userLists span-margin setEllipsis" title="'+ m.get('name') +'" ><a href="#!/user/'+ m.get('id')+'" >'+ m.get('name') + '</a></span>';
+                        tag +='<span class="link-tag userLists span-margin setEllipsis" title="'+ _.escape(m.get('name')) +'" ><a href="#!/user/'+ m.get('id')+'" >'+ _.escape(m.get('name')) + '</a></span>';
                         that.copyUserLists.push(m.get('name'));
                     });
                     modal.$el.find(".usernames").empty();
@@ -616,7 +792,7 @@ define(function(require){
 		onDeleteUser: function(e){
 
 			var that = this;
-			var collection = that.showUsers ? that.collection : that.groupList;
+                        var collection = that.showUsers ? that.collection : (that.showGroups ? that.groupList : that.roleList);
 			var selArr = [];
 			var message = '';
 			collection.each(function(obj){
@@ -639,16 +815,18 @@ define(function(require){
 			if(total_selected == 0){
 				if(that.showUsers){
 					XAUtil.alertBoxWithTimeSet(localization.tt('msg.noDeleteUserRow'));
-				}else{
+                                }else if(that.showGroups){
 					XAUtil.alertBoxWithTimeSet(localization.tt('msg.noDeleteGroupRow'));
+                                }else {
+                                        XAUtil.alertBoxWithTimeSet(localization.tt('msg.noDeleteRoleRow'));
 				}
 				return;
 			}
             if(total_selected == 1) {
-                message = 'Are you sure you want to delete '+(that.showUsers ? 'user':'group')+' \''+ _.escape( jsonUsers.vXStrings[0].value )+'\'?';
+                message = 'Are you sure you want to delete '+(that.showUsers ? 'user': (that.showGroups ? 'group' : 'role'))+' \''+ _.escape( jsonUsers.vXStrings[0].value )+'\'?';
 			}
 			else {
-				message = 'Are you sure you want to delete '+total_selected+' '+(that.showUsers ? 'users':'groups')+'?';
+                                message = 'Are you sure you want to delete '+total_selected+' '+(that.showUsers ? 'user': (that.showGroups ? 'group' : 'role'))+'?';
 			}
 			if(total_selected > 0){
 				XAUtil.confirmPopup({
@@ -657,62 +835,117 @@ define(function(require){
 						XAUtil.blockUI();
 						if(that.showUsers){
 							var model = new VXUser();
-                            var count = 0 , notDeletedUserName = "";
+                            var count = 0 , notDeletedUserName = "", errorMsgForNotDeletedUsers = "";
                             _.map(jsonUsers.vXStrings , function(m){
                             	model.deleteUsers(m.id,{
                             		success: function(response,options){
                             			count += 1;
-                            			that.userCollection(jsonUsers.vXStrings.length, count, notDeletedUserName)
+                            			that.userCollection(jsonUsers.vXStrings.length, count, notDeletedUserName, errorMsgForNotDeletedUsers)
                             		},
                             		error:function(response,options){
                             			count += 1;
-                            			notDeletedUserName += m.value + ", ";
-                            			that.userCollection(jsonUsers.vXStrings.length, count, notDeletedUserName)
+                            			if(response.responseJSON && response.responseJSON.msgDesc){
+                            				errorMsgForNotDeletedUsers += _.escape(response.responseJSON.msgDesc) +".<br>"
+                            			}else{
+                            				notDeletedUserName += _.escape(m.value) + ", ";
+                            			}
+                            			that.collection.find(function(model){return model.get('name') === m.value}).selected = false
+                            			that.userCollection(jsonUsers.vXStrings.length, count, notDeletedUserName, errorMsgForNotDeletedUsers)
                             		}
                             	});
                             });
-                        }else {
+                        }else if(that.showGroups) {
 							var model = new VXGroup();
-                            var count = 0, notDeletedGroupName ="";
+                            var count = 0, notDeletedGroupName ="", errorMsgForNotDeletedGroups = "";
                             _.map(jsonUsers.vXStrings, function(m){
                             	model.deleteGroups(m.id,{
                             		success: function(response){
                             			count += 1;
-                            			that.groupCollection(jsonUsers.vXStrings.length,count,notDeletedGroupName)
+                            			that.groupCollection(jsonUsers.vXStrings.length,count,notDeletedGroupName, errorMsgForNotDeletedGroups)
                             		},
                             		error:function(response,options){
                             			count += 1;
-                            			notDeletedGroupName += m.value + ", ";
-                            			that.groupCollection(jsonUsers.vXStrings.length,count, notDeletedGroupName)
+                                        if(response.responseJSON && response.responseJSON.msgDesc){
+                                            errorMsgForNotDeletedGroups += _.escape(response.responseJSON.msgDesc) +"<br>"
+                                        }else{
+                                            notDeletedGroupName += _.escape(m.value) + ", ";
+                                        }
+                            			that.groupList.find(function(model){return model.get('name') === m.value}).selected = false
+                            			that.groupCollection(jsonUsers.vXStrings.length,count, notDeletedGroupName, errorMsgForNotDeletedGroups)
                             		}
                             	})
+                            });
+                                                }else {
+                                                        var model = new VXRole();
+                            var count = 0, notDeletedRoleName ="", errorMsgForNotDeletedRoles = "";
+                            _.map(jsonUsers.vXStrings, function(m){
+                                model.deleteRoles(m.id,{
+                                        success: function(response){
+                                                count += 1;
+                                                that.roleCollection(jsonUsers.vXStrings.length,count,notDeletedRoleName, errorMsgForNotDeletedRoles);
+                                        },
+                                        error:function(response,options){
+                                                count += 1;
+                                        if(response.responseJSON && response.responseJSON.msgDesc){
+                                            errorMsgForNotDeletedRoles += _.escape(response.responseJSON.msgDesc) +"<br>"
+                                        }else{
+                                            notDeletedRoleName += _.escape(m.value) + ", ";
+                                        }
+                                                that.roleList.find(function(model){return model.get('name') === m.value}).selected = false
+                                                that.roleCollection(jsonUsers.vXStrings.length,count, notDeletedRoleName, errorMsgForNotDeletedRoles)
+                                        }
+                                })
                             });
 						}
 					}
 				});
 			}
 		},
-        userCollection : function(numberOfUser, count, notDeletedUserName){
+        userCollection : function(numberOfUser, count, notDeletedUserName, errorMsgForNotDeletedUsers){
                 if(count == numberOfUser){
                         this.collection.getFirstPage({fetch:true});
                         this.collection.selected = {};
                         XAUtil.blockUI('unblock');
-                        if(notDeletedUserName === ""){
+                        if(notDeletedUserName === "" && _.isEmpty(errorMsgForNotDeletedUsers)){
                                 XAUtil.notifySuccess('Success','User deleted successfully!');
                         }else{
-                                XAUtil.notifyError('Error', 'Error occurred during deleting Users: '+ notDeletedUserName.slice(0 , -2));
+                            var msg = "";
+                            if(!_.isEmpty(notDeletedUserName)){
+                                msg = 'Error occurred during deleting Users: '+ notDeletedUserName.slice(0 , -2);
+                            }
+                            XAUtil.notifyError('Error', errorMsgForNotDeletedUsers + msg);
                         }
                 }
         },
-        groupCollection : function(numberOfGroup, count ,notDeletedGroupName){
+        groupCollection : function(numberOfGroup, count ,notDeletedGroupName, errorMsgForNotDeletedGroups){
                 if(count == numberOfGroup){
                         this.groupList.getFirstPage({fetch:true});
                         this.groupList.selected  = {};
                         XAUtil.blockUI('unblock');
-                        if(notDeletedGroupName === ""){
+                        if(notDeletedGroupName === "" && _.isEmpty(errorMsgForNotDeletedGroups)){
                                 XAUtil.notifySuccess('Success','Group deleted successfully!');
                         } else {
-                                XAUtil.notifyError('Error', 'Error occurred during deleting Groups: '+ notDeletedGroupName.slice(0 , -2));
+                            var msg = "";
+                            if(!_.isEmpty(notDeletedGroupName)){
+                                msg = 'Error occurred during deleting Users: '+ notDeletedGroupName.slice(0 , -2);
+                            }
+                            XAUtil.notifyError('Error', errorMsgForNotDeletedGroups + msg);
+                        }
+                }
+        },
+        roleCollection : function(numberOfRole, count ,notDeletedRoleName, errorMsgForNotDeletedRoles){
+                if(count == numberOfRole){
+                        this.roleList.getFirstPage({fetch:true});
+                        this.roleList.selected  = {};
+                        XAUtil.blockUI('unblock');
+                        if(notDeletedRoleName === "" && _.isEmpty(errorMsgForNotDeletedRoles)){
+                                XAUtil.notifySuccess('Success','Role deleted successfully!');
+                        } else {
+                            var msg = "";
+                            if(!_.isEmpty(notDeletedRoleName)){
+                                msg = 'Error occurred during deleting Users: '+ notDeletedRoleName.slice(0 , -2);
+                            }
+                            XAUtil.notifyError('Error', errorMsgForNotDeletedRoles + msg);
                         }
                 }
         },
@@ -732,7 +965,7 @@ define(function(require){
 				                   {text : "User Source", label :"userSource", 'multiple' : true, 'optionsArr' : XAUtil.enumToSelectLabelValuePairs(XAEnums.UserTypes)},
 				                   {text : "User Status", label :"status", 'multiple' : true, 'optionsArr' : XAUtil.enumToSelectLabelValuePairs(XAEnums.ActiveStatus)},
 								];
-			} else {
+            } else if(this.showGroups){
 				placeholder = localization.tt('h.searchForYourGroup');
 				coll = this.groupList;
 				searchOpt = ['Group Name','Group Source', 'Visibility'];//,'Start Date','End Date','Today'];
@@ -740,6 +973,15 @@ define(function(require){
 				                   {text : "Visibility", label :"isVisible", 'multiple' : true, 'optionsArr' : XAUtil.enumToSelectLabelValuePairs(XAEnums.VisibilityStatus)},
 				                   {text : "Group Source", label :"groupSource", 'multiple' : true, 'optionsArr' : XAUtil.enumToSelectLabelValuePairs(XAEnums.GroupTypes)},];
 
+            } else{
+                placeholder = localization.tt('h.searchForYourRole');
+                coll = this.roleList;
+                searchOpt = ['Role Name','User Name', 'Group Name', /*Role ID*/];//,'Start Date','End Date','Today'];
+                serverAttrName  = [{text : "Role Name", label :"roleName"},
+                                   {text : "User Name", label :"userName"},
+                                   {text : "Group Name", label :"groupName"},
+                                   // {text : "Role ID", label : "roleId"}
+                                  ];
 			}
 			var query = (!_.isUndefined(coll.VSQuery)) ? coll.VSQuery : '';
 			var pluginAttr = {
@@ -795,18 +1037,20 @@ define(function(require){
 			return _.map(activeStatusList, function(status) { return { 'label': status.label, 'value': status.label}; })
 		},
 		onShowMore : function(e){
-			var id = $(e.currentTarget).attr('policy-group-id');
-			this.rTableList.$el.find('[policy-group-id="'+id+'"]').show();
-			$('[data-id="showLess"][policy-group-id="'+id+'"]').show();
-			$('[data-id="showMore"][policy-group-id="'+id+'"]').hide();
-			$('[data-id="showMore"][policy-group-id="'+id+'"]').parents('div[data-id="groupsDiv"]').addClass('set-height-groups');
+                        var name = $(e.currentTarget).attr('data-name');
+                        var id = $(e.currentTarget).attr('model-'+name+'-id');
+                        this.rTableList.$el.find('[model-'+name+'-id="'+id+'"]').show();
+                        $('[data-id="showLess"][model-'+name+'-id="'+id+'"]').show();
+                        $('[data-id="showMore"][model-'+name+'-id="'+id+'"]').hide();
+                        $('[data-id="showMore"][model-'+name+'-id="'+id+'"]').parents('div[data-id="groupsDiv"]').addClass('set-height-groups');
 		},
 		onShowLess : function(e){
-			var id = $(e.currentTarget).attr('policy-group-id');
-			this.rTableList.$el.find('[policy-group-id="'+id+'"]').slice(4).hide();
-			$('[data-id="showLess"][policy-group-id="'+id+'"]').hide();
-			$('[data-id="showMore"][policy-group-id="'+id+'"]').show();
-			$('[data-id="showMore"][policy-group-id="'+id+'"]').parents('div[data-id="groupsDiv"]').removeClass('set-height-groups')
+                        var name = $(e.currentTarget).attr('data-name');
+                        var id = $(e.currentTarget).attr('model-'+name+'-id');
+                        this.rTableList.$el.find('[model-'+name+'-id="'+id+'"]').slice(4).hide();
+                        $('[data-id="showLess"][model-'+name+'-id="'+id+'"]').hide();
+                        $('[data-id="showMore"][model-'+name+'-id="'+id+'"]').show();
+                        $('[data-id="showMore"][model-'+name+'-id="'+id+'"]').parents('div[data-id="groupsDiv"]').removeClass('set-height-groups')
 		},
 		checkRoleKeyAdmin : function() {
 			if(SessionMgr.isKeyAdmin()){
