@@ -521,8 +521,11 @@
                                                 <a href="javascript:void(0);" data-name="viewService" data-id="'+serv.id+'" class="btn btn-mini" title="View"><i class="icon-eye-open "></i></a>\
                                            </div>'
 				}
-				tr += '<tr><td><div>\
-						<a class="pull-left serviceNameEllipsis" data-id="'+serv.id+'" href="#!/service/'+serv.id+'/policies/'+policyType+'" title="'+_.escape(serv.attributes.name)+'">'+_.escape(serv.attributes.name)+'</a>'+serviceOperationDiv+'\
+				tr += '<tr><td><div>';
+				if (!serv.get('isEnabled')) {
+					tr += '<i class="icon-ban-circle text-color-red pull-left icon-large"></i>';
+				}
+				tr += '<a class="pull-left serviceNameEllipsis" data-id="'+serv.id+'" href="#!/service/'+serv.id+'/policies/'+policyType+'" title="'+_.escape(serv.attributes.name)+'">'+_.escape(serv.attributes.name)+'</a>'+serviceOperationDiv+'\
 					  </div></td></tr>';
 			});
 		}
@@ -563,9 +566,34 @@
 				&& ( !_.isUndefined(rowFilterDef.resources) ) && rowFilterDef.resources.length > 0 )
 				? options.fn(this) : options.inverse(this); 
 	});
+	Handlebars.registerHelper('printZoneResourceGroups', function(zoneServiceResources) {
+		var resourceStr = '';	
+		_.each(zoneServiceResources, function(resourceGroup){
+			resourceStr += '<div class="zone-resource">';
+			_.map(resourceGroup,function(res, resType){ 
+				resourceStr +=  '<strong>' + _.escape(resType) + '</strong> : ' + _.escape(res) + '<br>' ;
+			});
+			resourceStr += '</div>';
+		});
+		
+		return resourceStr;
+	});
         Handlebars.registerHelper('blankCheck', function(context, options) {
                 return _.isUndefined(context) || _.isEmpty(context) ? '--' : context;
         });
 
+    Handlebars.registerHelper('getPolicyConditionTmpl', function(obj) {
+        if(!_.isUndefined(obj.evaluatorOptions) && !_.isUndefined(obj.evaluatorOptions['ui.isMultiline']) && Boolean(obj.evaluatorOptions['ui.isMultiline'])){
+            return '<div class="margin-bottom-5">\
+                        <label class="display-block">\
+                            <span>'+obj.label+' : </span>\
+                            <i title="'+localization.tt('validationMessages.jsValidationMsg')+'" class="icon-info-sign pull-right margin-top-6"></i>\
+                        </label>\
+                        <textarea class="multiline-condition" data-id="textAreaContainer" name="'+obj.name+'" placeholder="Please enter condition.."></textarea>\
+                   </div>'
+            }
+            return '<div class="margin-bottom-5 display-block"><label><span>'+obj.label+' : </span></label><input type="input" data-id="inputField" name="'+obj.name+'" ></div>'
+    });
+
 	return HHelpers;
 });
