@@ -33,10 +33,12 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import javax.ws.rs.WebApplicationException;
 
+import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.ranger.admin.client.datatype.RESTResponse;
 import org.apache.ranger.biz.AssetMgr;
 import org.apache.ranger.biz.RangerBizUtil;
+import org.apache.ranger.biz.SecurityZoneDBStore;
 import org.apache.ranger.biz.ServiceDBStore;
 import org.apache.ranger.biz.ServiceMgr;
 import org.apache.ranger.biz.TagDBStore;
@@ -50,10 +52,18 @@ import org.apache.ranger.common.RangerValidatorFactory;
 import org.apache.ranger.common.ServiceUtil;
 import org.apache.ranger.common.StringUtil;
 import org.apache.ranger.common.UserSessionBase;
+import org.apache.ranger.common.db.RangerTransactionSynchronizationAdapter;
 import org.apache.ranger.db.RangerDaoManager;
+import org.apache.ranger.db.XXSecurityZoneDao;
+import org.apache.ranger.db.XXSecurityZoneRefServiceDao;
+import org.apache.ranger.db.XXSecurityZoneRefTagServiceDao;
+import org.apache.ranger.db.XXGroupUserDao;
 import org.apache.ranger.db.XXServiceDao;
 import org.apache.ranger.db.XXServiceDefDao;
 import org.apache.ranger.entity.XXPortalUser;
+import org.apache.ranger.entity.XXSecurityZone;
+import org.apache.ranger.entity.XXSecurityZoneRefService;
+import org.apache.ranger.entity.XXSecurityZoneRefTagService;
 import org.apache.ranger.entity.XXService;
 import org.apache.ranger.entity.XXServiceDef;
 import org.apache.ranger.plugin.model.RangerPluginInfo;
@@ -73,6 +83,7 @@ import org.apache.ranger.plugin.model.RangerServiceDef.RangerServiceConfigDef;
 import org.apache.ranger.plugin.model.validation.RangerPolicyValidator;
 import org.apache.ranger.plugin.model.validation.RangerServiceDefValidator;
 import org.apache.ranger.plugin.model.validation.RangerServiceValidator;
+import org.apache.ranger.plugin.policyengine.RangerPolicyEngine;
 import org.apache.ranger.plugin.policyengine.RangerPolicyEngineImpl;
 import org.apache.ranger.plugin.service.ResourceLookupContext;
 import org.apache.ranger.plugin.store.EmbeddedServiceDefsUtil;
@@ -89,6 +100,7 @@ import org.apache.ranger.service.RangerPolicyLabelsService;
 import org.apache.ranger.service.RangerPolicyService;
 import org.apache.ranger.service.RangerServiceDefService;
 import org.apache.ranger.service.RangerServiceService;
+import org.apache.ranger.service.RangerTransactionService;
 import org.apache.ranger.service.XUserService;
 import org.apache.ranger.view.RangerExportPolicyList;
 import org.apache.ranger.view.RangerPluginInfoList;
@@ -132,6 +144,9 @@ public class TestServiceREST {
 	@Mock
 	ServiceDBStore svcStore;
 
+	@Mock
+	SecurityZoneDBStore zoneStore;
+
 	@Mock
 	TagDBStore tagStore;
 
@@ -212,7 +227,16 @@ public class TestServiceREST {
 
 	@Mock
 	RangerPolicyEngineImpl rpImpl;
+	
+	@Mock
+	RangerPolicyEngine policyEngine;
 
+	@Mock
+	RangerTransactionService rangerTransactionService;
+
+	@Mock
+	RangerTransactionSynchronizationAdapter rangerTransactionSynchronizationAdapter;
+	
 	@Rule
 	public ExpectedException thrown = ExpectedException.none();
 
@@ -281,7 +305,7 @@ public class TestServiceREST {
 		return rangerService;
 	}
 
-	public RangerPolicy rangerPolicy() {
+	RangerPolicy rangerPolicy() {
 		List<RangerPolicyItemAccess> accesses = new ArrayList<RangerPolicyItemAccess>();
 		List<String> users = new ArrayList<String>();
 		List<String> groups = new ArrayList<String>();
@@ -573,6 +597,7 @@ public class TestServiceREST {
 		serviceDefList.setStartIndex(0);
 		serviceDefList.setTotalCount(10);
 		serviceDefList.setList(serviceDefsList);
+		Mockito.when(bizUtil.hasModuleAccess(RangerConstants.MODULE_RESOURCE_BASED_POLICIES)).thenReturn(true);
 		Mockito.when(svcStore.getPaginatedServiceDefs(filter)).thenReturn(
 				serviceDefList);
 		RangerServiceDefList dbRangerServiceDef = serviceREST
@@ -992,7 +1017,7 @@ public class TestServiceREST {
 
 		ServicePolicies dbServicePolicies = serviceREST
 				.getServicePoliciesIfUpdated(serviceName, lastKnownVersion, 0L,
-						pluginId, "", request);
+						pluginId, "", "", false, request);
 		Assert.assertNull(dbServicePolicies);
 	}
 
@@ -1048,8 +1073,12 @@ public class TestServiceREST {
 		SearchFilter filter = new SearchFilter();
 		XXService xs = Mockito.mock(XXService.class);
 		xs.setType(3L);
-		XXServiceDao xSDao = Mockito.mock(XXServiceDao.class);
+		XXGroupUserDao xGroupDao = Mockito.mock(XXGroupUserDao.class);
+		ServiceREST spySVCRest = Mockito.spy(serviceREST);
 		List<RangerPolicy> policies = new ArrayList<RangerPolicy>();
+		ServicePolicies svcPolicies = new ServicePolicies();
+		svcPolicies.setPolicies(policies);
+		svcPolicies.setServiceName("HDFS_1-1-20150316062453");
 		RangerPolicy rPol=rangerPolicy();
 		policies.add(rPol);
 		filter.setParam(SearchFilter.POLICY_NAME, "policyName");
@@ -1057,18 +1086,16 @@ public class TestServiceREST {
 		Mockito.when(searchUtil.getSearchFilter(request, policyService.sortFields)).thenReturn(filter);
 		Mockito.when(svcStore.getPolicies(filter)).thenReturn(policies);
 		/*here we are setting serviceAdminRole, so we will get the required policy with serviceAdmi role*/
-		Mockito.when(daoManager.getXXService()).thenReturn(xSDao);
+		Mockito.when(daoManager.getXXGroupUser()).thenReturn(xGroupDao);
 		Mockito.when(svcStore.isServiceAdminUser(rPol.getService(), null)).thenReturn(true);
-		Mockito.when(xSDao.findByName(rPol.getName())).thenReturn(xs);
-		RangerPolicyList dbRangerPolicy = serviceREST.getPolicies(request);
+		Mockito.doReturn(policyEngine).when(spySVCRest).getDelegatedAdminPolicyEngine("HDFS_1-1-20150316062453");
+		RangerPolicyList dbRangerPolicy = spySVCRest.getPolicies(request);
 		Assert.assertNotNull(dbRangerPolicy);
 		Assert.assertEquals(dbRangerPolicy.getListSize(), 1);
 		Mockito.verify(searchUtil).getSearchFilter(request,
 				policyService.sortFields);
 		Mockito.verify(svcStore).getPolicies(filter);
 		Mockito.verify(svcStore).isServiceAdminUser(rPol.getService(), null);
-		Mockito.verify(daoManager).getXXService();
-		Mockito.verify(xSDao).findByName(rPol.getName());
 	}
 
 
@@ -1083,6 +1110,7 @@ public class TestServiceREST {
 		userGroupsList.add("group2");
 		Mockito.when(request.getParameter("eventTime")).thenReturn(strdt);
 		Mockito.when(request.getParameter("policyId")).thenReturn("1");
+		Mockito.when(request.getParameter("versionNo")).thenReturn("1");
 		RangerPolicy policy=new RangerPolicy();
 		Map<String, RangerPolicyResource> resources=new HashMap<String, RangerPolicy.RangerPolicyResource>();
 		policy.setService("services");
@@ -1100,6 +1128,7 @@ public class TestServiceREST {
 		Assert.assertNull(dbRangerPolicy);
 		Mockito.verify(request).getParameter("eventTime");
 		Mockito.verify(request).getParameter("policyId");
+		Mockito.verify(request).getParameter("versionNo");
 	}
 
 	@Test
@@ -1529,7 +1558,7 @@ public class TestServiceREST {
 		request.setAttribute("serviceType", "hdfs,hbase,hive,yarn,knox,storm,solr,kafka,nifi,atlas,sqoop");
 		HttpServletResponse response = Mockito.mock(HttpServletResponse.class);
 		SearchFilter filter = new SearchFilter();
-
+		filter.setParam("zoneName", "zone1");
 		Mockito.when(searchUtil.getSearchFilter(request, policyService.sortFields)).thenReturn(filter);
 		Mockito.when(svcStore.getPolicies(filter)).thenReturn(rangerPolicyList);
 		Mockito.when(bizUtil.isAdmin()).thenReturn(true);
@@ -1540,7 +1569,6 @@ public class TestServiceREST {
 		Mockito.when(daoManager.getXXService()).thenReturn(xServiceDao);
 
 		Mockito.when(daoManager.getXXServiceDef()).thenReturn(xServiceDefDao);
-
 		Mockito.when(daoManager.getXXService().findByName("HDFS_1-1-20150316062453")).thenReturn(xService);
 		Mockito.when(daoManager.getXXServiceDef().getById(xService.getType())).thenReturn(xServiceDef);
 		serviceREST.getPoliciesInJson(request, response, false);
@@ -1637,36 +1665,50 @@ public class TestServiceREST {
 		Mockito.verify(svcStore).getPoliciesInExcel(rangerPolicyList, response);
 	}
 
+
 	@SuppressWarnings("unchecked")
 	@Test
 	public void test49importPoliciesFromFileAllowingOverride() throws Exception {
 		HttpServletRequest request = Mockito.mock(HttpServletRequest.class);
-
+		RangerPolicyValidator policyValidator = Mockito.mock(RangerPolicyValidator.class) ;
 		Map<String, RangerPolicy> policiesMap = new LinkedHashMap<String, RangerPolicy>();
-
 		RangerPolicy rangerPolicy = rangerPolicy();
-
+		RangerService service = rangerService();
 		XXService xService = xService();
 		policiesMap.put("Name", rangerPolicy);
 		XXServiceDao xServiceDao = Mockito.mock(XXServiceDao.class);
 		XXServiceDef xServiceDef = serviceDef();
 		XXServiceDefDao xServiceDefDao = Mockito.mock(XXServiceDefDao.class);
+		XXSecurityZoneRefServiceDao xSecZoneRefServiceDao = Mockito.mock(XXSecurityZoneRefServiceDao.class);
+		XXSecurityZoneRefTagServiceDao xSecZoneRefTagServiceDao = Mockito.mock(XXSecurityZoneRefTagServiceDao.class);
+		XXSecurityZoneRefService xSecZoneRefService = Mockito.mock(XXSecurityZoneRefService.class);
+		XXSecurityZoneRefTagService xSecZoneRefTagService = Mockito.mock(XXSecurityZoneRefTagService.class);
+		XXSecurityZoneDao xSecZoneDao = Mockito.mock(XXSecurityZoneDao.class);
+		XXSecurityZone xSecZone = Mockito.mock(XXSecurityZone.class);
+		List<XXSecurityZoneRefService> zoneServiceList = new ArrayList<>();
+		List<XXSecurityZoneRefTagService> zoneTagServiceList = new ArrayList<>();
+		zoneServiceList.add(xSecZoneRefService);
+		zoneTagServiceList.add(xSecZoneRefTagService);
+		Map<String, String> zoneMappingMap = new LinkedHashMap<String, String>();
+		zoneMappingMap.put("ZoneSource", "ZoneDestination");
 
 		String PARAM_SERVICE_TYPE = "serviceType";
 		String serviceTypeList = "hdfs,hbase,hive,yarn,knox,storm,solr,kafka,nifi,atlas,sqoop";
 		request.setAttribute("serviceType", "hdfs,hbase,hive,yarn,knox,storm,solr,kafka,nifi,atlas,sqoop");
 		SearchFilter filter = new SearchFilter();
 		filter.setParam("serviceType", "value");
-		Mockito.when(searchUtil.getSearchFilter(request, policyService.sortFields)).thenReturn(filter);
 
-		Mockito.when(request.getParameter(PARAM_SERVICE_TYPE)).thenReturn(serviceTypeList);
 		File jsonPolicyFile = new File(importPoliceTestFilePath);
 		InputStream uploadedInputStream = new FileInputStream(jsonPolicyFile);
 		FormDataContentDisposition fileDetail = FormDataContentDisposition.name("file")
 				.fileName(jsonPolicyFile.getName()).size(uploadedInputStream.toString().length()).build();
 		boolean isOverride = true;
 
-		Mockito.when(svcStore.createPolicyMap(Mockito.any(Map.class), Mockito.any(List.class), Mockito.any(List.class),
+		InputStream zoneInputStream =IOUtils.toInputStream("ZoneSource=ZoneDestination", "UTF-8");
+
+		Mockito.when(searchUtil.getSearchFilter(request, policyService.sortFields)).thenReturn(filter);
+		Mockito.when(request.getParameter(PARAM_SERVICE_TYPE)).thenReturn(serviceTypeList);
+		Mockito.when(svcStore.createPolicyMap(Mockito.any(Map.class), Mockito.any(List.class),Mockito.anyString(),Mockito.any(Map.class), Mockito.any(List.class), Mockito.any(List.class),
 				Mockito.any(RangerPolicy.class), Mockito.any(Map.class))).thenReturn(policiesMap);
 		Mockito.when(validatorFactory.getPolicyValidator(svcStore)).thenReturn(policyValidator);
 		Mockito.when(bizUtil.isAdmin()).thenReturn(true);
@@ -1676,8 +1718,17 @@ public class TestServiceREST {
 
 		Mockito.when(daoManager.getXXService().findByName("HDFS_1-1-20150316062453")).thenReturn(xService);
 		Mockito.when(daoManager.getXXServiceDef().getById(xService.getType())).thenReturn(xServiceDef);
+		Mockito.when(validatorFactory.getPolicyValidator(svcStore)).thenReturn(policyValidator);
+		Mockito.when(svcStore.getMapFromInputStream(zoneInputStream)).thenReturn(zoneMappingMap);
+		Mockito.when(daoManager.getXXSecurityZoneDao()).thenReturn(xSecZoneDao);
+		Mockito.when(xSecZoneDao.findByZoneName(Mockito.anyString())).thenReturn(xSecZone);
+		Mockito.when(daoManager.getXXSecurityZoneRefService()).thenReturn(xSecZoneRefServiceDao);
+		Mockito.when(xSecZoneRefServiceDao.findByServiceNameAndZoneId(Mockito.anyString(),Mockito.anyLong())).thenReturn(zoneServiceList);
+		Mockito.when(daoManager.getXXSecurityZoneRefTagService()).thenReturn(xSecZoneRefTagServiceDao);
+		Mockito.when(xSecZoneRefTagServiceDao.findByTagServiceNameAndZoneId(Mockito.anyString(),Mockito.anyLong())).thenReturn(zoneTagServiceList);
+		Mockito.when(svcStore.getServiceByName(Mockito.anyString())).thenReturn(service);
+		serviceREST.importPoliciesFromFile(request, null, zoneInputStream, uploadedInputStream, fileDetail, isOverride , "unzoneToZone");
 
-		serviceREST.importPoliciesFromFile(request, null, uploadedInputStream, fileDetail, isOverride);
 		Mockito.verify(svcStore).createPolicy(rangerPolicy);
 
 	}
@@ -1686,32 +1737,43 @@ public class TestServiceREST {
 	@Test
 	public void test50importPoliciesFromFileNotAllowingOverride() throws Exception {
 		HttpServletRequest request = Mockito.mock(HttpServletRequest.class);
-
 		Map<String, RangerPolicy> policiesMap = new LinkedHashMap<String, RangerPolicy>();
-
 		RangerPolicy rangerPolicy = rangerPolicy();
-
 		XXService xService = xService();
 		policiesMap.put("Name", rangerPolicy);
 		XXServiceDao xServiceDao = Mockito.mock(XXServiceDao.class);
 		XXServiceDef xServiceDef = serviceDef();
 		XXServiceDefDao xServiceDefDao = Mockito.mock(XXServiceDefDao.class);
+		XXSecurityZoneRefServiceDao xSecZoneRefServiceDao = Mockito.mock(XXSecurityZoneRefServiceDao.class);
+		XXSecurityZoneRefTagServiceDao xSecZoneRefTagServiceDao = Mockito.mock(XXSecurityZoneRefTagServiceDao.class);
+		XXSecurityZoneRefService xSecZoneRefService = Mockito.mock(XXSecurityZoneRefService.class);
+		XXSecurityZoneRefTagService xSecZoneRefTagService = Mockito.mock(XXSecurityZoneRefTagService.class);
+		XXSecurityZoneDao xSecZoneDao = Mockito.mock(XXSecurityZoneDao.class);
+		XXSecurityZone xSecZone = Mockito.mock(XXSecurityZone.class);
+		List<XXSecurityZoneRefService> zoneServiceList = new ArrayList<>();
+		List<XXSecurityZoneRefTagService> zoneTagServiceList = new ArrayList<>();
+		zoneServiceList.add(xSecZoneRefService);
+		zoneTagServiceList.add(xSecZoneRefTagService);
+		Map<String, String> zoneMappingMap = new LinkedHashMap<String, String>();
+		zoneMappingMap.put("ZoneSource", "ZoneDestination");
 
 		String PARAM_SERVICE_TYPE = "serviceType";
 		String serviceTypeList = "hdfs,hbase,hive,yarn,knox,storm,solr,kafka,nifi,atlas,sqoop";
 		request.setAttribute("serviceType", "hdfs,hbase,hive,yarn,knox,storm,solr,kafka,nifi,atlas,sqoop");
 		SearchFilter filter = new SearchFilter();
 		filter.setParam("serviceType", "value");
-		Mockito.when(searchUtil.getSearchFilter(request, policyService.sortFields)).thenReturn(filter);
 
-		Mockito.when(request.getParameter(PARAM_SERVICE_TYPE)).thenReturn(serviceTypeList);
 		File jsonPolicyFile = new File(importPoliceTestFilePath);
 		InputStream uploadedInputStream = new FileInputStream(jsonPolicyFile);
 		FormDataContentDisposition fileDetail = FormDataContentDisposition.name("file")
 				.fileName(jsonPolicyFile.getName()).size(uploadedInputStream.toString().length()).build();
 		boolean isOverride = false;
 
-		Mockito.when(svcStore.createPolicyMap(Mockito.any(Map.class), Mockito.any(List.class), Mockito.any(List.class),
+		InputStream zoneInputStream = IOUtils.toInputStream("ZoneSource=ZoneDestination", "UTF-8");
+
+		Mockito.when(searchUtil.getSearchFilter(request, policyService.sortFields)).thenReturn(filter);
+		Mockito.when(request.getParameter(PARAM_SERVICE_TYPE)).thenReturn(serviceTypeList);
+		Mockito.when(svcStore.createPolicyMap(Mockito.any(Map.class), Mockito.any(List.class),Mockito.anyString(),Mockito.any(Map.class), Mockito.any(List.class), Mockito.any(List.class),
 				Mockito.any(RangerPolicy.class), Mockito.any(Map.class))).thenReturn(policiesMap);
 		Mockito.when(validatorFactory.getPolicyValidator(svcStore)).thenReturn(policyValidator);
 		Mockito.when(bizUtil.isAdmin()).thenReturn(true);
@@ -1722,7 +1784,14 @@ public class TestServiceREST {
 		Mockito.when(daoManager.getXXService().findByName("HDFS_1-1-20150316062453")).thenReturn(xService);
 		Mockito.when(daoManager.getXXServiceDef().getById(xService.getType())).thenReturn(xServiceDef);
 
-		serviceREST.importPoliciesFromFile(request, null, uploadedInputStream, fileDetail, isOverride);
+		Mockito.when(svcStore.getMapFromInputStream(zoneInputStream)).thenReturn(zoneMappingMap);
+		Mockito.when(daoManager.getXXSecurityZoneDao()).thenReturn(xSecZoneDao);
+		Mockito.when(xSecZoneDao.findByZoneName(Mockito.anyString())).thenReturn(xSecZone);
+		Mockito.when(daoManager.getXXSecurityZoneRefService()).thenReturn(xSecZoneRefServiceDao);
+		Mockito.when(xSecZoneRefServiceDao.findByServiceNameAndZoneId(Mockito.anyString(),Mockito.anyLong())).thenReturn(zoneServiceList);
+		Mockito.when(daoManager.getXXSecurityZoneRefTagService()).thenReturn(xSecZoneRefTagServiceDao);
+		Mockito.when(xSecZoneRefTagServiceDao.findByTagServiceNameAndZoneId(Mockito.anyString(),Mockito.anyLong())).thenReturn(zoneTagServiceList);
+		serviceREST.importPoliciesFromFile(request, null, zoneInputStream, uploadedInputStream, fileDetail, isOverride, "unzoneToUnZone");
 		Mockito.verify(svcStore).createPolicy(rangerPolicy);
 
 	}
@@ -1748,6 +1817,18 @@ public class TestServiceREST {
 		xService.setType(embeddedServiceDefsUtil.getTagServiceDefId());
 		XXServiceDao xServiceDao = Mockito.mock(XXServiceDao.class);
 
+		String userLoginID = "testuser";
+		Long userId = 8L;
+		RangerSecurityContext context = new RangerSecurityContext();
+		context.setUserSession(new UserSessionBase());
+		RangerContextHolder.setSecurityContext(context);
+		UserSessionBase session = ContextUtil.getCurrentUserSession();
+		session.setUserAdmin(true);
+		XXPortalUser xXPortalUser = new XXPortalUser();
+		xXPortalUser.setLoginId(userLoginID);
+		xXPortalUser.setId(userId);
+		session.setXXPortalUser(xXPortalUser);
+
 		Mockito.when(validatorFactory.getServiceValidator(svcStore)).thenReturn(serviceValidator);
 		Mockito.when(daoManager.getXXService()).thenReturn(xServiceDao);
 		Mockito.when(xServiceDao.findByTagServiceId(Mockito.anyLong())).thenReturn(referringServices);
@@ -1797,7 +1878,7 @@ public class TestServiceREST {
 		Mockito.when(restErrorUtil.createRESTException(Mockito.anyInt(), Mockito.anyString(), Mockito.anyBoolean()))
 				.thenThrow(new WebApplicationException());
 		thrown.expect(WebApplicationException.class);
-		serviceREST.getServicePoliciesIfUpdated(serviceName, lastKnownVersion, 0L, pluginId, "", request);
+		serviceREST.getServicePoliciesIfUpdated(serviceName, lastKnownVersion, 0L, pluginId, "", "", false, request);
 	}
 
 	@Test
@@ -1808,9 +1889,10 @@ public class TestServiceREST {
 		Long lastKnownVersion = 1L;
 		String pluginId = "1";
 		Mockito.when(serviceUtil.isValidateHttpsAuthentication(serviceName, request)).thenReturn(true);
-		Mockito.when(svcStore.getServicePoliciesIfUpdated(serviceName, lastKnownVersion)).thenReturn(servicePolicies);
+		Mockito.when(svcStore.getServicePoliciesIfUpdated(Mockito.anyString(), Mockito.anyLong(), Mockito.anyBoolean())).thenReturn(servicePolicies);
+		Mockito.when(zoneStore.getSecurityZonesForService(serviceName)).thenReturn(null);
 		ServicePolicies dbServicePolicies = serviceREST.getServicePoliciesIfUpdated(serviceName, lastKnownVersion, 0L,
-				pluginId, "", request);
+				pluginId, "", "", true, request);
 		Assert.assertNotNull(dbServicePolicies);
 	}
 
@@ -1834,7 +1916,7 @@ public class TestServiceREST {
 				.thenThrow(new WebApplicationException());
 		thrown.expect(WebApplicationException.class);
 
-		serviceREST.getSecureServicePoliciesIfUpdated(serviceName, lastKnownVersion, 0L, pluginId, "", request);
+		serviceREST.getSecureServicePoliciesIfUpdated(serviceName, lastKnownVersion, 0L, pluginId, "", "", false, request);
 	}
 
 	@Test
@@ -1860,7 +1942,7 @@ public class TestServiceREST {
 				.thenThrow(new WebApplicationException());
 		thrown.expect(WebApplicationException.class);
 
-		serviceREST.getSecureServicePoliciesIfUpdated(serviceName, lastKnownVersion, 0L, pluginId, "", request);
+		serviceREST.getSecureServicePoliciesIfUpdated(serviceName, lastKnownVersion, 0L, pluginId, "", "", false, request);
 	}
 
 	@Test
@@ -1883,16 +1965,17 @@ public class TestServiceREST {
 		Mockito.when(xServiceDefDao.getById(xService.getType())).thenReturn(xServiceDef);
 		Mockito.when(svcStore.getServiceByNameForDP(serviceName)).thenReturn(rs);
 		Mockito.when(bizUtil.isUserAllowed(rs, ServiceREST.Allowed_User_List_For_Grant_Revoke)).thenReturn(true);
-		Mockito.when(svcStore.getServicePoliciesIfUpdated(serviceName, lastKnownVersion)).thenReturn(sp);
-		ServicePolicies dbServiceSecurePolicies = serviceREST.getSecureServicePoliciesIfUpdated(serviceName,
-				lastKnownVersion, 0L, pluginId, "", request);
+		Mockito.when(svcStore.getServicePoliciesIfUpdated(Mockito.anyString(), Mockito.anyLong(), Mockito.anyBoolean())).thenReturn(sp);
+		Mockito.when(zoneStore.getSecurityZonesForService(serviceName)).thenReturn(null);
+        	ServicePolicies dbServiceSecurePolicies = serviceREST.getSecureServicePoliciesIfUpdated(serviceName,
+                		lastKnownVersion, 0L, pluginId, "", "", true, request);
 		Assert.assertNotNull(dbServiceSecurePolicies);
 		Mockito.verify(serviceUtil).isValidService(serviceName, request);
 		Mockito.verify(xServiceDao).findByName(serviceName);
 		Mockito.verify(xServiceDefDao).getById(xService.getType());
 		Mockito.verify(svcStore).getServiceByNameForDP(serviceName);
 		Mockito.verify(bizUtil).isUserAllowed(rs, ServiceREST.Allowed_User_List_For_Grant_Revoke);
-		Mockito.verify(svcStore).getServicePoliciesIfUpdated(serviceName, lastKnownVersion);
+		Mockito.verify(svcStore).getServicePoliciesIfUpdated(serviceName, lastKnownVersion, false);
 	}
 
 	@Test
@@ -1905,6 +1988,7 @@ public class TestServiceREST {
 		userGroupsList.add("group2");
 		Mockito.when(request.getParameter("eventTime")).thenReturn(strdt);
 		Mockito.when(request.getParameter("policyId")).thenReturn("1");
+		Mockito.when(request.getParameter("versionNo")).thenReturn("1");
 		RangerPolicy policy = new RangerPolicy();
 		Map<String, RangerPolicyResource> resources = new HashMap<String, RangerPolicy.RangerPolicyResource>();
 		policy.setService("services");
