@@ -22,8 +22,7 @@ import java.nio.file.FileSystems;
 import java.nio.file.Files;
 import java.util.List;
 
-import org.apache.ranger.admin.client.RangerAdminClient;
-import org.apache.ranger.plugin.util.GrantRevokeRequest;
+import org.apache.ranger.admin.client.AbstractRangerAdminClient;
 import org.apache.ranger.plugin.util.ServicePolicies;
 import org.apache.ranger.plugin.util.ServiceTags;
 import org.slf4j.Logger;
@@ -35,7 +34,7 @@ import com.google.gson.GsonBuilder;
 /**
  * A test implementation of the RangerAdminClient interface that just reads policies in from a file and returns them
  */
-public class RangerAdminClientImpl implements RangerAdminClient {
+public class RangerAdminClientImpl extends AbstractRangerAdminClient {
     private static final Logger LOG = LoggerFactory.getLogger(RangerAdminClientImpl.class);
     private final static String cacheFilename = "storm-policies.json";
     private final static String tagFilename = "storm-policies-tag.json";
@@ -64,14 +63,6 @@ public class RangerAdminClientImpl implements RangerAdminClient {
         return gson.fromJson(new String(cacheBytes), ServicePolicies.class);
     }
 
-    public void grantAccess(GrantRevokeRequest request) throws Exception {
-
-    }
-
-    public void revokeAccess(GrantRevokeRequest request) throws Exception {
-
-    }
-
     public ServiceTags getServiceTagsIfUpdated(long lastKnownVersion, long lastActivationTimeInMillis) throws Exception {
         String basedir = System.getProperty("basedir");
         if (basedir == null) {
