@@ -39,7 +39,7 @@ public class UserGroupSyncConfig  {
 	public static final String CONFIG_FILE = "ranger-ugsync-site.xml";
 	private static final Logger LOG = Logger.getLogger(UserGroupSyncConfig.class);
 
-	public static final String DEFAULT_CONFIG_FILE = "ranger-ugsync-default-site.xml";
+	public static final String DEFAULT_CONFIG_FILE = "ranger-ugsync-default.xml";
 
 	private static final String CORE_SITE_CONFIG_FILE = "core-site.xml";
 
@@ -168,7 +168,7 @@ public class UserGroupSyncConfig  {
 	 * from the additional user search based on the user attribute configuration
 	 */
 	private static final String LGSYNC_USER_SEARCH_ENABLED = "ranger.usersync.user.searchenabled";
-	private static final boolean DEFAULT_LGSYNC_USER_SEARCH_ENABLED = false;
+	private static final boolean DEFAULT_LGSYNC_USER_SEARCH_ENABLED = true;
 
 	private static final String LGSYNC_GROUP_USER_MAP_SYNC_ENABLED = "ranger.usersync.group.usermapsyncenabled";
 	private static final boolean DEFAULT_LGSYNC_GROUP_USER_MAP_SYNC_ENABLED = false;
@@ -211,7 +211,6 @@ public class UserGroupSyncConfig  {
 
 	private static final String DEFAULT_POLICYMGR_USERNAME = "rangerusersync";
 
-	private static final String DEFAULT_POLICYMGR_PASSWORD = "rangerusersync";
 	private static final String SYNC_SOURCE = "ranger.usersync.sync.source";
 	private static final String LGSYNC_REFERRAL = "ranger.usersync.ldap.referral";
 	private static final String DEFAULT_LGSYNC_REFERRAL = "ignore";
@@ -233,7 +232,10 @@ public class UserGroupSyncConfig  {
     private static final String USERNAME_GROUPNAME_ASSIGNMENT_LIST_DELIMITER = "ranger.usersync.username.groupname.assignment.list.delimiter";
 
     private static final String GROUP_BASED_ROLE_ASSIGNMENT_RULES = "ranger.usersync.group.based.role.assignment.rules";
-	private Properties prop = new Properties();
+
+    private static final String USERSYNC_RANGER_COOKIE_ENABLED_PROP = "ranger.usersync.cookie.enabled";
+
+    private Properties prop = new Properties();
 
 	private static volatile UserGroupSyncConfig me = null;
 
@@ -255,9 +257,9 @@ public class UserGroupSyncConfig  {
 	}
 
 	private void init() {
+		XMLUtils.loadConfig(DEFAULT_CONFIG_FILE, prop);
 		XMLUtils.loadConfig(CORE_SITE_CONFIG_FILE, prop);
 		XMLUtils.loadConfig(CONFIG_FILE, prop);
-		XMLUtils.loadConfig(DEFAULT_CONFIG_FILE, prop);
 	}
 
 	public String getUserSyncFileSource(){
@@ -815,20 +817,13 @@ public class UserGroupSyncConfig  {
 		String userName=null;
 		if(prop!=null && prop.containsKey(SYNC_POLICY_MGR_USERNAME)){
 			userName=prop.getProperty(SYNC_POLICY_MGR_USERNAME);
-			if(userName!=null && !userName.isEmpty()){
-				return userName;
-			}
 		}
-		return null;
+		if (userName == null || userName.isEmpty()) {
+			userName = DEFAULT_POLICYMGR_USERNAME;
+		}
+		return userName;
 	}
 
-	public String getDefaultPolicyMgrUserName(){
-		return DEFAULT_POLICYMGR_USERNAME;
-	}
-
-	public String getDefaultPolicyMgrPassword(){
-		return DEFAULT_POLICYMGR_PASSWORD;
-	}
 	public String getSyncSource() {
 		String syncSource=null;
 		if(prop!=null && prop.containsKey(SYNC_SOURCE)){
@@ -928,6 +923,12 @@ public class UserGroupSyncConfig  {
         return null;
     }
 
+	public boolean isUserSyncRangerCookieEnabled() {
+		String val = prop.getProperty(USERSYNC_RANGER_COOKIE_ENABLED_PROP);
+		return val == null || Boolean.valueOf(val.trim());
+	}
+
+
     public String getRoleDelimiter() {
         if (prop != null && prop.containsKey(ROLE_ASSIGNMENT_LIST_DELIMITER)) {
             String roleDelimiter = prop
