@@ -24,15 +24,15 @@ import java.io.File;
 import java.io.FileInputStream;
 import java.io.InputStreamReader;
 import java.nio.charset.StandardCharsets;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.ArrayList;
-import java.util.Arrays;
+import java.text.DateFormat;
+import java.text.SimpleDateFormat;
+import java.util.*;
 
 import com.google.common.annotations.VisibleForTesting;
 import org.apache.log4j.Logger;
 import org.apache.ranger.unixusersync.config.UserGroupSyncConfig;
+import org.apache.ranger.unixusersync.model.UgsyncAuditInfo;
+import org.apache.ranger.unixusersync.model.UnixSyncSourceInfo;
 import org.apache.ranger.usergroupsync.UserGroupSink;
 import org.apache.ranger.usergroupsync.UserGroupSource;
 
@@ -83,6 +83,11 @@ public class UnixUserGroupBuilder implements UserGroupSource {
 
 	private long passwordFileModifiedAt = 0;
 	private long groupFileModifiedAt = 0;
+	private UgsyncAuditInfo ugsyncAuditInfo;
+	private UnixSyncSourceInfo unixSyncSourceInfo;
+	private boolean isStartupFlag = false;
+	Set<String> allGroups = new HashSet<>();
+
 
 	public static void main(String[] args) throws Throwable {
 		UnixUserGroupBuilder ugbuilder = new UnixUserGroupBuilder();
@@ -91,10 +96,18 @@ public class UnixUserGroupBuilder implements UserGroupSource {
 	}
 	
 	public UnixUserGroupBuilder() {
+		isStartupFlag = true;
 		minimumUserId = Integer.parseInt(config.getMinUserId());
 		minimumGroupId = Integer.parseInt(config.getMinGroupId());
 		unixPasswordFile = config.getUnixPasswordFile();
 		unixGroupFile = config.getUnixGroupFile();
+		ugsyncAuditInfo = new UgsyncAuditInfo();
+		unixSyncSourceInfo = new UnixSyncSourceInfo();
+		ugsyncAuditInfo.setSyncSource("Unix");
+		ugsyncAuditInfo.setUnixSyncSourceInfo(unixSyncSourceInfo);
+		unixSyncSourceInfo.setFileName(unixPasswordFile);
+		unixSyncSourceInfo.setMinUserId(config.getMinUserId());
+		unixSyncSourceInfo.setMinGroupId(config.getMinGroupId());
 
 		LOG.debug("Minimum UserId: " + minimumUserId + ", minimum GroupId: " + minimumGroupId);
 
@@ -103,10 +116,13 @@ public class UnixUserGroupBuilder implements UserGroupSource {
 
 		if (!config.getUnixBackend().equalsIgnoreCase(BACKEND_PASSWD)) {
 			useNss = true;
+			unixSyncSourceInfo.setUnixBackend("nss");
 		} else {
 			LOG.warn("DEPRECATED: Unix backend is configured to use /etc/passwd and /etc/group files directly " +
 					"instead of standard system mechanisms.");
+			unixSyncSourceInfo.setUnixBackend(BACKEND_PASSWD);
 		}
+
 	}
 
 	@Override
@@ -142,28 +158,43 @@ public class UnixUserGroupBuilder implements UserGroupSource {
 
 	@Override
 	public void updateSink(UserGroupSink sink) throws Throwable {
+		DateFormat formatter = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
+		Date lastModifiedTime = new Date(passwordFileModifiedAt);
+		Date syncTime = new Date(System.currentTimeMillis());
+		unixSyncSourceInfo.setLastModified(formatter.format(lastModifiedTime));
+		unixSyncSourceInfo.setSyncTime(formatter.format(syncTime));
 		isUpdateSinkSucc = true;
-		buildUserGroupInfo();
+		if (isChanged() || isStartupFlag) {
+			buildUserGroupInfo();
 
-		for (Map.Entry<String, List<String>> entry : user2GroupListMap.entrySet()) {
-		    String       user   = entry.getKey();
-		    List<String> groups = entry.getValue();
-		
-			try{
-				sink.addOrUpdateUser(user, groups);
-			}catch (Throwable t) {
-				LOG.error("sink.addOrUpdateUser failed with exception: " + t.getMessage()
-				+ ", for user: " + user
-				+ ", groups: " + groups);
-				isUpdateSinkSucc = false;
+			for (Map.Entry<String, List<String>> entry : user2GroupListMap.entrySet()) {
+				String user = entry.getKey();
+				List<String> groups = entry.getValue();
+				try {
+					sink.addOrUpdateUser(user, groups);
+				} catch (Throwable t) {
+					LOG.error("sink.addOrUpdateUser failed with exception: " + t.getMessage()
+							+ ", for user: " + user
+							+ ", groups: " + groups);
+					isUpdateSinkSucc = false;
+				}
 			}
 		}
+		try {
+			unixSyncSourceInfo.setTotalUsersSynced(user2GroupListMap.size());
+			unixSyncSourceInfo.setTotalGroupsSynced(allGroups.size());
+			sink.postUserGroupAuditInfo(ugsyncAuditInfo);
+		} catch (Throwable t) {
+			LOG.error("sink.postUserGroupAuditInfo failed with exception: ", t);
+		}
+		isStartupFlag = false;
 	}
 	
 	
 	private void buildUserGroupInfo() throws Throwable {
 		user2GroupListMap = new HashMap<String,List<String>>();
 		groupId2groupNameMap = new HashMap<String, String>();
+		allGroups = new HashSet<>();
 
 		if (OS.startsWith("Mac")) {
 			buildUnixGroupList(MAC_GET_ALL_GROUPS_CMD, MAC_GET_GROUP_CMD, false);
@@ -265,6 +296,7 @@ public class UnixUserGroupBuilder implements UserGroupSource {
 							groupList.addAll(map);
 						}
 						user2GroupListMap.put(userName, groupList);
+						allGroups.addAll(groupList);
 					} else {
 						// we are ignoring the possibility that this user was present in /etc/groups.
 						LOG.warn("Group Name could not be found for group id: [" + groupId + "]. Skipping adding user [" + userName + "] with id [" + userId + "].");
@@ -339,6 +371,7 @@ public class UnixUserGroupBuilder implements UserGroupSource {
 				}
 
 				user2GroupListMap.put(entry.getKey(), allowedGroups);
+				allGroups.addAll(allowedGroups);
 			}
 			LOG.debug("End drill down group members");
 		}
